Class: PaysecureApiDocumentationLive::ActionStatus

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/action_status.rb

Overview

ActionStatus Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type:, message:, actual_message:, merchant_name:, code:, status:, callback_url:, method:, beneficiary_id:, profile_id:, pay_in_bank_detail:, pix_payload:, pay_in_details:, balance:, vab:, auth_key:, method_execution_time:, password:, salt:, next_call:, next_url:, descriptor:, current_time:, cust_verification_string:, instructions:, trust_score:, trust_level:, no_of_cust_hits:, no_of_hits:, referer:, client_ip:, merchant_ip:, is_s2s:, otp:, user_device_id:, is_allowed:, logo_url:, transaction_expire_in_min:, mandate_reference_id:, additional_properties: nil) ⇒ ActionStatus

Returns a new instance of ActionStatus.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 258

def initialize(type:, message:, actual_message:, merchant_name:, code:,
               status:, callback_url:, method:, beneficiary_id:,
               profile_id:, pay_in_bank_detail:, pix_payload:,
               pay_in_details:, balance:, vab:, auth_key:,
               method_execution_time:, password:, salt:, next_call:,
               next_url:, descriptor:, current_time:,
               cust_verification_string:, instructions:, trust_score:,
               trust_level:, no_of_cust_hits:, no_of_hits:, referer:,
               client_ip:, merchant_ip:, is_s2s:, otp:, user_device_id:,
               is_allowed:, logo_url:, transaction_expire_in_min:,
               mandate_reference_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type
  @message = message
  @actual_message = actual_message
  @merchant_name = merchant_name
  @code = code
  @status = status
  @callback_url = callback_url
  @method = method
  @beneficiary_id = beneficiary_id
  @profile_id = profile_id
  @pay_in_bank_detail = pay_in_bank_detail
  @pix_payload = pix_payload
  @pay_in_details = pay_in_details
  @balance = balance
  @vab = vab
  @auth_key = auth_key
  @method_execution_time = method_execution_time
  @password = password
  @salt = salt
  @next_call = next_call
  @next_url = next_url
  @descriptor = descriptor
  @current_time = current_time
  @cust_verification_string = cust_verification_string
  @instructions = instructions
  @trust_score = trust_score
  @trust_level = trust_level
  @no_of_cust_hits = no_of_cust_hits
  @no_of_hits = no_of_hits
  @referer = referer
  @client_ip = client_ip
  @merchant_ip = merchant_ip
  @is_s2s = is_s2s
  @otp = otp
  @user_device_id = user_device_id
  @is_allowed = is_allowed
  @logo_url = logo_url
  @transaction_expire_in_min = transaction_expire_in_min
  @mandate_reference_id = mandate_reference_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#actual_messageString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 22

def actual_message
  @actual_message
end

#auth_keyString

TODO: Write general description for this method

Returns:

  • (String)


74
75
76
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 74

def auth_key
  @auth_key
end

#balanceString

TODO: Write general description for this method

Returns:

  • (String)


66
67
68
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 66

def balance
  @balance
end

#beneficiary_idString

TODO: Write general description for this method

Returns:

  • (String)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 46

def beneficiary_id
  @beneficiary_id
end

#callback_urlString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 38

def callback_url
  @callback_url
end

#client_ipString

TODO: Write general description for this method

Returns:

  • (String)


134
135
136
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 134

def client_ip
  @client_ip
end

#codeString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 30

def code
  @code
end

#current_timeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


102
103
104
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 102

def current_time
  @current_time
end

#cust_verification_stringString

TODO: Write general description for this method

Returns:

  • (String)


106
107
108
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 106

def cust_verification_string
  @cust_verification_string
end

#descriptorString

TODO: Write general description for this method

Returns:

  • (String)


98
99
100
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 98

def descriptor
  @descriptor
end

#instructionsString

TODO: Write general description for this method

Returns:

  • (String)


110
111
112
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 110

def instructions
  @instructions
end

#is_allowedString

TODO: Write general description for this method

Returns:

  • (String)


154
155
156
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 154

def is_allowed
  @is_allowed
end

#is_s2sString

TODO: Write general description for this method

Returns:

  • (String)


142
143
144
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 142

def is_s2s
  @is_s2s
end

#logo_urlString

TODO: Write general description for this method

Returns:

  • (String)


158
159
160
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 158

def logo_url
  @logo_url
end

#mandate_reference_idString

TODO: Write general description for this method

Returns:

  • (String)


166
167
168
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 166

def mandate_reference_id
  @mandate_reference_id
end

#merchant_ipString

TODO: Write general description for this method

Returns:

  • (String)


138
139
140
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 138

def merchant_ip
  @merchant_ip
end

#merchant_nameString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 26

def merchant_name
  @merchant_name
end

#messageString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 18

def message
  @message
end

#methodString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 42

def method
  @method
end

#method_execution_timeString

TODO: Write general description for this method

Returns:

  • (String)


78
79
80
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 78

def method_execution_time
  @method_execution_time
end

#next_callString

TODO: Write general description for this method

Returns:

  • (String)


90
91
92
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 90

def next_call
  @next_call
end

#next_urlString

TODO: Write general description for this method

Returns:

  • (String)


94
95
96
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 94

def next_url
  @next_url
end

#no_of_cust_hitsString

TODO: Write general description for this method

Returns:

  • (String)


122
123
124
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 122

def no_of_cust_hits
  @no_of_cust_hits
end

#no_of_hitsString

TODO: Write general description for this method

Returns:

  • (String)


126
127
128
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 126

def no_of_hits
  @no_of_hits
end

#otpString

TODO: Write general description for this method

Returns:

  • (String)


146
147
148
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 146

def otp
  @otp
end

#passwordString

TODO: Write general description for this method

Returns:

  • (String)


82
83
84
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 82

def password
  @password
end

#pay_in_bank_detailString

TODO: Write general description for this method

Returns:

  • (String)


54
55
56
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 54

def pay_in_bank_detail
  @pay_in_bank_detail
end

#pay_in_detailsPayInDetails2

TODO: Write general description for this method

Returns:



62
63
64
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 62

def pay_in_details
  @pay_in_details
end

#pix_payloadString

TODO: Write general description for this method

Returns:

  • (String)


58
59
60
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 58

def pix_payload
  @pix_payload
end

#profile_idString

TODO: Write general description for this method

Returns:

  • (String)


50
51
52
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 50

def profile_id
  @profile_id
end

#refererString

TODO: Write general description for this method

Returns:

  • (String)


130
131
132
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 130

def referer
  @referer
end

#saltString

TODO: Write general description for this method

Returns:

  • (String)


86
87
88
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 86

def salt
  @salt
end

#statusString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 34

def status
  @status
end

#transaction_expire_in_minString

TODO: Write general description for this method

Returns:

  • (String)


162
163
164
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 162

def transaction_expire_in_min
  @transaction_expire_in_min
end

#trust_levelString

TODO: Write general description for this method

Returns:

  • (String)


118
119
120
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 118

def trust_level
  @trust_level
end

#trust_scoreString

TODO: Write general description for this method

Returns:

  • (String)


114
115
116
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 114

def trust_score
  @trust_score
end

#typeString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 14

def type
  @type
end

#user_device_idString

TODO: Write general description for this method

Returns:

  • (String)


150
151
152
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 150

def user_device_id
  @user_device_id
end

#vabString

TODO: Write general description for this method

Returns:

  • (String)


70
71
72
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 70

def vab
  @vab
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 315

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('_type') ? hash['_type'] : nil
  message = hash.key?('message') ? hash['message'] : nil
  actual_message = hash.key?('actualMessage') ? hash['actualMessage'] : nil
  merchant_name = hash.key?('merchantName') ? hash['merchantName'] : nil
  code = hash.key?('code') ? hash['code'] : nil
  status = hash.key?('status') ? hash['status'] : nil
  callback_url = hash.key?('callback_url') ? hash['callback_url'] : nil
  method = hash.key?('method') ? hash['method'] : nil
  beneficiary_id = hash.key?('beneficiaryId') ? hash['beneficiaryId'] : nil
  profile_id = hash.key?('profileId') ? hash['profileId'] : nil
  pay_in_bank_detail =
    hash.key?('payInBankDetail') ? hash['payInBankDetail'] : nil
  pix_payload = hash.key?('pix_payload') ? hash['pix_payload'] : nil
  pay_in_details = PayInDetails2.from_hash(hash['payInDetails']) if hash['payInDetails']
  balance = hash.key?('balance') ? hash['balance'] : nil
  vab = hash.key?('vab') ? hash['vab'] : nil
  auth_key = hash.key?('authKey') ? hash['authKey'] : nil
  method_execution_time =
    hash.key?('methodExecutionTime') ? hash['methodExecutionTime'] : nil
  password = hash.key?('password') ? hash['password'] : nil
  salt = hash.key?('salt') ? hash['salt'] : nil
  next_call = hash.key?('nextCall') ? hash['nextCall'] : nil
  next_url = hash.key?('nextURL') ? hash['nextURL'] : nil
  descriptor = hash.key?('descriptor') ? hash['descriptor'] : nil
  current_time = hash.key?('currentTime') ? hash['currentTime'] : nil
  cust_verification_string =
    hash.key?('custVerificationString') ? hash['custVerificationString'] : nil
  instructions = hash.key?('instructions') ? hash['instructions'] : nil
  trust_score = hash.key?('trustScore') ? hash['trustScore'] : nil
  trust_level = hash.key?('trustLevel') ? hash['trustLevel'] : nil
  no_of_cust_hits =
    hash.key?('no_Of_Cust_Hits') ? hash['no_Of_Cust_Hits'] : nil
  no_of_hits = hash.key?('no_Of_Hits') ? hash['no_Of_Hits'] : nil
  referer = hash.key?('referer') ? hash['referer'] : nil
  client_ip = hash.key?('clientIp') ? hash['clientIp'] : nil
  merchant_ip = hash.key?('merchantIp') ? hash['merchantIp'] : nil
  is_s2s = hash.key?('isS2s') ? hash['isS2s'] : nil
  otp = hash.key?('otp') ? hash['otp'] : nil
  user_device_id = hash.key?('userDeviceId') ? hash['userDeviceId'] : nil
  is_allowed = hash.key?('isAllowed') ? hash['isAllowed'] : nil
  logo_url = hash.key?('logo_url') ? hash['logo_url'] : nil
  transaction_expire_in_min =
    hash.key?('transactionExpireInMin') ? hash['transactionExpireInMin'] : nil
  mandate_reference_id =
    hash.key?('mandateReferenceId') ? hash['mandateReferenceId'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ActionStatus.new(type: type,
                   message: message,
                   actual_message: actual_message,
                   merchant_name: merchant_name,
                   code: code,
                   status: status,
                   callback_url: callback_url,
                   method: method,
                   beneficiary_id: beneficiary_id,
                   profile_id: profile_id,
                   pay_in_bank_detail: pay_in_bank_detail,
                   pix_payload: pix_payload,
                   pay_in_details: pay_in_details,
                   balance: balance,
                   vab: vab,
                   auth_key: auth_key,
                   method_execution_time: method_execution_time,
                   password: password,
                   salt: salt,
                   next_call: next_call,
                   next_url: next_url,
                   descriptor: descriptor,
                   current_time: current_time,
                   cust_verification_string: cust_verification_string,
                   instructions: instructions,
                   trust_score: trust_score,
                   trust_level: trust_level,
                   no_of_cust_hits: no_of_cust_hits,
                   no_of_hits: no_of_hits,
                   referer: referer,
                   client_ip: client_ip,
                   merchant_ip: merchant_ip,
                   is_s2s: is_s2s,
                   otp: otp,
                   user_device_id: user_device_id,
                   is_allowed: is_allowed,
                   logo_url: logo_url,
                   transaction_expire_in_min: transaction_expire_in_min,
                   mandate_reference_id: mandate_reference_id,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 169

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = '_type'
  @_hash['message'] = 'message'
  @_hash['actual_message'] = 'actualMessage'
  @_hash['merchant_name'] = 'merchantName'
  @_hash['code'] = 'code'
  @_hash['status'] = 'status'
  @_hash['callback_url'] = 'callback_url'
  @_hash['method'] = 'method'
  @_hash['beneficiary_id'] = 'beneficiaryId'
  @_hash['profile_id'] = 'profileId'
  @_hash['pay_in_bank_detail'] = 'payInBankDetail'
  @_hash['pix_payload'] = 'pix_payload'
  @_hash['pay_in_details'] = 'payInDetails'
  @_hash['balance'] = 'balance'
  @_hash['vab'] = 'vab'
  @_hash['auth_key'] = 'authKey'
  @_hash['method_execution_time'] = 'methodExecutionTime'
  @_hash['password'] = 'password'
  @_hash['salt'] = 'salt'
  @_hash['next_call'] = 'nextCall'
  @_hash['next_url'] = 'nextURL'
  @_hash['descriptor'] = 'descriptor'
  @_hash['current_time'] = 'currentTime'
  @_hash['cust_verification_string'] = 'custVerificationString'
  @_hash['instructions'] = 'instructions'
  @_hash['trust_score'] = 'trustScore'
  @_hash['trust_level'] = 'trustLevel'
  @_hash['no_of_cust_hits'] = 'no_Of_Cust_Hits'
  @_hash['no_of_hits'] = 'no_Of_Hits'
  @_hash['referer'] = 'referer'
  @_hash['client_ip'] = 'clientIp'
  @_hash['merchant_ip'] = 'merchantIp'
  @_hash['is_s2s'] = 'isS2s'
  @_hash['otp'] = 'otp'
  @_hash['user_device_id'] = 'userDeviceId'
  @_hash['is_allowed'] = 'isAllowed'
  @_hash['logo_url'] = 'logo_url'
  @_hash['transaction_expire_in_min'] = 'transactionExpireInMin'
  @_hash['mandate_reference_id'] = 'mandateReferenceId'
  @_hash
end

.nullablesObject

An array for nullable fields



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 219

def self.nullables
  %w[
    message
    actual_message
    merchant_name
    callback_url
    method
    beneficiary_id
    profile_id
    pay_in_bank_detail
    pix_payload
    balance
    vab
    auth_key
    method_execution_time
    password
    salt
    next_call
    next_url
    descriptor
    cust_verification_string
    instructions
    trust_score
    trust_level
    no_of_cust_hits
    no_of_hits
    referer
    client_ip
    merchant_ip
    is_s2s
    otp
    user_device_id
    is_allowed
    logo_url
    transaction_expire_in_min
    mandate_reference_id
  ]
end

.optionalsObject

An array for optional fields



214
215
216
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 214

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 436

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, message: #{@message.inspect}, actual_message:"\
  " #{@actual_message.inspect}, merchant_name: #{@merchant_name.inspect}, code:"\
  " #{@code.inspect}, status: #{@status.inspect}, callback_url: #{@callback_url.inspect},"\
  " method: #{@method.inspect}, beneficiary_id: #{@beneficiary_id.inspect}, profile_id:"\
  " #{@profile_id.inspect}, pay_in_bank_detail: #{@pay_in_bank_detail.inspect}, pix_payload:"\
  " #{@pix_payload.inspect}, pay_in_details: #{@pay_in_details.inspect}, balance:"\
  " #{@balance.inspect}, vab: #{@vab.inspect}, auth_key: #{@auth_key.inspect},"\
  " method_execution_time: #{@method_execution_time.inspect}, password: #{@password.inspect},"\
  " salt: #{@salt.inspect}, next_call: #{@next_call.inspect}, next_url: #{@next_url.inspect},"\
  " descriptor: #{@descriptor.inspect}, current_time: #{@current_time.inspect},"\
  " cust_verification_string: #{@cust_verification_string.inspect}, instructions:"\
  " #{@instructions.inspect}, trust_score: #{@trust_score.inspect}, trust_level:"\
  " #{@trust_level.inspect}, no_of_cust_hits: #{@no_of_cust_hits.inspect}, no_of_hits:"\
  " #{@no_of_hits.inspect}, referer: #{@referer.inspect}, client_ip: #{@client_ip.inspect},"\
  " merchant_ip: #{@merchant_ip.inspect}, is_s2s: #{@is_s2s.inspect}, otp: #{@otp.inspect},"\
  " user_device_id: #{@user_device_id.inspect}, is_allowed: #{@is_allowed.inspect}, logo_url:"\
  " #{@logo_url.inspect}, transaction_expire_in_min: #{@transaction_expire_in_min.inspect},"\
  " mandate_reference_id: #{@mandate_reference_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/paysecure_api_documentation_live/models/action_status.rb', line 416

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, message: #{@message}, actual_message: #{@actual_message},"\
  " merchant_name: #{@merchant_name}, code: #{@code}, status: #{@status}, callback_url:"\
  " #{@callback_url}, method: #{@method}, beneficiary_id: #{@beneficiary_id}, profile_id:"\
  " #{@profile_id}, pay_in_bank_detail: #{@pay_in_bank_detail}, pix_payload: #{@pix_payload},"\
  " pay_in_details: #{@pay_in_details}, balance: #{@balance}, vab: #{@vab}, auth_key:"\
  " #{@auth_key}, method_execution_time: #{@method_execution_time}, password: #{@password},"\
  " salt: #{@salt}, next_call: #{@next_call}, next_url: #{@next_url}, descriptor:"\
  " #{@descriptor}, current_time: #{@current_time}, cust_verification_string:"\
  " #{@cust_verification_string}, instructions: #{@instructions}, trust_score:"\
  " #{@trust_score}, trust_level: #{@trust_level}, no_of_cust_hits: #{@no_of_cust_hits},"\
  " no_of_hits: #{@no_of_hits}, referer: #{@referer}, client_ip: #{@client_ip}, merchant_ip:"\
  " #{@merchant_ip}, is_s2s: #{@is_s2s}, otp: #{@otp}, user_device_id: #{@user_device_id},"\
  " is_allowed: #{@is_allowed}, logo_url: #{@logo_url}, transaction_expire_in_min:"\
  " #{@transaction_expire_in_min}, mandate_reference_id: #{@mandate_reference_id},"\
  " additional_properties: #{@additional_properties}>"
end