Class: PaysecureApiDocumentationLive::ApplepayToken
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::ApplepayToken
- Defined in:
- lib/paysecure_api_documentation_live/models/applepay_token.rb
Overview
ApplepayToken Model.
Instance Attribute Summary collapse
-
#data ⇒ String
TODO: Write general description for this method.
-
#header ⇒ Header
TODO: Write general description for this method.
-
#signature ⇒ String
TODO: Write general description for this method.
-
#version ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(version:, data:, signature:, header:, additional_properties: nil) ⇒ ApplepayToken
constructor
A new instance of ApplepayToken.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(version:, data:, signature:, header:, additional_properties: nil) ⇒ ApplepayToken
Returns a new instance of ApplepayToken.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/paysecure_api_documentation_live/models/applepay_token.rb', line 48 def initialize(version:, data:, signature:, header:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @version = version @data = data @signature = signature @header = header @additional_properties = additional_properties end |
Instance Attribute Details
#data ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/applepay_token.rb', line 18 def data @data end |
#header ⇒ Header
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/applepay_token.rb', line 26 def header @header end |
#signature ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/applepay_token.rb', line 22 def signature @signature end |
#version ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/applepay_token.rb', line 14 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/paysecure_api_documentation_live/models/applepay_token.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. version = hash.key?('version') ? hash['version'] : nil data = hash.key?('data') ? hash['data'] : nil signature = hash.key?('signature') ? hash['signature'] : nil header = Header.from_hash(hash['header']) if hash['header'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ApplepayToken.new(version: version, data: data, signature: signature, header: header, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/applepay_token.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['version'] = 'version' @_hash['data'] = 'data' @_hash['signature'] = 'signature' @_hash['header'] = 'header' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/applepay_token.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/applepay_token.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/paysecure_api_documentation_live/models/applepay_token.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} version: #{@version.inspect}, data: #{@data.inspect}, signature:"\ " #{@signature.inspect}, header: #{@header.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/paysecure_api_documentation_live/models/applepay_token.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} version: #{@version}, data: #{@data}, signature: #{@signature}, header:"\ " #{@header}, additional_properties: #{@additional_properties}>" end |