Class: PaysecureApiDocumentationLive::Attempt28

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/attempt28.rb

Overview

Attempt28 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_ip:, type:, payment_method:, flow:, successful:, country:, processing_time:, extra:, error:, additional_properties: nil) ⇒ Attempt28

Returns a new instance of Attempt28.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 73

def initialize(client_ip:, type:, payment_method:, flow:, successful:,
               country:, processing_time:, extra:, error:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_ip = client_ip
  @type = type
  @payment_method = payment_method
  @flow = flow
  @successful = successful
  @country = country
  @processing_time = processing_time
  @extra = extra
  @error = error
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_ipString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 14

def client_ip
  @client_ip
end

#countryString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 34

def country
  @country
end

#errorError

TODO: Write general description for this method

Returns:



46
47
48
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 46

def error
  @error
end

#extraExtra57

TODO: Write general description for this method

Returns:



42
43
44
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 42

def extra
  @extra
end

#flowString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 26

def flow
  @flow
end

#payment_methodString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 22

def payment_method
  @payment_method
end

#processing_timeInteger

TODO: Write general description for this method

Returns:

  • (Integer)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 38

def processing_time
  @processing_time
end

#successfulTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 30

def successful
  @successful
end

#typeString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 18

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 92

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  client_ip = hash.key?('client_ip') ? hash['client_ip'] : nil
  type = hash.key?('type') ? hash['type'] : nil
  payment_method =
    hash.key?('payment_method') ? hash['payment_method'] : nil
  flow = hash.key?('flow') ? hash['flow'] : nil
  successful = hash.key?('successful') ? hash['successful'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  processing_time =
    hash.key?('processing_time') ? hash['processing_time'] : nil
  extra = Extra57.from_hash(hash['extra']) if hash['extra']
  error = Error.from_hash(hash['error']) if hash['error']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Attempt28.new(client_ip: client_ip,
                type: type,
                payment_method: payment_method,
                flow: flow,
                successful: successful,
                country: country,
                processing_time: processing_time,
                extra: extra,
                error: error,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 49

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_ip'] = 'client_ip'
  @_hash['type'] = 'type'
  @_hash['payment_method'] = 'payment_method'
  @_hash['flow'] = 'flow'
  @_hash['successful'] = 'successful'
  @_hash['country'] = 'country'
  @_hash['processing_time'] = 'processing_time'
  @_hash['extra'] = 'extra'
  @_hash['error'] = 'error'
  @_hash
end

.nullablesObject

An array for nullable fields



69
70
71
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 69

def self.nullables
  []
end

.optionalsObject

An array for optional fields



64
65
66
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 64

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



138
139
140
141
142
143
144
145
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 138

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_ip: #{@client_ip.inspect}, type: #{@type.inspect}, payment_method:"\
  " #{@payment_method.inspect}, flow: #{@flow.inspect}, successful: #{@successful.inspect},"\
  " country: #{@country.inspect}, processing_time: #{@processing_time.inspect}, extra:"\
  " #{@extra.inspect}, error: #{@error.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



129
130
131
132
133
134
135
# File 'lib/paysecure_api_documentation_live/models/attempt28.rb', line 129

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_ip: #{@client_ip}, type: #{@type}, payment_method:"\
  " #{@payment_method}, flow: #{@flow}, successful: #{@successful}, country: #{@country},"\
  " processing_time: #{@processing_time}, extra: #{@extra}, error: #{@error},"\
  " additional_properties: #{@additional_properties}>"
end