Class: PaysecureApiDocumentationLive::Attempt5
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Attempt5
- Defined in:
- lib/paysecure_api_documentation_live/models/attempt5.rb
Overview
Attempt5 Model.
Instance Attribute Summary collapse
-
#client_ip ⇒ String
TODO: Write general description for this method.
-
#country ⇒ String
TODO: Write general description for this method.
-
#extra ⇒ Extra10
TODO: Write general description for this method.
-
#flow ⇒ String
TODO: Write general description for this method.
-
#payment_method ⇒ String
TODO: Write general description for this method.
-
#processing_time ⇒ Integer
TODO: Write general description for this method.
-
#successful ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_ip:, type:, payment_method:, flow:, successful:, country:, processing_time:, extra:, additional_properties: nil) ⇒ Attempt5
constructor
A new instance of Attempt5.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_ip:, type:, payment_method:, flow:, successful:, country:, processing_time:, extra:, additional_properties: nil) ⇒ Attempt5
Returns a new instance of Attempt5.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 68 def initialize(client_ip:, type:, payment_method:, flow:, successful:, country:, processing_time:, extra:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_ip = client_ip @type = type @payment_method = payment_method @flow = flow @successful = successful @country = country @processing_time = processing_time @extra = extra @additional_properties = additional_properties end |
Instance Attribute Details
#client_ip ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 14 def client_ip @client_ip end |
#country ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 34 def country @country end |
#extra ⇒ Extra10
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 42 def extra @extra end |
#flow ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 26 def flow @flow end |
#payment_method ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 22 def payment_method @payment_method end |
#processing_time ⇒ Integer
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 38 def processing_time @processing_time end |
#successful ⇒ TrueClass | FalseClass
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 30 def successful @successful end |
#type ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 18 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 86 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_ip = hash.key?('client_ip') ? hash['client_ip'] : nil type = hash.key?('type') ? hash['type'] : nil payment_method = hash.key?('payment_method') ? hash['payment_method'] : nil flow = hash.key?('flow') ? hash['flow'] : nil successful = hash.key?('successful') ? hash['successful'] : nil country = hash.key?('country') ? hash['country'] : nil processing_time = hash.key?('processing_time') ? hash['processing_time'] : nil extra = Extra10.from_hash(hash['extra']) if hash['extra'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Attempt5.new(client_ip: client_ip, type: type, payment_method: payment_method, flow: flow, successful: successful, country: country, processing_time: processing_time, extra: extra, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['client_ip'] = 'client_ip' @_hash['type'] = 'type' @_hash['payment_method'] = 'payment_method' @_hash['flow'] = 'flow' @_hash['successful'] = 'successful' @_hash['country'] = 'country' @_hash['processing_time'] = 'processing_time' @_hash['extra'] = 'extra' @_hash end |
.nullables ⇒ Object
An array for nullable fields
64 65 66 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 64 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 59 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
130 131 132 133 134 135 136 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 130 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_ip: #{@client_ip.inspect}, type: #{@type.inspect}, payment_method:"\ " #{@payment_method.inspect}, flow: #{@flow.inspect}, successful: #{@successful.inspect},"\ " country: #{@country.inspect}, processing_time: #{@processing_time.inspect}, extra:"\ " #{@extra.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
121 122 123 124 125 126 127 |
# File 'lib/paysecure_api_documentation_live/models/attempt5.rb', line 121 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_ip: #{@client_ip}, type: #{@type}, payment_method:"\ " #{@payment_method}, flow: #{@flow}, successful: #{@successful}, country: #{@country},"\ " processing_time: #{@processing_time}, extra: #{@extra}, additional_properties:"\ " #{@additional_properties}>" end |