Class: PaysecureApiDocumentationLive::Balance
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Balance
- Defined in:
- lib/paysecure_api_documentation_live/models/balance.rb
Overview
Balance Model.
Instance Attribute Summary collapse
-
#balance ⇒ Float
TODO: Write general description for this method.
-
#currency ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(currency:, balance:, additional_properties: nil) ⇒ Balance
constructor
A new instance of Balance.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(currency:, balance:, additional_properties: nil) ⇒ Balance
Returns a new instance of Balance.
38 39 40 41 42 43 44 45 |
# File 'lib/paysecure_api_documentation_live/models/balance.rb', line 38 def initialize(currency:, balance:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @currency = currency @balance = balance @additional_properties = additional_properties end |
Instance Attribute Details
#balance ⇒ Float
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/balance.rb', line 18 def balance @balance end |
#currency ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/balance.rb', line 14 def currency @currency end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/paysecure_api_documentation_live/models/balance.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. currency = hash.key?('currency') ? hash['currency'] : nil balance = hash.key?('balance') ? hash['balance'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Balance.new(currency: currency, balance: balance, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/paysecure_api_documentation_live/models/balance.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['currency'] = 'currency' @_hash['balance'] = 'balance' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/balance.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/balance.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/paysecure_api_documentation_live/models/balance.rb', line 70 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.currency, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.balance, ->(val) { val.instance_of? Float }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['currency'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['balance'], ->(val) { val.instance_of? Float }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/paysecure_api_documentation_live/models/balance.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency.inspect}, balance: #{@balance.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/paysecure_api_documentation_live/models/balance.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency}, balance: #{@balance}, additional_properties:"\ " #{@additional_properties}>" end |