Class: PaysecureApiDocumentationLive::BeneficiaryDetail
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::BeneficiaryDetail
- Defined in:
- lib/paysecure_api_documentation_live/models/beneficiary_detail.rb
Overview
BeneficiaryDetail Model.
Instance Attribute Summary collapse
-
#bank_account_number ⇒ String
TODO: Write general description for this method.
-
#ifsc_code ⇒ String
TODO: Write general description for this method.
-
#payee_name ⇒ String
TODO: Write general description for this method.
-
#transfer_type ⇒ String
TODO: Write general description for this method.
-
#upi ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bank_account_number:, upi:, transfer_type:, ifsc_code:, payee_name:, additional_properties: nil) ⇒ BeneficiaryDetail
constructor
A new instance of BeneficiaryDetail.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bank_account_number:, upi:, transfer_type:, ifsc_code:, payee_name:, additional_properties: nil) ⇒ BeneficiaryDetail
Returns a new instance of BeneficiaryDetail.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 53 def initialize(bank_account_number:, upi:, transfer_type:, ifsc_code:, payee_name:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bank_account_number = bank_account_number @upi = upi @transfer_type = transfer_type @ifsc_code = ifsc_code @payee_name = payee_name @additional_properties = additional_properties end |
Instance Attribute Details
#bank_account_number ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 14 def bank_account_number @bank_account_number end |
#ifsc_code ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 26 def ifsc_code @ifsc_code end |
#payee_name ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 30 def payee_name @payee_name end |
#transfer_type ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 22 def transfer_type @transfer_type end |
#upi ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 18 def upi @upi end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bank_account_number = hash.key?('bankAccountNumber') ? hash['bankAccountNumber'] : nil upi = hash.key?('upi') ? hash['upi'] : nil transfer_type = hash.key?('transferType') ? hash['transferType'] : nil ifsc_code = hash.key?('ifscCode') ? hash['ifscCode'] : nil payee_name = hash.key?('payeeName') ? hash['payeeName'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BeneficiaryDetail.new(bank_account_number: bank_account_number, upi: upi, transfer_type: transfer_type, ifsc_code: ifsc_code, payee_name: payee_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['bank_account_number'] = 'bankAccountNumber' @_hash['upi'] = 'upi' @_hash['transfer_type'] = 'transferType' @_hash['ifsc_code'] = 'ifscCode' @_hash['payee_name'] = 'payeeName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} bank_account_number: #{@bank_account_number.inspect}, upi: #{@upi.inspect},"\ " transfer_type: #{@transfer_type.inspect}, ifsc_code: #{@ifsc_code.inspect}, payee_name:"\ " #{@payee_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 100 |
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} bank_account_number: #{@bank_account_number}, upi: #{@upi}, transfer_type:"\ " #{@transfer_type}, ifsc_code: #{@ifsc_code}, payee_name: #{@payee_name},"\ " additional_properties: #{@additional_properties}>" end |