Class: PaysecureApiDocumentationLive::BeneficiaryDetail3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/beneficiary_detail3.rb

Overview

BeneficiaryDetail3 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(bank_account_name:, bank_account_number:, bank_name:, additional_properties: nil) ⇒ BeneficiaryDetail3

Returns a new instance of BeneficiaryDetail3.



43
44
45
46
47
48
49
50
51
52
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail3.rb', line 43

def initialize(bank_account_name:, bank_account_number:, bank_name:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @bank_account_name = 
  @bank_account_number = 
  @bank_name = bank_name
  @additional_properties = additional_properties
end

Instance Attribute Details

#bank_account_nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail3.rb', line 14

def 
  @bank_account_name
end

#bank_account_numberString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail3.rb', line 18

def 
  @bank_account_number
end

#bank_nameString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail3.rb', line 22

def bank_name
  @bank_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail3.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   =
    hash.key?('bankAccountName') ? hash['bankAccountName'] : nil
   =
    hash.key?('bankAccountNumber') ? hash['bankAccountNumber'] : nil
  bank_name = hash.key?('bankName') ? hash['bankName'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BeneficiaryDetail3.new(bank_account_name: ,
                         bank_account_number: ,
                         bank_name: bank_name,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail3.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['bank_account_name'] = 'bankAccountName'
  @_hash['bank_account_number'] = 'bankAccountNumber'
  @_hash['bank_name'] = 'bankName'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail3.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail3.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
93
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail3.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} bank_account_name: #{@bank_account_name.inspect}, bank_account_number:"\
  " #{@bank_account_number.inspect}, bank_name: #{@bank_name.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
85
# File 'lib/paysecure_api_documentation_live/models/beneficiary_detail3.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} bank_account_name: #{@bank_account_name}, bank_account_number:"\
  " #{@bank_account_number}, bank_name: #{@bank_name}, additional_properties:"\
  " #{@additional_properties}>"
end