Class: PaysecureApiDocumentationLive::CaptureRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::CaptureRequest
- Defined in:
- lib/paysecure_api_documentation_live/models/capture_request.rb
Overview
CaptureRequest Model.
Instance Attribute Summary collapse
-
#merchant_reference ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(merchant_reference:, additional_properties: nil) ⇒ CaptureRequest
constructor
A new instance of CaptureRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(merchant_reference:, additional_properties: nil) ⇒ CaptureRequest
Returns a new instance of CaptureRequest.
33 34 35 36 37 38 39 |
# File 'lib/paysecure_api_documentation_live/models/capture_request.rb', line 33 def initialize(merchant_reference:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @merchant_reference = merchant_reference @additional_properties = additional_properties end |
Instance Attribute Details
#merchant_reference ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/capture_request.rb', line 14 def merchant_reference @merchant_reference end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/paysecure_api_documentation_live/models/capture_request.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. merchant_reference = hash.key?('merchant_reference') ? hash['merchant_reference'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CaptureRequest.new(merchant_reference: merchant_reference, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/paysecure_api_documentation_live/models/capture_request.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['merchant_reference'] = 'merchant_reference' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/capture_request.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/paysecure_api_documentation_live/models/capture_request.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 73 |
# File 'lib/paysecure_api_documentation_live/models/capture_request.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} merchant_reference: #{@merchant_reference.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 66 |
# File 'lib/paysecure_api_documentation_live/models/capture_request.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} merchant_reference: #{@merchant_reference}, additional_properties:"\ " #{@additional_properties}>" end |