Class: PaysecureApiDocumentationLive::CheckingBalancePayoutError2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::CheckingBalancePayoutError2
- Defined in:
- lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb
Overview
CheckingBalancePayoutError2 Model.
Instance Attribute Summary collapse
-
#aggregated_balances ⇒ Array[String]
TODO: Write general description for this method.
-
#gateways ⇒ Array[Gateway2]
TODO: Write general description for this method.
-
#payment_method ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment_method:, status:, gateways:, aggregated_balances:, additional_properties: nil) ⇒ CheckingBalancePayoutError2
constructor
A new instance of CheckingBalancePayoutError2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_method:, status:, gateways:, aggregated_balances:, additional_properties: nil) ⇒ CheckingBalancePayoutError2
Returns a new instance of CheckingBalancePayoutError2.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb', line 48 def initialize(payment_method:, status:, gateways:, aggregated_balances:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @payment_method = payment_method @status = status @gateways = gateways @aggregated_balances = aggregated_balances @additional_properties = additional_properties end |
Instance Attribute Details
#aggregated_balances ⇒ Array[String]
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb', line 26 def aggregated_balances @aggregated_balances end |
#gateways ⇒ Array[Gateway2]
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb', line 22 def gateways @gateways end |
#payment_method ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb', line 14 def payment_method @payment_method end |
#status ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb', line 18 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payment_method = hash.key?('paymentMethod') ? hash['paymentMethod'] : nil status = hash.key?('status') ? hash['status'] : nil # Parameter is an array, so we need to iterate through it gateways = nil unless hash['gateways'].nil? gateways = [] hash['gateways'].each do |structure| gateways << (Gateway2.from_hash(structure) if structure) end end gateways = nil unless hash.key?('gateways') aggregated_balances = hash.key?('aggregatedBalances') ? hash['aggregatedBalances'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CheckingBalancePayoutError2.new(payment_method: payment_method, status: status, gateways: gateways, aggregated_balances: aggregated_balances, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['payment_method'] = 'paymentMethod' @_hash['status'] = 'status' @_hash['gateways'] = 'gateways' @_hash['aggregated_balances'] = 'aggregatedBalances' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment_method: #{@payment_method.inspect}, status: #{@status.inspect},"\ " gateways: #{@gateways.inspect}, aggregated_balances: #{@aggregated_balances.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 101 |
# File 'lib/paysecure_api_documentation_live/models/checking_balance_payout_error2.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment_method: #{@payment_method}, status: #{@status}, gateways:"\ " #{@gateways}, aggregated_balances: #{@aggregated_balances}, additional_properties:"\ " #{@additional_properties}>" end |