Class: PaysecureApiDocumentationLive::Client10

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/client10.rb

Overview

Client10 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(customer_id:, email:, phone:, full_name:, date_of_birth:, street_address:, country:, city:, zip_code:, cc:, bcc:, gender:, state_code:, additional_properties: nil) ⇒ Client10

Returns a new instance of Client10.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 93

def initialize(customer_id:, email:, phone:, full_name:, date_of_birth:,
               street_address:, country:, city:, zip_code:, cc:, bcc:,
               gender:, state_code:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @customer_id = customer_id
  @email = email
  @phone = phone
  @full_name = full_name
  @date_of_birth = date_of_birth
  @street_address = street_address
  @country = country
  @city = city
  @zip_code = zip_code
  @cc = cc
  @bcc = bcc
  @gender = gender
  @state_code = state_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#bccArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


54
55
56
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 54

def bcc
  @bcc
end

#ccArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


50
51
52
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 50

def cc
  @cc
end

#cityString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 42

def city
  @city
end

#countryString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 38

def country
  @country
end

#customer_idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 14

def customer_id
  @customer_id
end

#date_of_birthString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 30

def date_of_birth
  @date_of_birth
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 18

def email
  @email
end

#full_nameString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 26

def full_name
  @full_name
end

#genderString

TODO: Write general description for this method

Returns:

  • (String)


58
59
60
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 58

def gender
  @gender
end

#phoneString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 22

def phone
  @phone
end

#state_codeString

TODO: Write general description for this method

Returns:

  • (String)


62
63
64
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 62

def state_code
  @state_code
end

#street_addressString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 34

def street_address
  @street_address
end

#zip_codeString

TODO: Write general description for this method

Returns:

  • (String)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 46

def zip_code
  @zip_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 116

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  customer_id = hash.key?('customerId') ? hash['customerId'] : nil
  email = hash.key?('email') ? hash['email'] : nil
  phone = hash.key?('phone') ? hash['phone'] : nil
  full_name = hash.key?('full_name') ? hash['full_name'] : nil
  date_of_birth = hash.key?('date_of_birth') ? hash['date_of_birth'] : nil
  street_address =
    hash.key?('street_address') ? hash['street_address'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  city = hash.key?('city') ? hash['city'] : nil
  zip_code = hash.key?('zip_code') ? hash['zip_code'] : nil
  cc = hash.key?('cc') ? hash['cc'] : nil
  bcc = hash.key?('bcc') ? hash['bcc'] : nil
  gender = hash.key?('gender') ? hash['gender'] : nil
  state_code = hash.key?('stateCode') ? hash['stateCode'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Client10.new(customer_id: customer_id,
               email: email,
               phone: phone,
               full_name: full_name,
               date_of_birth: date_of_birth,
               street_address: street_address,
               country: country,
               city: city,
               zip_code: zip_code,
               cc: cc,
               bcc: bcc,
               gender: gender,
               state_code: state_code,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 65

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['customer_id'] = 'customerId'
  @_hash['email'] = 'email'
  @_hash['phone'] = 'phone'
  @_hash['full_name'] = 'full_name'
  @_hash['date_of_birth'] = 'date_of_birth'
  @_hash['street_address'] = 'street_address'
  @_hash['country'] = 'country'
  @_hash['city'] = 'city'
  @_hash['zip_code'] = 'zip_code'
  @_hash['cc'] = 'cc'
  @_hash['bcc'] = 'bcc'
  @_hash['gender'] = 'gender'
  @_hash['state_code'] = 'stateCode'
  @_hash
end

.nullablesObject

An array for nullable fields



89
90
91
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 89

def self.nullables
  []
end

.optionalsObject

An array for optional fields



84
85
86
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 84

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



170
171
172
173
174
175
176
177
178
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 170

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id.inspect}, email: #{@email.inspect}, phone:"\
  " #{@phone.inspect}, full_name: #{@full_name.inspect}, date_of_birth:"\
  " #{@date_of_birth.inspect}, street_address: #{@street_address.inspect}, country:"\
  " #{@country.inspect}, city: #{@city.inspect}, zip_code: #{@zip_code.inspect}, cc:"\
  " #{@cc.inspect}, bcc: #{@bcc.inspect}, gender: #{@gender.inspect}, state_code:"\
  " #{@state_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



160
161
162
163
164
165
166
167
# File 'lib/paysecure_api_documentation_live/models/client10.rb', line 160

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id}, email: #{@email}, phone: #{@phone},"\
  " full_name: #{@full_name}, date_of_birth: #{@date_of_birth}, street_address:"\
  " #{@street_address}, country: #{@country}, city: #{@city}, zip_code: #{@zip_code}, cc:"\
  " #{@cc}, bcc: #{@bcc}, gender: #{@gender}, state_code: #{@state_code},"\
  " additional_properties: #{@additional_properties}>"
end