Class: PaysecureApiDocumentationLive::Client100

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/client100.rb

Overview

Client100 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(customer_id:, email:, street_address:, country:, city:, zip_code:, cc:, bcc:, state_code:, additional_properties: nil) ⇒ Client100

Returns a new instance of Client100.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 73

def initialize(customer_id:, email:, street_address:, country:, city:,
               zip_code:, cc:, bcc:, state_code:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @customer_id = customer_id
  @email = email
  @street_address = street_address
  @country = country
  @city = city
  @zip_code = zip_code
  @cc = cc
  @bcc = bcc
  @state_code = state_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#bccArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


42
43
44
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 42

def bcc
  @bcc
end

#ccArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


38
39
40
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 38

def cc
  @cc
end

#cityString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 30

def city
  @city
end

#countryString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 26

def country
  @country
end

#customer_idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 14

def customer_id
  @customer_id
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 18

def email
  @email
end

#state_codeString

TODO: Write general description for this method

Returns:

  • (String)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 46

def state_code
  @state_code
end

#street_addressString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 22

def street_address
  @street_address
end

#zip_codeString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 34

def zip_code
  @zip_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 92

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  customer_id = hash.key?('customerId') ? hash['customerId'] : nil
  email = hash.key?('email') ? hash['email'] : nil
  street_address =
    hash.key?('street_address') ? hash['street_address'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  city = hash.key?('city') ? hash['city'] : nil
  zip_code = hash.key?('zip_code') ? hash['zip_code'] : nil
  cc = hash.key?('cc') ? hash['cc'] : nil
  bcc = hash.key?('bcc') ? hash['bcc'] : nil
  state_code = hash.key?('stateCode') ? hash['stateCode'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Client100.new(customer_id: customer_id,
                email: email,
                street_address: street_address,
                country: country,
                city: city,
                zip_code: zip_code,
                cc: cc,
                bcc: bcc,
                state_code: state_code,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 49

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['customer_id'] = 'customerId'
  @_hash['email'] = 'email'
  @_hash['street_address'] = 'street_address'
  @_hash['country'] = 'country'
  @_hash['city'] = 'city'
  @_hash['zip_code'] = 'zip_code'
  @_hash['cc'] = 'cc'
  @_hash['bcc'] = 'bcc'
  @_hash['state_code'] = 'stateCode'
  @_hash
end

.nullablesObject

An array for nullable fields



69
70
71
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 69

def self.nullables
  []
end

.optionalsObject

An array for optional fields



64
65
66
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 64

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



137
138
139
140
141
142
143
144
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 137

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id.inspect}, email: #{@email.inspect},"\
  " street_address: #{@street_address.inspect}, country: #{@country.inspect}, city:"\
  " #{@city.inspect}, zip_code: #{@zip_code.inspect}, cc: #{@cc.inspect}, bcc:"\
  " #{@bcc.inspect}, state_code: #{@state_code.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



128
129
130
131
132
133
134
# File 'lib/paysecure_api_documentation_live/models/client100.rb', line 128

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id}, email: #{@email}, street_address:"\
  " #{@street_address}, country: #{@country}, city: #{@city}, zip_code: #{@zip_code}, cc:"\
  " #{@cc}, bcc: #{@bcc}, state_code: #{@state_code}, additional_properties:"\
  " #{@additional_properties}>"
end