Class: PaysecureApiDocumentationLive::Client12

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/client12.rb

Overview

Client12 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type:, customer_id:, email:, phone:, full_name:, date_of_birth:, street_address:, country:, city:, zip_code:, document_id:, document_type:, spei_clabe:, spei_debit_card:, spei_mobile_no:, state_code:, additional_properties: nil) ⇒ Client12

Returns a new instance of Client12.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 115

def initialize(type:, customer_id:, email:, phone:, full_name:,
               date_of_birth:, street_address:, country:, city:, zip_code:,
               document_id:, document_type:, spei_clabe:, spei_debit_card:,
               spei_mobile_no:, state_code:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type
  @customer_id = customer_id
  @email = email
  @phone = phone
  @full_name = full_name
  @date_of_birth = date_of_birth
  @street_address = street_address
  @country = country
  @city = city
  @zip_code = zip_code
  @document_id = document_id
  @document_type = document_type
  @spei_clabe = spei_clabe
  @spei_debit_card = spei_debit_card
  @spei_mobile_no = spei_mobile_no
  @state_code = state_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#cityString

TODO: Write general description for this method

Returns:

  • (String)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 46

def city
  @city
end

#countryString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 42

def country
  @country
end

#customer_idString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 18

def customer_id
  @customer_id
end

#date_of_birthString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 34

def date_of_birth
  @date_of_birth
end

#document_idString

TODO: Write general description for this method

Returns:

  • (String)


54
55
56
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 54

def document_id
  @document_id
end

#document_typeString

TODO: Write general description for this method

Returns:

  • (String)


58
59
60
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 58

def document_type
  @document_type
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 22

def email
  @email
end

#full_nameString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 30

def full_name
  @full_name
end

#phoneString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 26

def phone
  @phone
end

#spei_clabeString

TODO: Write general description for this method

Returns:

  • (String)


62
63
64
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 62

def spei_clabe
  @spei_clabe
end

#spei_debit_cardString

TODO: Write general description for this method

Returns:

  • (String)


66
67
68
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 66

def spei_debit_card
  @spei_debit_card
end

#spei_mobile_noString

TODO: Write general description for this method

Returns:

  • (String)


70
71
72
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 70

def spei_mobile_no
  @spei_mobile_no
end

#state_codeString

TODO: Write general description for this method

Returns:

  • (String)


74
75
76
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 74

def state_code
  @state_code
end

#street_addressString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 38

def street_address
  @street_address
end

#typeString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 14

def type
  @type
end

#zip_codeString

TODO: Write general description for this method

Returns:

  • (String)


50
51
52
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 50

def zip_code
  @zip_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 142

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('_type') ? hash['_type'] : nil
  customer_id = hash.key?('customerId') ? hash['customerId'] : nil
  email = hash.key?('email') ? hash['email'] : nil
  phone = hash.key?('phone') ? hash['phone'] : nil
  full_name = hash.key?('full_name') ? hash['full_name'] : nil
  date_of_birth = hash.key?('date_of_birth') ? hash['date_of_birth'] : nil
  street_address =
    hash.key?('street_address') ? hash['street_address'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  city = hash.key?('city') ? hash['city'] : nil
  zip_code = hash.key?('zip_code') ? hash['zip_code'] : nil
  document_id = hash.key?('documentId') ? hash['documentId'] : nil
  document_type = hash.key?('documentType') ? hash['documentType'] : nil
  spei_clabe = hash.key?('spei_clabe') ? hash['spei_clabe'] : nil
  spei_debit_card =
    hash.key?('spei_debitCard') ? hash['spei_debitCard'] : nil
  spei_mobile_no = hash.key?('spei_mobileNo') ? hash['spei_mobileNo'] : nil
  state_code = hash.key?('stateCode') ? hash['stateCode'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Client12.new(type: type,
               customer_id: customer_id,
               email: email,
               phone: phone,
               full_name: full_name,
               date_of_birth: date_of_birth,
               street_address: street_address,
               country: country,
               city: city,
               zip_code: zip_code,
               document_id: document_id,
               document_type: document_type,
               spei_clabe: spei_clabe,
               spei_debit_card: spei_debit_card,
               spei_mobile_no: spei_mobile_no,
               state_code: state_code,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 77

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = '_type'
  @_hash['customer_id'] = 'customerId'
  @_hash['email'] = 'email'
  @_hash['phone'] = 'phone'
  @_hash['full_name'] = 'full_name'
  @_hash['date_of_birth'] = 'date_of_birth'
  @_hash['street_address'] = 'street_address'
  @_hash['country'] = 'country'
  @_hash['city'] = 'city'
  @_hash['zip_code'] = 'zip_code'
  @_hash['document_id'] = 'documentId'
  @_hash['document_type'] = 'documentType'
  @_hash['spei_clabe'] = 'spei_clabe'
  @_hash['spei_debit_card'] = 'spei_debitCard'
  @_hash['spei_mobile_no'] = 'spei_mobileNo'
  @_hash['state_code'] = 'stateCode'
  @_hash
end

.nullablesObject

An array for nullable fields



104
105
106
107
108
109
110
111
112
113
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 104

def self.nullables
  %w[
    date_of_birth
    document_id
    document_type
    spei_clabe
    spei_debit_card
    spei_mobile_no
  ]
end

.optionalsObject

An array for optional fields



99
100
101
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 99

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



204
205
206
207
208
209
210
211
212
213
214
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 204

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, customer_id: #{@customer_id.inspect}, email:"\
  " #{@email.inspect}, phone: #{@phone.inspect}, full_name: #{@full_name.inspect},"\
  " date_of_birth: #{@date_of_birth.inspect}, street_address: #{@street_address.inspect},"\
  " country: #{@country.inspect}, city: #{@city.inspect}, zip_code: #{@zip_code.inspect},"\
  " document_id: #{@document_id.inspect}, document_type: #{@document_type.inspect},"\
  " spei_clabe: #{@spei_clabe.inspect}, spei_debit_card: #{@spei_debit_card.inspect},"\
  " spei_mobile_no: #{@spei_mobile_no.inspect}, state_code: #{@state_code.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



193
194
195
196
197
198
199
200
201
# File 'lib/paysecure_api_documentation_live/models/client12.rb', line 193

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, customer_id: #{@customer_id}, email: #{@email}, phone:"\
  " #{@phone}, full_name: #{@full_name}, date_of_birth: #{@date_of_birth}, street_address:"\
  " #{@street_address}, country: #{@country}, city: #{@city}, zip_code: #{@zip_code},"\
  " document_id: #{@document_id}, document_type: #{@document_type}, spei_clabe:"\
  " #{@spei_clabe}, spei_debit_card: #{@spei_debit_card}, spei_mobile_no: #{@spei_mobile_no},"\
  " state_code: #{@state_code}, additional_properties: #{@additional_properties}>"
end