Class: PaysecureApiDocumentationLive::Client17

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/client17.rb

Overview

Client17 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(email:, country:, phone:, full_name:, additional_properties: nil) ⇒ Client17

Returns a new instance of Client17.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/paysecure_api_documentation_live/models/client17.rb', line 48

def initialize(email:, country:, phone:, full_name:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @email = email
  @country = country
  @phone = phone
  @full_name = full_name
  @additional_properties = additional_properties
end

Instance Attribute Details

#countryString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/client17.rb', line 18

def country
  @country
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/client17.rb', line 14

def email
  @email
end

#full_nameString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/client17.rb', line 26

def full_name
  @full_name
end

#phoneString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/client17.rb', line 22

def phone
  @phone
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/paysecure_api_documentation_live/models/client17.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  email = hash.key?('email') ? hash['email'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  phone = hash.key?('phone') ? hash['phone'] : nil
  full_name = hash.key?('full_name') ? hash['full_name'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Client17.new(email: email,
               country: country,
               phone: phone,
               full_name: full_name,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/paysecure_api_documentation_live/models/client17.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['email'] = 'email'
  @_hash['country'] = 'country'
  @_hash['phone'] = 'phone'
  @_hash['full_name'] = 'full_name'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/paysecure_api_documentation_live/models/client17.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/paysecure_api_documentation_live/models/client17.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
98
# File 'lib/paysecure_api_documentation_live/models/client17.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email.inspect}, country: #{@country.inspect}, phone:"\
  " #{@phone.inspect}, full_name: #{@full_name.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/paysecure_api_documentation_live/models/client17.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email}, country: #{@country}, phone: #{@phone}, full_name:"\
  " #{@full_name}, additional_properties: #{@additional_properties}>"
end