Class: PaysecureApiDocumentationLive::Client2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/client2.rb

Overview

Client2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(bank_account:, bank_code:, email:, phone:, full_name:, date_of_birth:, personal_code:, street_address:, country:, city:, zip_code:, shipping_street_address:, shipping_country:, shipping_city:, shipping_zip_code:, cc:, bcc:, legal_name:, brand_name:, registration_number:, tax_number:, state_code:, additional_properties: nil) ⇒ Client2

Returns a new instance of Client2.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 138

def initialize(bank_account:, bank_code:, email:, phone:, full_name:,
               date_of_birth:, personal_code:, street_address:, country:,
               city:, zip_code:, shipping_street_address:,
               shipping_country:, shipping_city:, shipping_zip_code:, cc:,
               bcc:, legal_name:, brand_name:, registration_number:,
               tax_number:, state_code:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @bank_account = 
  @bank_code = bank_code
  @email = email
  @phone = phone
  @full_name = full_name
  @date_of_birth = date_of_birth
  @personal_code = personal_code
  @street_address = street_address
  @country = country
  @city = city
  @zip_code = zip_code
  @shipping_street_address = shipping_street_address
  @shipping_country = shipping_country
  @shipping_city = shipping_city
  @shipping_zip_code = shipping_zip_code
  @cc = cc
  @bcc = bcc
  @legal_name = legal_name
  @brand_name = brand_name
  @registration_number = registration_number
  @tax_number = tax_number
  @state_code = state_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#bank_accountString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 14

def 
  @bank_account
end

#bank_codeString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 18

def bank_code
  @bank_code
end

#bccArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


78
79
80
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 78

def bcc
  @bcc
end

#brand_nameString

TODO: Write general description for this method

Returns:

  • (String)


86
87
88
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 86

def brand_name
  @brand_name
end

#ccArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


74
75
76
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 74

def cc
  @cc
end

#cityString

TODO: Write general description for this method

Returns:

  • (String)


50
51
52
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 50

def city
  @city
end

#countryString

TODO: Write general description for this method

Returns:

  • (String)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 46

def country
  @country
end

#date_of_birthString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 34

def date_of_birth
  @date_of_birth
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 22

def email
  @email
end

#full_nameString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 30

def full_name
  @full_name
end

TODO: Write general description for this method

Returns:

  • (String)


82
83
84
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 82

def legal_name
  @legal_name
end

#personal_codeString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 38

def personal_code
  @personal_code
end

#phoneString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 26

def phone
  @phone
end

#registration_numberString

TODO: Write general description for this method

Returns:

  • (String)


90
91
92
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 90

def registration_number
  @registration_number
end

#shipping_cityString

TODO: Write general description for this method

Returns:

  • (String)


66
67
68
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 66

def shipping_city
  @shipping_city
end

#shipping_countryString

TODO: Write general description for this method

Returns:

  • (String)


62
63
64
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 62

def shipping_country
  @shipping_country
end

#shipping_street_addressString

TODO: Write general description for this method

Returns:

  • (String)


58
59
60
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 58

def shipping_street_address
  @shipping_street_address
end

#shipping_zip_codeString

TODO: Write general description for this method

Returns:

  • (String)


70
71
72
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 70

def shipping_zip_code
  @shipping_zip_code
end

#state_codeString

TODO: Write general description for this method

Returns:

  • (String)


98
99
100
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 98

def state_code
  @state_code
end

#street_addressString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 42

def street_address
  @street_address
end

#tax_numberString

TODO: Write general description for this method

Returns:

  • (String)


94
95
96
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 94

def tax_number
  @tax_number
end

#zip_codeString

TODO: Write general description for this method

Returns:

  • (String)


54
55
56
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 54

def zip_code
  @zip_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 173

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('bank_account') ? hash['bank_account'] : nil
  bank_code = hash.key?('bank_code') ? hash['bank_code'] : nil
  email = hash.key?('email') ? hash['email'] : nil
  phone = hash.key?('phone') ? hash['phone'] : nil
  full_name = hash.key?('full_name') ? hash['full_name'] : nil
  date_of_birth = hash.key?('date_of_birth') ? hash['date_of_birth'] : nil
  personal_code = hash.key?('personal_code') ? hash['personal_code'] : nil
  street_address =
    hash.key?('street_address') ? hash['street_address'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  city = hash.key?('city') ? hash['city'] : nil
  zip_code = hash.key?('zip_code') ? hash['zip_code'] : nil
  shipping_street_address =
    hash.key?('shipping_street_address') ? hash['shipping_street_address'] : nil
  shipping_country =
    hash.key?('shipping_country') ? hash['shipping_country'] : nil
  shipping_city = hash.key?('shipping_city') ? hash['shipping_city'] : nil
  shipping_zip_code =
    hash.key?('shipping_zip_code') ? hash['shipping_zip_code'] : nil
  cc = hash.key?('cc') ? hash['cc'] : nil
  bcc = hash.key?('bcc') ? hash['bcc'] : nil
  legal_name = hash.key?('legal_name') ? hash['legal_name'] : nil
  brand_name = hash.key?('brand_name') ? hash['brand_name'] : nil
  registration_number =
    hash.key?('registration_number') ? hash['registration_number'] : nil
  tax_number = hash.key?('tax_number') ? hash['tax_number'] : nil
  state_code = hash.key?('stateCode') ? hash['stateCode'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Client2.new(bank_account: ,
              bank_code: bank_code,
              email: email,
              phone: phone,
              full_name: full_name,
              date_of_birth: date_of_birth,
              personal_code: personal_code,
              street_address: street_address,
              country: country,
              city: city,
              zip_code: zip_code,
              shipping_street_address: shipping_street_address,
              shipping_country: shipping_country,
              shipping_city: shipping_city,
              shipping_zip_code: shipping_zip_code,
              cc: cc,
              bcc: bcc,
              legal_name: legal_name,
              brand_name: brand_name,
              registration_number: registration_number,
              tax_number: tax_number,
              state_code: state_code,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 101

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['bank_account'] = 'bank_account'
  @_hash['bank_code'] = 'bank_code'
  @_hash['email'] = 'email'
  @_hash['phone'] = 'phone'
  @_hash['full_name'] = 'full_name'
  @_hash['date_of_birth'] = 'date_of_birth'
  @_hash['personal_code'] = 'personal_code'
  @_hash['street_address'] = 'street_address'
  @_hash['country'] = 'country'
  @_hash['city'] = 'city'
  @_hash['zip_code'] = 'zip_code'
  @_hash['shipping_street_address'] = 'shipping_street_address'
  @_hash['shipping_country'] = 'shipping_country'
  @_hash['shipping_city'] = 'shipping_city'
  @_hash['shipping_zip_code'] = 'shipping_zip_code'
  @_hash['cc'] = 'cc'
  @_hash['bcc'] = 'bcc'
  @_hash['legal_name'] = 'legal_name'
  @_hash['brand_name'] = 'brand_name'
  @_hash['registration_number'] = 'registration_number'
  @_hash['tax_number'] = 'tax_number'
  @_hash['state_code'] = 'stateCode'
  @_hash
end

.nullablesObject

An array for nullable fields



134
135
136
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 134

def self.nullables
  []
end

.optionalsObject

An array for optional fields



129
130
131
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 129

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 253

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} bank_account: #{@bank_account.inspect}, bank_code: #{@bank_code.inspect},"\
  " email: #{@email.inspect}, phone: #{@phone.inspect}, full_name: #{@full_name.inspect},"\
  " date_of_birth: #{@date_of_birth.inspect}, personal_code: #{@personal_code.inspect},"\
  " street_address: #{@street_address.inspect}, country: #{@country.inspect}, city:"\
  " #{@city.inspect}, zip_code: #{@zip_code.inspect}, shipping_street_address:"\
  " #{@shipping_street_address.inspect}, shipping_country: #{@shipping_country.inspect},"\
  " shipping_city: #{@shipping_city.inspect}, shipping_zip_code:"\
  " #{@shipping_zip_code.inspect}, cc: #{@cc.inspect}, bcc: #{@bcc.inspect}, legal_name:"\
  " #{@legal_name.inspect}, brand_name: #{@brand_name.inspect}, registration_number:"\
  " #{@registration_number.inspect}, tax_number: #{@tax_number.inspect}, state_code:"\
  " #{@state_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/paysecure_api_documentation_live/models/client2.rb', line 239

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} bank_account: #{@bank_account}, bank_code: #{@bank_code}, email: #{@email},"\
  " phone: #{@phone}, full_name: #{@full_name}, date_of_birth: #{@date_of_birth},"\
  " personal_code: #{@personal_code}, street_address: #{@street_address}, country:"\
  " #{@country}, city: #{@city}, zip_code: #{@zip_code}, shipping_street_address:"\
  " #{@shipping_street_address}, shipping_country: #{@shipping_country}, shipping_city:"\
  " #{@shipping_city}, shipping_zip_code: #{@shipping_zip_code}, cc: #{@cc}, bcc: #{@bcc},"\
  " legal_name: #{@legal_name}, brand_name: #{@brand_name}, registration_number:"\
  " #{@registration_number}, tax_number: #{@tax_number}, state_code: #{@state_code},"\
  " additional_properties: #{@additional_properties}>"
end