Class: PaysecureApiDocumentationLive::Client26

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/client26.rb

Overview

Client26 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(email:, full_name:, tax_number:, additional_properties: nil) ⇒ Client26

Returns a new instance of Client26.



43
44
45
46
47
48
49
50
51
# File 'lib/paysecure_api_documentation_live/models/client26.rb', line 43

def initialize(email:, full_name:, tax_number:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @email = email
  @full_name = full_name
  @tax_number = tax_number
  @additional_properties = additional_properties
end

Instance Attribute Details

#emailString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/client26.rb', line 14

def email
  @email
end

#full_nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/client26.rb', line 18

def full_name
  @full_name
end

#tax_numberString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/client26.rb', line 22

def tax_number
  @tax_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/paysecure_api_documentation_live/models/client26.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  email = hash.key?('email') ? hash['email'] : nil
  full_name = hash.key?('full_name') ? hash['full_name'] : nil
  tax_number = hash.key?('tax_number') ? hash['tax_number'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Client26.new(email: email,
               full_name: full_name,
               tax_number: tax_number,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/paysecure_api_documentation_live/models/client26.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['email'] = 'email'
  @_hash['full_name'] = 'full_name'
  @_hash['tax_number'] = 'tax_number'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/paysecure_api_documentation_live/models/client26.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/paysecure_api_documentation_live/models/client26.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/paysecure_api_documentation_live/models/client26.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email.inspect}, full_name: #{@full_name.inspect}, tax_number:"\
  " #{@tax_number.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



77
78
79
80
81
# File 'lib/paysecure_api_documentation_live/models/client26.rb', line 77

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email}, full_name: #{@full_name}, tax_number: #{@tax_number},"\
  " additional_properties: #{@additional_properties}>"
end