Class: PaysecureApiDocumentationLive::Client4
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Client4
- Defined in:
- lib/paysecure_api_documentation_live/models/client4.rb
Overview
Client4 Model.
Instance Attribute Summary collapse
-
#bcc ⇒ Array[String]
TODO: Write general description for this method.
-
#cc ⇒ Array[String]
TODO: Write general description for this method.
-
#city ⇒ String
TODO: Write general description for this method.
-
#country ⇒ String
TODO: Write general description for this method.
-
#customer_id ⇒ String
TODO: Write general description for this method.
-
#date_of_birth ⇒ String
TODO: Write general description for this method.
-
#email ⇒ String
TODO: Write general description for this method.
-
#full_name ⇒ String
TODO: Write general description for this method.
-
#phone ⇒ String
TODO: Write general description for this method.
-
#state_code ⇒ String
TODO: Write general description for this method.
-
#street_address ⇒ String
TODO: Write general description for this method.
-
#zip_code ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(customer_id:, email:, phone:, full_name:, date_of_birth:, street_address:, country:, city:, zip_code:, cc:, bcc:, state_code:, additional_properties: nil) ⇒ Client4
constructor
A new instance of Client4.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(customer_id:, email:, phone:, full_name:, date_of_birth:, street_address:, country:, city:, zip_code:, cc:, bcc:, state_code:, additional_properties: nil) ⇒ Client4
Returns a new instance of Client4.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 88 def initialize(customer_id:, email:, phone:, full_name:, date_of_birth:, street_address:, country:, city:, zip_code:, cc:, bcc:, state_code:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @customer_id = customer_id @email = email @phone = phone @full_name = full_name @date_of_birth = date_of_birth @street_address = street_address @country = country @city = city @zip_code = zip_code @cc = cc @bcc = bcc @state_code = state_code @additional_properties = additional_properties end |
Instance Attribute Details
#bcc ⇒ Array[String]
TODO: Write general description for this method
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 54 def bcc @bcc end |
#cc ⇒ Array[String]
TODO: Write general description for this method
50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 50 def cc @cc end |
#city ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 42 def city @city end |
#country ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 38 def country @country end |
#customer_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 14 def customer_id @customer_id end |
#date_of_birth ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 30 def date_of_birth @date_of_birth end |
#email ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 18 def email @email end |
#full_name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 26 def full_name @full_name end |
#phone ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 22 def phone @phone end |
#state_code ⇒ String
TODO: Write general description for this method
58 59 60 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 58 def state_code @state_code end |
#street_address ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 34 def street_address @street_address end |
#zip_code ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 46 def zip_code @zip_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 110 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. customer_id = hash.key?('customerId') ? hash['customerId'] : nil email = hash.key?('email') ? hash['email'] : nil phone = hash.key?('phone') ? hash['phone'] : nil full_name = hash.key?('full_name') ? hash['full_name'] : nil date_of_birth = hash.key?('date_of_birth') ? hash['date_of_birth'] : nil street_address = hash.key?('street_address') ? hash['street_address'] : nil country = hash.key?('country') ? hash['country'] : nil city = hash.key?('city') ? hash['city'] : nil zip_code = hash.key?('zip_code') ? hash['zip_code'] : nil cc = hash.key?('cc') ? hash['cc'] : nil bcc = hash.key?('bcc') ? hash['bcc'] : nil state_code = hash.key?('stateCode') ? hash['stateCode'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Client4.new(customer_id: customer_id, email: email, phone: phone, full_name: full_name, date_of_birth: date_of_birth, street_address: street_address, country: country, city: city, zip_code: zip_code, cc: cc, bcc: bcc, state_code: state_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 61 def self.names @_hash = {} if @_hash.nil? @_hash['customer_id'] = 'customerId' @_hash['email'] = 'email' @_hash['phone'] = 'phone' @_hash['full_name'] = 'full_name' @_hash['date_of_birth'] = 'date_of_birth' @_hash['street_address'] = 'street_address' @_hash['country'] = 'country' @_hash['city'] = 'city' @_hash['zip_code'] = 'zip_code' @_hash['cc'] = 'cc' @_hash['bcc'] = 'bcc' @_hash['state_code'] = 'stateCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
84 85 86 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 84 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
79 80 81 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 79 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
162 163 164 165 166 167 168 169 170 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 162 def inspect class_name = self.class.name.split('::').last "<#{class_name} customer_id: #{@customer_id.inspect}, email: #{@email.inspect}, phone:"\ " #{@phone.inspect}, full_name: #{@full_name.inspect}, date_of_birth:"\ " #{@date_of_birth.inspect}, street_address: #{@street_address.inspect}, country:"\ " #{@country.inspect}, city: #{@city.inspect}, zip_code: #{@zip_code.inspect}, cc:"\ " #{@cc.inspect}, bcc: #{@bcc.inspect}, state_code: #{@state_code.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
152 153 154 155 156 157 158 159 |
# File 'lib/paysecure_api_documentation_live/models/client4.rb', line 152 def to_s class_name = self.class.name.split('::').last "<#{class_name} customer_id: #{@customer_id}, email: #{@email}, phone: #{@phone},"\ " full_name: #{@full_name}, date_of_birth: #{@date_of_birth}, street_address:"\ " #{@street_address}, country: #{@country}, city: #{@city}, zip_code: #{@zip_code}, cc:"\ " #{@cc}, bcc: #{@bcc}, state_code: #{@state_code}, additional_properties:"\ " #{@additional_properties}>" end |