Class: PaysecureApiDocumentationLive::Client45

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/client45.rb

Overview

Client45 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(email:, country:, phone:, full_name:, state_code:, spei_clabe:, additional_properties: nil) ⇒ Client45

Returns a new instance of Client45.



58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 58

def initialize(email:, country:, phone:, full_name:, state_code:,
               spei_clabe:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @email = email
  @country = country
  @phone = phone
  @full_name = full_name
  @state_code = state_code
  @spei_clabe = spei_clabe
  @additional_properties = additional_properties
end

Instance Attribute Details

#countryString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 18

def country
  @country
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 14

def email
  @email
end

#full_nameString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 26

def full_name
  @full_name
end

#phoneString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 22

def phone
  @phone
end

#spei_clabeString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 34

def spei_clabe
  @spei_clabe
end

#state_codeString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 30

def state_code
  @state_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  email = hash.key?('email') ? hash['email'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  phone = hash.key?('phone') ? hash['phone'] : nil
  full_name = hash.key?('full_name') ? hash['full_name'] : nil
  state_code = hash.key?('stateCode') ? hash['stateCode'] : nil
  spei_clabe = hash.key?('spei_clabe') ? hash['spei_clabe'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Client45.new(email: email,
               country: country,
               phone: phone,
               full_name: full_name,
               state_code: state_code,
               spei_clabe: spei_clabe,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['email'] = 'email'
  @_hash['country'] = 'country'
  @_hash['phone'] = 'phone'
  @_hash['full_name'] = 'full_name'
  @_hash['state_code'] = 'stateCode'
  @_hash['spei_clabe'] = 'spei_clabe'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 54

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 49

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



110
111
112
113
114
115
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 110

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email.inspect}, country: #{@country.inspect}, phone:"\
  " #{@phone.inspect}, full_name: #{@full_name.inspect}, state_code: #{@state_code.inspect},"\
  " spei_clabe: #{@spei_clabe.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



102
103
104
105
106
107
# File 'lib/paysecure_api_documentation_live/models/client45.rb', line 102

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email}, country: #{@country}, phone: #{@phone}, full_name:"\
  " #{@full_name}, state_code: #{@state_code}, spei_clabe: #{@spei_clabe},"\
  " additional_properties: #{@additional_properties}>"
end