Class: PaysecureApiDocumentationLive::Client46
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Client46
- Defined in:
- lib/paysecure_api_documentation_live/models/client46.rb
Overview
Client46 Model.
Instance Attribute Summary collapse
-
#country ⇒ String
TODO: Write general description for this method.
-
#customer_id ⇒ String
TODO: Write general description for this method.
-
#email ⇒ String
TODO: Write general description for this method.
-
#full_name ⇒ String
TODO: Write general description for this method.
-
#phone ⇒ String
TODO: Write general description for this method.
-
#spei_clabe ⇒ String
TODO: Write general description for this method.
-
#state_code ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(customer_id:, email:, phone:, full_name:, country:, spei_clabe:, state_code:, additional_properties: nil) ⇒ Client46
constructor
A new instance of Client46.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(customer_id:, email:, phone:, full_name:, country:, spei_clabe:, state_code:, additional_properties: nil) ⇒ Client46
Returns a new instance of Client46.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 63 def initialize(customer_id:, email:, phone:, full_name:, country:, spei_clabe:, state_code:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @customer_id = customer_id @email = email @phone = phone @full_name = full_name @country = country @spei_clabe = spei_clabe @state_code = state_code @additional_properties = additional_properties end |
Instance Attribute Details
#country ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 30 def country @country end |
#customer_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 14 def customer_id @customer_id end |
#email ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 18 def email @email end |
#full_name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 26 def full_name @full_name end |
#phone ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 22 def phone @phone end |
#spei_clabe ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 34 def spei_clabe @spei_clabe end |
#state_code ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 38 def state_code @state_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 79 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. customer_id = hash.key?('customerId') ? hash['customerId'] : nil email = hash.key?('email') ? hash['email'] : nil phone = hash.key?('phone') ? hash['phone'] : nil full_name = hash.key?('full_name') ? hash['full_name'] : nil country = hash.key?('country') ? hash['country'] : nil spei_clabe = hash.key?('spei_clabe') ? hash['spei_clabe'] : nil state_code = hash.key?('stateCode') ? hash['stateCode'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Client46.new(customer_id: customer_id, email: email, phone: phone, full_name: full_name, country: country, spei_clabe: spei_clabe, state_code: state_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['customer_id'] = 'customerId' @_hash['email'] = 'email' @_hash['phone'] = 'phone' @_hash['full_name'] = 'full_name' @_hash['country'] = 'country' @_hash['spei_clabe'] = 'spei_clabe' @_hash['state_code'] = 'stateCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 59 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 54 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
118 119 120 121 122 123 124 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 118 def inspect class_name = self.class.name.split('::').last "<#{class_name} customer_id: #{@customer_id.inspect}, email: #{@email.inspect}, phone:"\ " #{@phone.inspect}, full_name: #{@full_name.inspect}, country: #{@country.inspect},"\ " spei_clabe: #{@spei_clabe.inspect}, state_code: #{@state_code.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
110 111 112 113 114 115 |
# File 'lib/paysecure_api_documentation_live/models/client46.rb', line 110 def to_s class_name = self.class.name.split('::').last "<#{class_name} customer_id: #{@customer_id}, email: #{@email}, phone: #{@phone},"\ " full_name: #{@full_name}, country: #{@country}, spei_clabe: #{@spei_clabe}, state_code:"\ " #{@state_code}, additional_properties: #{@additional_properties}>" end |