Class: PaysecureApiDocumentationLive::Client52

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/client52.rb

Overview

Client52 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(customer_id:, email:, full_name:, date_of_birth:, street_address:, country:, city:, zip_code:, cc:, bcc:, state_code:, additional_properties: nil) ⇒ Client52

Returns a new instance of Client52.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 83

def initialize(customer_id:, email:, full_name:, date_of_birth:,
               street_address:, country:, city:, zip_code:, cc:, bcc:,
               state_code:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @customer_id = customer_id
  @email = email
  @full_name = full_name
  @date_of_birth = date_of_birth
  @street_address = street_address
  @country = country
  @city = city
  @zip_code = zip_code
  @cc = cc
  @bcc = bcc
  @state_code = state_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#bccArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


50
51
52
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 50

def bcc
  @bcc
end

#ccArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


46
47
48
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 46

def cc
  @cc
end

#cityString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 38

def city
  @city
end

#countryString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 34

def country
  @country
end

#customer_idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 14

def customer_id
  @customer_id
end

#date_of_birthString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 26

def date_of_birth
  @date_of_birth
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 18

def email
  @email
end

#full_nameString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 22

def full_name
  @full_name
end

#state_codeString

TODO: Write general description for this method

Returns:

  • (String)


54
55
56
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 54

def state_code
  @state_code
end

#street_addressString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 30

def street_address
  @street_address
end

#zip_codeString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 42

def zip_code
  @zip_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 104

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  customer_id = hash.key?('customerId') ? hash['customerId'] : nil
  email = hash.key?('email') ? hash['email'] : nil
  full_name = hash.key?('full_name') ? hash['full_name'] : nil
  date_of_birth = hash.key?('date_of_birth') ? hash['date_of_birth'] : nil
  street_address =
    hash.key?('street_address') ? hash['street_address'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  city = hash.key?('city') ? hash['city'] : nil
  zip_code = hash.key?('zip_code') ? hash['zip_code'] : nil
  cc = hash.key?('cc') ? hash['cc'] : nil
  bcc = hash.key?('bcc') ? hash['bcc'] : nil
  state_code = hash.key?('stateCode') ? hash['stateCode'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Client52.new(customer_id: customer_id,
               email: email,
               full_name: full_name,
               date_of_birth: date_of_birth,
               street_address: street_address,
               country: country,
               city: city,
               zip_code: zip_code,
               cc: cc,
               bcc: bcc,
               state_code: state_code,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 57

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['customer_id'] = 'customerId'
  @_hash['email'] = 'email'
  @_hash['full_name'] = 'full_name'
  @_hash['date_of_birth'] = 'date_of_birth'
  @_hash['street_address'] = 'street_address'
  @_hash['country'] = 'country'
  @_hash['city'] = 'city'
  @_hash['zip_code'] = 'zip_code'
  @_hash['cc'] = 'cc'
  @_hash['bcc'] = 'bcc'
  @_hash['state_code'] = 'stateCode'
  @_hash
end

.nullablesObject

An array for nullable fields



79
80
81
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 79

def self.nullables
  []
end

.optionalsObject

An array for optional fields



74
75
76
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 74

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



153
154
155
156
157
158
159
160
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 153

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id.inspect}, email: #{@email.inspect}, full_name:"\
  " #{@full_name.inspect}, date_of_birth: #{@date_of_birth.inspect}, street_address:"\
  " #{@street_address.inspect}, country: #{@country.inspect}, city: #{@city.inspect},"\
  " zip_code: #{@zip_code.inspect}, cc: #{@cc.inspect}, bcc: #{@bcc.inspect}, state_code:"\
  " #{@state_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



144
145
146
147
148
149
150
# File 'lib/paysecure_api_documentation_live/models/client52.rb', line 144

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id}, email: #{@email}, full_name: #{@full_name},"\
  " date_of_birth: #{@date_of_birth}, street_address: #{@street_address}, country:"\
  " #{@country}, city: #{@city}, zip_code: #{@zip_code}, cc: #{@cc}, bcc: #{@bcc}, state_code:"\
  " #{@state_code}, additional_properties: #{@additional_properties}>"
end