Class: PaysecureApiDocumentationLive::Client65

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/client65.rb

Overview

Client65 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(email:, country:, city:, state_code:, street_address:, zip_code:, phone:, additional_properties: nil) ⇒ Client65

Returns a new instance of Client65.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 63

def initialize(email:, country:, city:, state_code:, street_address:,
               zip_code:, phone:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @email = email
  @country = country
  @city = city
  @state_code = state_code
  @street_address = street_address
  @zip_code = zip_code
  @phone = phone
  @additional_properties = additional_properties
end

Instance Attribute Details

#cityString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 22

def city
  @city
end

#countryString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 18

def country
  @country
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 14

def email
  @email
end

#phoneString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 38

def phone
  @phone
end

#state_codeString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 26

def state_code
  @state_code
end

#street_addressString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 30

def street_address
  @street_address
end

#zip_codeString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 34

def zip_code
  @zip_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  email = hash.key?('email') ? hash['email'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  city = hash.key?('city') ? hash['city'] : nil
  state_code = hash.key?('stateCode') ? hash['stateCode'] : nil
  street_address =
    hash.key?('street_address') ? hash['street_address'] : nil
  zip_code = hash.key?('zip_code') ? hash['zip_code'] : nil
  phone = hash.key?('phone') ? hash['phone'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Client65.new(email: email,
               country: country,
               city: city,
               state_code: state_code,
               street_address: street_address,
               zip_code: zip_code,
               phone: phone,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['email'] = 'email'
  @_hash['country'] = 'country'
  @_hash['city'] = 'city'
  @_hash['state_code'] = 'stateCode'
  @_hash['street_address'] = 'street_address'
  @_hash['zip_code'] = 'zip_code'
  @_hash['phone'] = 'phone'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 54

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



119
120
121
122
123
124
125
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 119

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email.inspect}, country: #{@country.inspect}, city:"\
  " #{@city.inspect}, state_code: #{@state_code.inspect}, street_address:"\
  " #{@street_address.inspect}, zip_code: #{@zip_code.inspect}, phone: #{@phone.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



111
112
113
114
115
116
# File 'lib/paysecure_api_documentation_live/models/client65.rb', line 111

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email}, country: #{@country}, city: #{@city}, state_code:"\
  " #{@state_code}, street_address: #{@street_address}, zip_code: #{@zip_code}, phone:"\
  " #{@phone}, additional_properties: #{@additional_properties}>"
end