Class: PaysecureApiDocumentationLive::Client67
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Client67
- Defined in:
- lib/paysecure_api_documentation_live/models/client67.rb
Overview
Client67 Model.
Instance Attribute Summary collapse
-
#country ⇒ String
TODO: Write general description for this method.
-
#email ⇒ String
TODO: Write general description for this method.
-
#full_name ⇒ String
TODO: Write general description for this method.
-
#phone ⇒ String
TODO: Write general description for this method.
-
#state_code ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(email:, country:, phone:, full_name:, state_code:, additional_properties: nil) ⇒ Client67
constructor
A new instance of Client67.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(email:, country:, phone:, full_name:, state_code:, additional_properties: nil) ⇒ Client67
Returns a new instance of Client67.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 53 def initialize(email:, country:, phone:, full_name:, state_code:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @email = email @country = country @phone = phone @full_name = full_name @state_code = state_code @additional_properties = additional_properties end |
Instance Attribute Details
#country ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 18 def country @country end |
#email ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 14 def email @email end |
#full_name ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 26 def full_name @full_name end |
#phone ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 22 def phone @phone end |
#state_code ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 30 def state_code @state_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. email = hash.key?('email') ? hash['email'] : nil country = hash.key?('country') ? hash['country'] : nil phone = hash.key?('phone') ? hash['phone'] : nil full_name = hash.key?('full_name') ? hash['full_name'] : nil state_code = hash.key?('stateCode') ? hash['stateCode'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Client67.new(email: email, country: country, phone: phone, full_name: full_name, state_code: state_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['email'] = 'email' @_hash['country'] = 'country' @_hash['phone'] = 'phone' @_hash['full_name'] = 'full_name' @_hash['state_code'] = 'stateCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 107 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} email: #{@email.inspect}, country: #{@country.inspect}, phone:"\ " #{@phone.inspect}, full_name: #{@full_name.inspect}, state_code: #{@state_code.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 99 |
# File 'lib/paysecure_api_documentation_live/models/client67.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} email: #{@email}, country: #{@country}, phone: #{@phone}, full_name:"\ " #{@full_name}, state_code: #{@state_code}, additional_properties:"\ " #{@additional_properties}>" end |