Class: PaysecureApiDocumentationLive::Client7

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/client7.rb

Overview

Client7 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(email:, country:, city:, state_code:, full_name:, street_address:, zip_code:, phone:, gender:, date_of_birth:, additional_properties: nil) ⇒ Client7

Returns a new instance of Client7.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 78

def initialize(email:, country:, city:, state_code:, full_name:,
               street_address:, zip_code:, phone:, gender:, date_of_birth:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @email = email
  @country = country
  @city = city
  @state_code = state_code
  @full_name = full_name
  @street_address = street_address
  @zip_code = zip_code
  @phone = phone
  @gender = gender
  @date_of_birth = date_of_birth
  @additional_properties = additional_properties
end

Instance Attribute Details

#cityString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 22

def city
  @city
end

#countryString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 18

def country
  @country
end

#date_of_birthString

TODO: Write general description for this method

Returns:

  • (String)


50
51
52
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 50

def date_of_birth
  @date_of_birth
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 14

def email
  @email
end

#full_nameString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 30

def full_name
  @full_name
end

#genderString

TODO: Write general description for this method

Returns:

  • (String)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 46

def gender
  @gender
end

#phoneString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 42

def phone
  @phone
end

#state_codeString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 26

def state_code
  @state_code
end

#street_addressString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 34

def street_address
  @street_address
end

#zip_codeString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 38

def zip_code
  @zip_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 98

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  email = hash.key?('email') ? hash['email'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  city = hash.key?('city') ? hash['city'] : nil
  state_code = hash.key?('stateCode') ? hash['stateCode'] : nil
  full_name = hash.key?('full_name') ? hash['full_name'] : nil
  street_address =
    hash.key?('street_address') ? hash['street_address'] : nil
  zip_code = hash.key?('zip_code') ? hash['zip_code'] : nil
  phone = hash.key?('phone') ? hash['phone'] : nil
  gender = hash.key?('gender') ? hash['gender'] : nil
  date_of_birth = hash.key?('date_of_birth') ? hash['date_of_birth'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Client7.new(email: email,
              country: country,
              city: city,
              state_code: state_code,
              full_name: full_name,
              street_address: street_address,
              zip_code: zip_code,
              phone: phone,
              gender: gender,
              date_of_birth: date_of_birth,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 53

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['email'] = 'email'
  @_hash['country'] = 'country'
  @_hash['city'] = 'city'
  @_hash['state_code'] = 'stateCode'
  @_hash['full_name'] = 'full_name'
  @_hash['street_address'] = 'street_address'
  @_hash['zip_code'] = 'zip_code'
  @_hash['phone'] = 'phone'
  @_hash['gender'] = 'gender'
  @_hash['date_of_birth'] = 'date_of_birth'
  @_hash
end

.nullablesObject

An array for nullable fields



74
75
76
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 74

def self.nullables
  []
end

.optionalsObject

An array for optional fields



69
70
71
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 69

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



145
146
147
148
149
150
151
152
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 145

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email.inspect}, country: #{@country.inspect}, city:"\
  " #{@city.inspect}, state_code: #{@state_code.inspect}, full_name: #{@full_name.inspect},"\
  " street_address: #{@street_address.inspect}, zip_code: #{@zip_code.inspect}, phone:"\
  " #{@phone.inspect}, gender: #{@gender.inspect}, date_of_birth: #{@date_of_birth.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



136
137
138
139
140
141
142
# File 'lib/paysecure_api_documentation_live/models/client7.rb', line 136

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} email: #{@email}, country: #{@country}, city: #{@city}, state_code:"\
  " #{@state_code}, full_name: #{@full_name}, street_address: #{@street_address}, zip_code:"\
  " #{@zip_code}, phone: #{@phone}, gender: #{@gender}, date_of_birth: #{@date_of_birth},"\
  " additional_properties: #{@additional_properties}>"
end