Class: PaysecureApiDocumentationLive::CreateCustomerRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/create_customer_request.rb

Overview

CreateCustomerRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(full_name:, email_id:, date_of_birth:, phone_no:, city:, state_code:, zip_code:, address:, country:, merchant_customer_id:, extra_param:, additional_properties: nil) ⇒ CreateCustomerRequest

Returns a new instance of CreateCustomerRequest.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 83

def initialize(full_name:, email_id:, date_of_birth:, phone_no:, city:,
               state_code:, zip_code:, address:, country:,
               merchant_customer_id:, extra_param:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @full_name = full_name
  @email_id = email_id
  @date_of_birth = date_of_birth
  @phone_no = phone_no
  @city = city
  @state_code = state_code
  @zip_code = zip_code
  @address = address
  @country = country
  @merchant_customer_id = merchant_customer_id
  @extra_param = extra_param
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 42

def address
  @address
end

#cityString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 30

def city
  @city
end

#countryString

TODO: Write general description for this method

Returns:

  • (String)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 46

def country
  @country
end

#date_of_birthString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 22

def date_of_birth
  @date_of_birth
end

#email_idString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 18

def email_id
  @email_id
end

#extra_paramExtraParam10

TODO: Write general description for this method

Returns:



54
55
56
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 54

def extra_param
  @extra_param
end

#full_nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 14

def full_name
  @full_name
end

#merchant_customer_idString

TODO: Write general description for this method

Returns:

  • (String)


50
51
52
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 50

def merchant_customer_id
  @merchant_customer_id
end

#phone_noString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 26

def phone_no
  @phone_no
end

#state_codeString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 34

def state_code
  @state_code
end

#zip_codeString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 38

def zip_code
  @zip_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 105

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  full_name = hash.key?('fullName') ? hash['fullName'] : nil
  email_id = hash.key?('emailId') ? hash['emailId'] : nil
  date_of_birth = hash.key?('dateOfBirth') ? hash['dateOfBirth'] : nil
  phone_no = hash.key?('phoneNo') ? hash['phoneNo'] : nil
  city = hash.key?('city') ? hash['city'] : nil
  state_code = hash.key?('stateCode') ? hash['stateCode'] : nil
  zip_code = hash.key?('zipCode') ? hash['zipCode'] : nil
  address = hash.key?('address') ? hash['address'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  merchant_customer_id =
    hash.key?('merchantCustomerId') ? hash['merchantCustomerId'] : nil
  extra_param = ExtraParam10.from_hash(hash['extraParam']) if hash['extraParam']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreateCustomerRequest.new(full_name: full_name,
                            email_id: email_id,
                            date_of_birth: date_of_birth,
                            phone_no: phone_no,
                            city: city,
                            state_code: state_code,
                            zip_code: zip_code,
                            address: address,
                            country: country,
                            merchant_customer_id: merchant_customer_id,
                            extra_param: extra_param,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 57

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['full_name'] = 'fullName'
  @_hash['email_id'] = 'emailId'
  @_hash['date_of_birth'] = 'dateOfBirth'
  @_hash['phone_no'] = 'phoneNo'
  @_hash['city'] = 'city'
  @_hash['state_code'] = 'stateCode'
  @_hash['zip_code'] = 'zipCode'
  @_hash['address'] = 'address'
  @_hash['country'] = 'country'
  @_hash['merchant_customer_id'] = 'merchantCustomerId'
  @_hash['extra_param'] = 'extraParam'
  @_hash
end

.nullablesObject

An array for nullable fields



79
80
81
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 79

def self.nullables
  []
end

.optionalsObject

An array for optional fields



74
75
76
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 74

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



155
156
157
158
159
160
161
162
163
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 155

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} full_name: #{@full_name.inspect}, email_id: #{@email_id.inspect},"\
  " date_of_birth: #{@date_of_birth.inspect}, phone_no: #{@phone_no.inspect}, city:"\
  " #{@city.inspect}, state_code: #{@state_code.inspect}, zip_code: #{@zip_code.inspect},"\
  " address: #{@address.inspect}, country: #{@country.inspect}, merchant_customer_id:"\
  " #{@merchant_customer_id.inspect}, extra_param: #{@extra_param.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



145
146
147
148
149
150
151
152
# File 'lib/paysecure_api_documentation_live/models/create_customer_request.rb', line 145

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} full_name: #{@full_name}, email_id: #{@email_id}, date_of_birth:"\
  " #{@date_of_birth}, phone_no: #{@phone_no}, city: #{@city}, state_code: #{@state_code},"\
  " zip_code: #{@zip_code}, address: #{@address}, country: #{@country}, merchant_customer_id:"\
  " #{@merchant_customer_id}, extra_param: #{@extra_param}, additional_properties:"\
  " #{@additional_properties}>"
end