Class: PaysecureApiDocumentationLive::CreatePayoutSuccess
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::CreatePayoutSuccess
- Defined in:
- lib/paysecure_api_documentation_live/models/create_payout_success.rb
Overview
CreatePayoutSuccess Model.
Instance Attribute Summary collapse
-
#action_status ⇒ ActionStatus
TODO: Write general description for this method.
-
#agent_id ⇒ Integer
TODO: Write general description for this method.
-
#amount ⇒ Integer
TODO: Write general description for this method.
-
#amount_in_usd ⇒ Float
TODO: Write general description for this method.
-
#amount_unit ⇒ String
TODO: Write general description for this method.
-
#auth_key ⇒ String
TODO: Write general description for this method.
-
#bankid ⇒ String
TODO: Write general description for this method.
-
#bankmid ⇒ String
TODO: Write general description for this method.
-
#bankname ⇒ String
TODO: Write general description for this method.
-
#beneficiary_detail ⇒ String
TODO: Write general description for this method.
-
#cascade_num ⇒ String
TODO: Write general description for this method.
-
#client ⇒ Client12
TODO: Write general description for this method.
-
#client_ip ⇒ String
TODO: Write general description for this method.
-
#conversion_risk_factor_applied ⇒ String
TODO: Write general description for this method.
-
#created_on ⇒ Integer
TODO: Write general description for this method.
-
#currency ⇒ String
TODO: Write general description for this method.
-
#currency_conversion ⇒ String
TODO: Write general description for this method.
-
#cust_unique_id ⇒ String
TODO: Write general description for this method.
-
#day ⇒ String
TODO: Write general description for this method.
-
#error_msg ⇒ String
TODO: Write general description for this method.
-
#failure_callback ⇒ String
TODO: Write general description for this method.
-
#failure_redirect ⇒ String
TODO: Write general description for this method.
-
#fees_deducted ⇒ Integer
TODO: Write general description for this method.
-
#fx_amount ⇒ String
TODO: Write general description for this method.
-
#fx_currency ⇒ String
TODO: Write general description for this method.
-
#hour ⇒ Integer
TODO: Write general description for this method.
-
#instruction ⇒ String
TODO: Write general description for this method.
-
#issued ⇒ String
TODO: Write general description for this method.
-
#mdr ⇒ String
TODO: Write general description for this method.
-
#merchant_id ⇒ String
TODO: Write general description for this method.
-
#merchant_ip ⇒ String
TODO: Write general description for this method.
-
#merchant_name ⇒ String
TODO: Write general description for this method.
-
#merchant_ref ⇒ String
TODO: Write general description for this method.
-
#month ⇒ String
TODO: Write general description for this method.
-
#parent_id ⇒ Integer
TODO: Write general description for this method.
-
#payout_id ⇒ String
TODO: Write general description for this method.
-
#payout_method ⇒ String
TODO: Write general description for this method.
-
#pending_redirect ⇒ String
TODO: Write general description for this method.
-
#psp_reference ⇒ String
TODO: Write general description for this method.
-
#pu_id ⇒ String
TODO: Write general description for this method.
-
#purpose ⇒ String
TODO: Write general description for this method.
-
#referer ⇒ String
TODO: Write general description for this method.
-
#response_msg ⇒ String
TODO: Write general description for this method.
-
#rule_name ⇒ String
TODO: Write general description for this method.
-
#set_curr ⇒ String
TODO: Write general description for this method.
-
#signature ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
-
#status_history ⇒ Array[StatusHistory8]
TODO: Write general description for this method.
-
#success_callback ⇒ String
TODO: Write general description for this method.
-
#success_redirect ⇒ String
TODO: Write general description for this method.
-
#trans_fees ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
-
#u_id ⇒ Integer
TODO: Write general description for this method.
-
#updated_on ⇒ Integer
TODO: Write general description for this method.
-
#use_private_key ⇒ String
TODO: Write general description for this method.
-
#viewed_on ⇒ String
TODO: Write general description for this method.
-
#white_id ⇒ Integer
TODO: Write general description for this method.
-
#year ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type:, payout_id:, client:, updated_on:, payout_method:, beneficiary_detail:, amount_unit:, amount:, error_msg:, issued:, response_msg:, purpose:, created_on:, cust_unique_id:, amount_in_usd:, merchant_ref:, instruction:, merchant_id:, use_private_key:, merchant_name:, agent_id:, parent_id:, white_id:, year:, month:, day:, hour:, bankid:, set_curr:, psp_reference:, bankmid:, bankname:, status:, status_history:, viewed_on:, currency:, action_status:, fx_currency:, fx_amount:, referer:, client_ip:, merchant_ip:, trans_fees:, mdr:, rule_name:, cascade_num:, conversion_risk_factor_applied:, fees_deducted:, signature:, pu_id:, u_id:, auth_key:, currency_conversion:, success_callback:, failure_callback:, success_redirect:, failure_redirect:, pending_redirect:, additional_properties: nil) ⇒ CreatePayoutSuccess
constructor
A new instance of CreatePayoutSuccess.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type:, payout_id:, client:, updated_on:, payout_method:, beneficiary_detail:, amount_unit:, amount:, error_msg:, issued:, response_msg:, purpose:, created_on:, cust_unique_id:, amount_in_usd:, merchant_ref:, instruction:, merchant_id:, use_private_key:, merchant_name:, agent_id:, parent_id:, white_id:, year:, month:, day:, hour:, bankid:, set_curr:, psp_reference:, bankmid:, bankname:, status:, status_history:, viewed_on:, currency:, action_status:, fx_currency:, fx_amount:, referer:, client_ip:, merchant_ip:, trans_fees:, mdr:, rule_name:, cascade_num:, conversion_risk_factor_applied:, fees_deducted:, signature:, pu_id:, u_id:, auth_key:, currency_conversion:, success_callback:, failure_callback:, success_redirect:, failure_redirect:, pending_redirect:, additional_properties: nil) ⇒ CreatePayoutSuccess
Returns a new instance of CreatePayoutSuccess.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 342 def initialize(type:, payout_id:, client:, updated_on:, payout_method:, beneficiary_detail:, amount_unit:, amount:, error_msg:, issued:, response_msg:, purpose:, created_on:, cust_unique_id:, amount_in_usd:, merchant_ref:, instruction:, merchant_id:, use_private_key:, merchant_name:, agent_id:, parent_id:, white_id:, year:, month:, day:, hour:, bankid:, set_curr:, psp_reference:, bankmid:, bankname:, status:, status_history:, viewed_on:, currency:, action_status:, fx_currency:, fx_amount:, referer:, client_ip:, merchant_ip:, trans_fees:, mdr:, rule_name:, cascade_num:, conversion_risk_factor_applied:, fees_deducted:, signature:, pu_id:, u_id:, auth_key:, currency_conversion:, success_callback:, failure_callback:, success_redirect:, failure_redirect:, pending_redirect:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type @payout_id = payout_id @client = client @updated_on = updated_on @payout_method = payout_method @beneficiary_detail = beneficiary_detail @amount_unit = amount_unit @amount = amount @error_msg = error_msg @issued = issued @response_msg = response_msg @purpose = purpose @created_on = created_on @cust_unique_id = cust_unique_id @amount_in_usd = amount_in_usd @merchant_ref = merchant_ref @instruction = instruction @merchant_id = merchant_id @use_private_key = use_private_key @merchant_name = merchant_name @agent_id = agent_id @parent_id = parent_id @white_id = white_id @year = year @month = month @day = day @hour = hour @bankid = bankid @set_curr = set_curr @psp_reference = psp_reference @bankmid = bankmid @bankname = bankname @status = status @status_history = status_history @viewed_on = viewed_on @currency = currency @action_status = action_status @fx_currency = fx_currency @fx_amount = fx_amount @referer = referer @client_ip = client_ip @merchant_ip = merchant_ip @trans_fees = trans_fees @mdr = mdr @rule_name = rule_name @cascade_num = cascade_num @conversion_risk_factor_applied = conversion_risk_factor_applied @fees_deducted = fees_deducted @signature = signature @pu_id = pu_id @u_id = u_id @auth_key = auth_key @currency_conversion = currency_conversion @success_callback = success_callback @failure_callback = failure_callback @success_redirect = success_redirect @failure_redirect = failure_redirect @pending_redirect = pending_redirect @additional_properties = additional_properties end |
Instance Attribute Details
#action_status ⇒ ActionStatus
TODO: Write general description for this method
158 159 160 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 158 def action_status @action_status end |
#agent_id ⇒ Integer
TODO: Write general description for this method
94 95 96 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 94 def agent_id @agent_id end |
#amount ⇒ Integer
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 42 def amount @amount end |
#amount_in_usd ⇒ Float
TODO: Write general description for this method
70 71 72 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 70 def amount_in_usd @amount_in_usd end |
#amount_unit ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 38 def amount_unit @amount_unit end |
#auth_key ⇒ String
TODO: Write general description for this method
218 219 220 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 218 def auth_key @auth_key end |
#bankid ⇒ String
TODO: Write general description for this method
122 123 124 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 122 def bankid @bankid end |
#bankmid ⇒ String
TODO: Write general description for this method
134 135 136 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 134 def bankmid @bankmid end |
#bankname ⇒ String
TODO: Write general description for this method
138 139 140 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 138 def bankname @bankname end |
#beneficiary_detail ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 34 def beneficiary_detail @beneficiary_detail end |
#cascade_num ⇒ String
TODO: Write general description for this method
194 195 196 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 194 def cascade_num @cascade_num end |
#client ⇒ Client12
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 22 def client @client end |
#client_ip ⇒ String
TODO: Write general description for this method
174 175 176 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 174 def client_ip @client_ip end |
#conversion_risk_factor_applied ⇒ String
TODO: Write general description for this method
198 199 200 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 198 def conversion_risk_factor_applied @conversion_risk_factor_applied end |
#created_on ⇒ Integer
TODO: Write general description for this method
62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 62 def created_on @created_on end |
#currency ⇒ String
TODO: Write general description for this method
154 155 156 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 154 def currency @currency end |
#currency_conversion ⇒ String
TODO: Write general description for this method
222 223 224 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 222 def currency_conversion @currency_conversion end |
#cust_unique_id ⇒ String
TODO: Write general description for this method
66 67 68 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 66 def cust_unique_id @cust_unique_id end |
#day ⇒ String
TODO: Write general description for this method
114 115 116 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 114 def day @day end |
#error_msg ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 46 def error_msg @error_msg end |
#failure_callback ⇒ String
TODO: Write general description for this method
230 231 232 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 230 def failure_callback @failure_callback end |
#failure_redirect ⇒ String
TODO: Write general description for this method
238 239 240 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 238 def failure_redirect @failure_redirect end |
#fees_deducted ⇒ Integer
TODO: Write general description for this method
202 203 204 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 202 def fees_deducted @fees_deducted end |
#fx_amount ⇒ String
TODO: Write general description for this method
166 167 168 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 166 def fx_amount @fx_amount end |
#fx_currency ⇒ String
TODO: Write general description for this method
162 163 164 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 162 def fx_currency @fx_currency end |
#hour ⇒ Integer
TODO: Write general description for this method
118 119 120 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 118 def hour @hour end |
#instruction ⇒ String
TODO: Write general description for this method
78 79 80 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 78 def instruction @instruction end |
#issued ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 50 def issued @issued end |
#mdr ⇒ String
TODO: Write general description for this method
186 187 188 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 186 def mdr @mdr end |
#merchant_id ⇒ String
TODO: Write general description for this method
82 83 84 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 82 def merchant_id @merchant_id end |
#merchant_ip ⇒ String
TODO: Write general description for this method
178 179 180 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 178 def merchant_ip @merchant_ip end |
#merchant_name ⇒ String
TODO: Write general description for this method
90 91 92 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 90 def merchant_name @merchant_name end |
#merchant_ref ⇒ String
TODO: Write general description for this method
74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 74 def merchant_ref @merchant_ref end |
#month ⇒ String
TODO: Write general description for this method
110 111 112 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 110 def month @month end |
#parent_id ⇒ Integer
TODO: Write general description for this method
98 99 100 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 98 def parent_id @parent_id end |
#payout_id ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 18 def payout_id @payout_id end |
#payout_method ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 30 def payout_method @payout_method end |
#pending_redirect ⇒ String
TODO: Write general description for this method
242 243 244 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 242 def pending_redirect @pending_redirect end |
#psp_reference ⇒ String
TODO: Write general description for this method
130 131 132 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 130 def psp_reference @psp_reference end |
#pu_id ⇒ String
TODO: Write general description for this method
210 211 212 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 210 def pu_id @pu_id end |
#purpose ⇒ String
TODO: Write general description for this method
58 59 60 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 58 def purpose @purpose end |
#referer ⇒ String
TODO: Write general description for this method
170 171 172 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 170 def referer @referer end |
#response_msg ⇒ String
TODO: Write general description for this method
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 54 def response_msg @response_msg end |
#rule_name ⇒ String
TODO: Write general description for this method
190 191 192 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 190 def rule_name @rule_name end |
#set_curr ⇒ String
TODO: Write general description for this method
126 127 128 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 126 def set_curr @set_curr end |
#signature ⇒ String
TODO: Write general description for this method
206 207 208 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 206 def signature @signature end |
#status ⇒ String
TODO: Write general description for this method
142 143 144 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 142 def status @status end |
#status_history ⇒ Array[StatusHistory8]
TODO: Write general description for this method
146 147 148 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 146 def status_history @status_history end |
#success_callback ⇒ String
TODO: Write general description for this method
226 227 228 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 226 def success_callback @success_callback end |
#success_redirect ⇒ String
TODO: Write general description for this method
234 235 236 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 234 def success_redirect @success_redirect end |
#trans_fees ⇒ String
TODO: Write general description for this method
182 183 184 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 182 def trans_fees @trans_fees end |
#type ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 14 def type @type end |
#u_id ⇒ Integer
TODO: Write general description for this method
214 215 216 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 214 def u_id @u_id end |
#updated_on ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 26 def updated_on @updated_on end |
#use_private_key ⇒ String
TODO: Write general description for this method
86 87 88 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 86 def use_private_key @use_private_key end |
#viewed_on ⇒ String
TODO: Write general description for this method
150 151 152 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 150 def viewed_on @viewed_on end |
#white_id ⇒ Integer
TODO: Write general description for this method
102 103 104 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 102 def white_id @white_id end |
#year ⇒ String
TODO: Write general description for this method
106 107 108 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 106 def year @year end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 422 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('_type') ? hash['_type'] : nil payout_id = hash.key?('payoutId') ? hash['payoutId'] : nil client = Client12.from_hash(hash['client']) if hash['client'] updated_on = hash.key?('updated_on') ? hash['updated_on'] : nil payout_method = hash.key?('payoutMethod') ? hash['payoutMethod'] : nil beneficiary_detail = hash.key?('beneficiaryDetail') ? hash['beneficiaryDetail'] : nil amount_unit = hash.key?('amountUnit') ? hash['amountUnit'] : nil amount = hash.key?('amount') ? hash['amount'] : nil error_msg = hash.key?('errorMsg') ? hash['errorMsg'] : nil issued = hash.key?('issued') ? hash['issued'] : nil response_msg = hash.key?('responseMsg') ? hash['responseMsg'] : nil purpose = hash.key?('purpose') ? hash['purpose'] : nil created_on = hash.key?('created_on') ? hash['created_on'] : nil cust_unique_id = hash.key?('custUniqueId') ? hash['custUniqueId'] : nil amount_in_usd = hash.key?('amount_in_usd') ? hash['amount_in_usd'] : nil merchant_ref = hash.key?('merchantRef') ? hash['merchantRef'] : nil instruction = hash.key?('instruction') ? hash['instruction'] : nil merchant_id = hash.key?('merchant_id') ? hash['merchant_id'] : nil use_private_key = hash.key?('usePrivateKey') ? hash['usePrivateKey'] : nil merchant_name = hash.key?('merchantName') ? hash['merchantName'] : nil agent_id = hash.key?('agentId') ? hash['agentId'] : nil parent_id = hash.key?('parentId') ? hash['parentId'] : nil white_id = hash.key?('whiteId') ? hash['whiteId'] : nil year = hash.key?('year') ? hash['year'] : nil month = hash.key?('month') ? hash['month'] : nil day = hash.key?('day') ? hash['day'] : nil hour = hash.key?('hour') ? hash['hour'] : nil bankid = hash.key?('bankid') ? hash['bankid'] : nil set_curr = hash.key?('setCurr') ? hash['setCurr'] : nil psp_reference = hash.key?('pspReference') ? hash['pspReference'] : nil bankmid = hash.key?('bankmid') ? hash['bankmid'] : nil bankname = hash.key?('bankname') ? hash['bankname'] : nil status = hash.key?('status') ? hash['status'] : nil # Parameter is an array, so we need to iterate through it status_history = nil unless hash['status_history'].nil? status_history = [] hash['status_history'].each do |structure| status_history << (StatusHistory8.from_hash(structure) if structure) end end status_history = nil unless hash.key?('status_history') viewed_on = hash.key?('viewedOn') ? hash['viewedOn'] : nil currency = hash.key?('currency') ? hash['currency'] : nil action_status = ActionStatus.from_hash(hash['actionStatus']) if hash['actionStatus'] fx_currency = hash.key?('fx_Currency') ? hash['fx_Currency'] : nil fx_amount = hash.key?('fx_Amount') ? hash['fx_Amount'] : nil referer = hash.key?('referer') ? hash['referer'] : nil client_ip = hash.key?('clientIp') ? hash['clientIp'] : nil merchant_ip = hash.key?('merchantIp') ? hash['merchantIp'] : nil trans_fees = hash.key?('transFees') ? hash['transFees'] : nil mdr = hash.key?('MDR') ? hash['MDR'] : nil rule_name = hash.key?('ruleName') ? hash['ruleName'] : nil cascade_num = hash.key?('cascade_Num') ? hash['cascade_Num'] : nil conversion_risk_factor_applied = hash.key?('conversionRiskFactorApplied') ? hash['conversionRiskFactorApplied'] : nil fees_deducted = hash.key?('feesDeducted') ? hash['feesDeducted'] : nil signature = hash.key?('signature') ? hash['signature'] : nil pu_id = hash.key?('puId') ? hash['puId'] : nil u_id = hash.key?('uId') ? hash['uId'] : nil auth_key = hash.key?('authKey') ? hash['authKey'] : nil currency_conversion = hash.key?('currency_conversion') ? hash['currency_conversion'] : nil success_callback = hash.key?('success_callback') ? hash['success_callback'] : nil failure_callback = hash.key?('failure_callback') ? hash['failure_callback'] : nil success_redirect = hash.key?('success_redirect') ? hash['success_redirect'] : nil failure_redirect = hash.key?('failure_redirect') ? hash['failure_redirect'] : nil pending_redirect = hash.key?('pending_redirect') ? hash['pending_redirect'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreatePayoutSuccess.new(type: type, payout_id: payout_id, client: client, updated_on: updated_on, payout_method: payout_method, beneficiary_detail: beneficiary_detail, amount_unit: amount_unit, amount: amount, error_msg: error_msg, issued: issued, response_msg: response_msg, purpose: purpose, created_on: created_on, cust_unique_id: cust_unique_id, amount_in_usd: amount_in_usd, merchant_ref: merchant_ref, instruction: instruction, merchant_id: merchant_id, use_private_key: use_private_key, merchant_name: merchant_name, agent_id: agent_id, parent_id: parent_id, white_id: white_id, year: year, month: month, day: day, hour: hour, bankid: bankid, set_curr: set_curr, psp_reference: psp_reference, bankmid: bankmid, bankname: bankname, status: status, status_history: status_history, viewed_on: viewed_on, currency: currency, action_status: action_status, fx_currency: fx_currency, fx_amount: fx_amount, referer: referer, client_ip: client_ip, merchant_ip: merchant_ip, trans_fees: trans_fees, mdr: mdr, rule_name: rule_name, cascade_num: cascade_num, conversion_risk_factor_applied: conversion_risk_factor_applied, fees_deducted: fees_deducted, signature: signature, pu_id: pu_id, u_id: u_id, auth_key: auth_key, currency_conversion: currency_conversion, success_callback: success_callback, failure_callback: failure_callback, success_redirect: success_redirect, failure_redirect: failure_redirect, pending_redirect: pending_redirect, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 245 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = '_type' @_hash['payout_id'] = 'payoutId' @_hash['client'] = 'client' @_hash['updated_on'] = 'updated_on' @_hash['payout_method'] = 'payoutMethod' @_hash['beneficiary_detail'] = 'beneficiaryDetail' @_hash['amount_unit'] = 'amountUnit' @_hash['amount'] = 'amount' @_hash['error_msg'] = 'errorMsg' @_hash['issued'] = 'issued' @_hash['response_msg'] = 'responseMsg' @_hash['purpose'] = 'purpose' @_hash['created_on'] = 'created_on' @_hash['cust_unique_id'] = 'custUniqueId' @_hash['amount_in_usd'] = 'amount_in_usd' @_hash['merchant_ref'] = 'merchantRef' @_hash['instruction'] = 'instruction' @_hash['merchant_id'] = 'merchant_id' @_hash['use_private_key'] = 'usePrivateKey' @_hash['merchant_name'] = 'merchantName' @_hash['agent_id'] = 'agentId' @_hash['parent_id'] = 'parentId' @_hash['white_id'] = 'whiteId' @_hash['year'] = 'year' @_hash['month'] = 'month' @_hash['day'] = 'day' @_hash['hour'] = 'hour' @_hash['bankid'] = 'bankid' @_hash['set_curr'] = 'setCurr' @_hash['psp_reference'] = 'pspReference' @_hash['bankmid'] = 'bankmid' @_hash['bankname'] = 'bankname' @_hash['status'] = 'status' @_hash['status_history'] = 'status_history' @_hash['viewed_on'] = 'viewedOn' @_hash['currency'] = 'currency' @_hash['action_status'] = 'actionStatus' @_hash['fx_currency'] = 'fx_Currency' @_hash['fx_amount'] = 'fx_Amount' @_hash['referer'] = 'referer' @_hash['client_ip'] = 'clientIp' @_hash['merchant_ip'] = 'merchantIp' @_hash['trans_fees'] = 'transFees' @_hash['mdr'] = 'MDR' @_hash['rule_name'] = 'ruleName' @_hash['cascade_num'] = 'cascade_Num' @_hash['conversion_risk_factor_applied'] = 'conversionRiskFactorApplied' @_hash['fees_deducted'] = 'feesDeducted' @_hash['signature'] = 'signature' @_hash['pu_id'] = 'puId' @_hash['u_id'] = 'uId' @_hash['auth_key'] = 'authKey' @_hash['currency_conversion'] = 'currency_conversion' @_hash['success_callback'] = 'success_callback' @_hash['failure_callback'] = 'failure_callback' @_hash['success_redirect'] = 'success_redirect' @_hash['failure_redirect'] = 'failure_redirect' @_hash['pending_redirect'] = 'pending_redirect' @_hash end |
.nullables ⇒ Object
An array for nullable fields
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 314 def self.nullables %w[ beneficiary_detail response_msg instruction merchant_id use_private_key merchant_name year month day bankid psp_reference bankmid bankname viewed_on fx_currency fx_amount referer trans_fees mdr cascade_num conversion_risk_factor_applied signature currency_conversion ] end |
.optionals ⇒ Object
An array for optional fields
309 310 311 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 309 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 598 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, payout_id: #{@payout_id.inspect}, client:"\ " #{@client.inspect}, updated_on: #{@updated_on.inspect}, payout_method:"\ " #{@payout_method.inspect}, beneficiary_detail: #{@beneficiary_detail.inspect},"\ " amount_unit: #{@amount_unit.inspect}, amount: #{@amount.inspect}, error_msg:"\ " #{@error_msg.inspect}, issued: #{@issued.inspect}, response_msg: #{@response_msg.inspect},"\ " purpose: #{@purpose.inspect}, created_on: #{@created_on.inspect}, cust_unique_id:"\ " #{@cust_unique_id.inspect}, amount_in_usd: #{@amount_in_usd.inspect}, merchant_ref:"\ " #{@merchant_ref.inspect}, instruction: #{@instruction.inspect}, merchant_id:"\ " #{@merchant_id.inspect}, use_private_key: #{@use_private_key.inspect}, merchant_name:"\ " #{@merchant_name.inspect}, agent_id: #{@agent_id.inspect}, parent_id:"\ " #{@parent_id.inspect}, white_id: #{@white_id.inspect}, year: #{@year.inspect}, month:"\ " #{@month.inspect}, day: #{@day.inspect}, hour: #{@hour.inspect}, bankid:"\ " #{@bankid.inspect}, set_curr: #{@set_curr.inspect}, psp_reference:"\ " #{@psp_reference.inspect}, bankmid: #{@bankmid.inspect}, bankname: #{@bankname.inspect},"\ " status: #{@status.inspect}, status_history: #{@status_history.inspect}, viewed_on:"\ " #{@viewed_on.inspect}, currency: #{@currency.inspect}, action_status:"\ " #{@action_status.inspect}, fx_currency: #{@fx_currency.inspect}, fx_amount:"\ " #{@fx_amount.inspect}, referer: #{@referer.inspect}, client_ip: #{@client_ip.inspect},"\ " merchant_ip: #{@merchant_ip.inspect}, trans_fees: #{@trans_fees.inspect}, mdr:"\ " #{@mdr.inspect}, rule_name: #{@rule_name.inspect}, cascade_num: #{@cascade_num.inspect},"\ " conversion_risk_factor_applied: #{@conversion_risk_factor_applied.inspect}, fees_deducted:"\ " #{@fees_deducted.inspect}, signature: #{@signature.inspect}, pu_id: #{@pu_id.inspect},"\ " u_id: #{@u_id.inspect}, auth_key: #{@auth_key.inspect}, currency_conversion:"\ " #{@currency_conversion.inspect}, success_callback: #{@success_callback.inspect},"\ " failure_callback: #{@failure_callback.inspect}, success_redirect:"\ " #{@success_redirect.inspect}, failure_redirect: #{@failure_redirect.inspect},"\ " pending_redirect: #{@pending_redirect.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 |
# File 'lib/paysecure_api_documentation_live/models/create_payout_success.rb', line 572 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, payout_id: #{@payout_id}, client: #{@client}, updated_on:"\ " #{@updated_on}, payout_method: #{@payout_method}, beneficiary_detail:"\ " #{@beneficiary_detail}, amount_unit: #{@amount_unit}, amount: #{@amount}, error_msg:"\ " #{@error_msg}, issued: #{@issued}, response_msg: #{@response_msg}, purpose: #{@purpose},"\ " created_on: #{@created_on}, cust_unique_id: #{@cust_unique_id}, amount_in_usd:"\ " #{@amount_in_usd}, merchant_ref: #{@merchant_ref}, instruction: #{@instruction},"\ " merchant_id: #{@merchant_id}, use_private_key: #{@use_private_key}, merchant_name:"\ " #{@merchant_name}, agent_id: #{@agent_id}, parent_id: #{@parent_id}, white_id:"\ " #{@white_id}, year: #{@year}, month: #{@month}, day: #{@day}, hour: #{@hour}, bankid:"\ " #{@bankid}, set_curr: #{@set_curr}, psp_reference: #{@psp_reference}, bankmid:"\ " #{@bankmid}, bankname: #{@bankname}, status: #{@status}, status_history:"\ " #{@status_history}, viewed_on: #{@viewed_on}, currency: #{@currency}, action_status:"\ " #{@action_status}, fx_currency: #{@fx_currency}, fx_amount: #{@fx_amount}, referer:"\ " #{@referer}, client_ip: #{@client_ip}, merchant_ip: #{@merchant_ip}, trans_fees:"\ " #{@trans_fees}, mdr: #{@mdr}, rule_name: #{@rule_name}, cascade_num: #{@cascade_num},"\ " conversion_risk_factor_applied: #{@conversion_risk_factor_applied}, fees_deducted:"\ " #{@fees_deducted}, signature: #{@signature}, pu_id: #{@pu_id}, u_id: #{@u_id}, auth_key:"\ " #{@auth_key}, currency_conversion: #{@currency_conversion}, success_callback:"\ " #{@success_callback}, failure_callback: #{@failure_callback}, success_redirect:"\ " #{@success_redirect}, failure_redirect: #{@failure_redirect}, pending_redirect:"\ " #{@pending_redirect}, additional_properties: #{@additional_properties}>" end |