Class: PaysecureApiDocumentationLive::CreatePurchaseCitRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::CreatePurchaseCitRequest
- Defined in:
- lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb
Overview
CreatePurchaseCitRequest Model.
Instance Attribute Summary collapse
-
#brand_id ⇒ String
TODO: Write general description for this method.
-
#client ⇒ Client8
TODO: Write general description for this method.
-
#failure_callback ⇒ String
TODO: Write general description for this method.
-
#failure_redirect ⇒ String
TODO: Write general description for this method.
-
#mandate ⇒ Mandate
TODO: Write general description for this method.
-
#merchant_ref ⇒ String
TODO: Write general description for this method.
-
#payment_method ⇒ String
TODO: Write general description for this method.
-
#payment_type ⇒ String
TODO: Write general description for this method.
-
#pending_redirect ⇒ String
TODO: Write general description for this method.
-
#purchase ⇒ Purchase
TODO: Write general description for this method.
-
#success_callback ⇒ String
TODO: Write general description for this method.
-
#success_redirect ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client:, purchase:, merchant_ref:, payment_method:, brand_id:, payment_type:, mandate:, success_redirect:, pending_redirect:, failure_redirect:, success_callback:, failure_callback:, additional_properties: nil) ⇒ CreatePurchaseCitRequest
constructor
A new instance of CreatePurchaseCitRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client:, purchase:, merchant_ref:, payment_method:, brand_id:, payment_type:, mandate:, success_redirect:, pending_redirect:, failure_redirect:, success_callback:, failure_callback:, additional_properties: nil) ⇒ CreatePurchaseCitRequest
Returns a new instance of CreatePurchaseCitRequest.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 88 def initialize(client:, purchase:, merchant_ref:, payment_method:, brand_id:, payment_type:, mandate:, success_redirect:, pending_redirect:, failure_redirect:, success_callback:, failure_callback:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client = client @purchase = purchase @merchant_ref = merchant_ref @payment_method = payment_method @brand_id = brand_id @payment_type = payment_type @mandate = mandate @success_redirect = success_redirect @pending_redirect = pending_redirect @failure_redirect = failure_redirect @success_callback = success_callback @failure_callback = failure_callback @additional_properties = additional_properties end |
Instance Attribute Details
#brand_id ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 30 def brand_id @brand_id end |
#client ⇒ Client8
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 14 def client @client end |
#failure_callback ⇒ String
TODO: Write general description for this method
58 59 60 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 58 def failure_callback @failure_callback end |
#failure_redirect ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 50 def failure_redirect @failure_redirect end |
#mandate ⇒ Mandate
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 38 def mandate @mandate end |
#merchant_ref ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 22 def merchant_ref @merchant_ref end |
#payment_method ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 26 def payment_method @payment_method end |
#payment_type ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 34 def payment_type @payment_type end |
#pending_redirect ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 46 def pending_redirect @pending_redirect end |
#purchase ⇒ Purchase
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 18 def purchase @purchase end |
#success_callback ⇒ String
TODO: Write general description for this method
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 54 def success_callback @success_callback end |
#success_redirect ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 42 def success_redirect @success_redirect end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 111 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client = Client8.from_hash(hash['client']) if hash['client'] purchase = Purchase.from_hash(hash['purchase']) if hash['purchase'] merchant_ref = hash.key?('merchantRef') ? hash['merchantRef'] : nil payment_method = hash.key?('paymentMethod') ? hash['paymentMethod'] : nil brand_id = hash.key?('brand_id') ? hash['brand_id'] : nil payment_type = hash.key?('payment_type') ? hash['payment_type'] : nil mandate = Mandate.from_hash(hash['mandate']) if hash['mandate'] success_redirect = hash.key?('success_redirect') ? hash['success_redirect'] : nil pending_redirect = hash.key?('pending_redirect') ? hash['pending_redirect'] : nil failure_redirect = hash.key?('failure_redirect') ? hash['failure_redirect'] : nil success_callback = hash.key?('success_callback') ? hash['success_callback'] : nil failure_callback = hash.key?('failure_callback') ? hash['failure_callback'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreatePurchaseCitRequest.new(client: client, purchase: purchase, merchant_ref: merchant_ref, payment_method: payment_method, brand_id: brand_id, payment_type: payment_type, mandate: mandate, success_redirect: success_redirect, pending_redirect: pending_redirect, failure_redirect: failure_redirect, success_callback: success_callback, failure_callback: failure_callback, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 61 def self.names @_hash = {} if @_hash.nil? @_hash['client'] = 'client' @_hash['purchase'] = 'purchase' @_hash['merchant_ref'] = 'merchantRef' @_hash['payment_method'] = 'paymentMethod' @_hash['brand_id'] = 'brand_id' @_hash['payment_type'] = 'payment_type' @_hash['mandate'] = 'mandate' @_hash['success_redirect'] = 'success_redirect' @_hash['pending_redirect'] = 'pending_redirect' @_hash['failure_redirect'] = 'failure_redirect' @_hash['success_callback'] = 'success_callback' @_hash['failure_callback'] = 'failure_callback' @_hash end |
.nullables ⇒ Object
An array for nullable fields
84 85 86 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 84 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
79 80 81 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 79 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
168 169 170 171 172 173 174 175 176 177 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 168 def inspect class_name = self.class.name.split('::').last "<#{class_name} client: #{@client.inspect}, purchase: #{@purchase.inspect}, merchant_ref:"\ " #{@merchant_ref.inspect}, payment_method: #{@payment_method.inspect}, brand_id:"\ " #{@brand_id.inspect}, payment_type: #{@payment_type.inspect}, mandate:"\ " #{@mandate.inspect}, success_redirect: #{@success_redirect.inspect}, pending_redirect:"\ " #{@pending_redirect.inspect}, failure_redirect: #{@failure_redirect.inspect},"\ " success_callback: #{@success_callback.inspect}, failure_callback:"\ " #{@failure_callback.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
157 158 159 160 161 162 163 164 165 |
# File 'lib/paysecure_api_documentation_live/models/create_purchase_cit_request.rb', line 157 def to_s class_name = self.class.name.split('::').last "<#{class_name} client: #{@client}, purchase: #{@purchase}, merchant_ref: #{@merchant_ref},"\ " payment_method: #{@payment_method}, brand_id: #{@brand_id}, payment_type:"\ " #{@payment_type}, mandate: #{@mandate}, success_redirect: #{@success_redirect},"\ " pending_redirect: #{@pending_redirect}, failure_redirect: #{@failure_redirect},"\ " success_callback: #{@success_callback}, failure_callback: #{@failure_callback},"\ " additional_properties: #{@additional_properties}>" end |