Class: PaysecureApiDocumentationLive::Data13
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Data13
- Defined in:
- lib/paysecure_api_documentation_live/models/data13.rb
Overview
Data13 Model.
Instance Attribute Summary collapse
-
#email ⇒ String
TODO: Write general description for this method.
-
#merchant_id ⇒ Integer
TODO: Write general description for this method.
-
#username ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(merchant_id:, username:, email:, additional_properties: nil) ⇒ Data13
constructor
A new instance of Data13.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(merchant_id:, username:, email:, additional_properties: nil) ⇒ Data13
Returns a new instance of Data13.
45 46 47 48 49 50 51 52 53 |
# File 'lib/paysecure_api_documentation_live/models/data13.rb', line 45 def initialize(merchant_id:, username:, email:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @merchant_id = merchant_id @username = username @email = email @additional_properties = additional_properties end |
Instance Attribute Details
#email ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/data13.rb', line 22 def email @email end |
#merchant_id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/data13.rb', line 14 def merchant_id @merchant_id end |
#username ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/data13.rb', line 18 def username @username end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/data13.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. merchant_id = hash.key?('merchantId') ? hash['merchantId'] : nil username = hash.key?('username') ? hash['username'] : nil email = hash.key?('email') ? hash['email'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Data13.new(merchant_id: merchant_id, username: username, email: email, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/data13.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['merchant_id'] = 'merchantId' @_hash['username'] = 'username' @_hash['email'] = 'email' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 42 43 |
# File 'lib/paysecure_api_documentation_live/models/data13.rb', line 39 def self.nullables %w[ email ] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/data13.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/paysecure_api_documentation_live/models/data13.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} merchant_id: #{@merchant_id.inspect}, username: #{@username.inspect},"\ " email: #{@email.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/paysecure_api_documentation_live/models/data13.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} merchant_id: #{@merchant_id}, username: #{@username}, email: #{@email},"\ " additional_properties: #{@additional_properties}>" end |