Class: PaysecureApiDocumentationLive::Data16
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Data16
- Defined in:
- lib/paysecure_api_documentation_live/models/data16.rb
Overview
Data16 Model.
Instance Attribute Summary collapse
-
#account_no ⇒ String
TODO: Write general description for this method.
-
#country ⇒ String
TODO: Write general description for this method.
-
#created_on ⇒ Integer
TODO: Write general description for this method.
-
#currency ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(country:, currency:, status:, account_no:, created_on:, additional_properties: nil) ⇒ Data16
constructor
A new instance of Data16.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(country:, currency:, status:, account_no:, created_on:, additional_properties: nil) ⇒ Data16
Returns a new instance of Data16.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 53 def initialize(country:, currency:, status:, account_no:, created_on:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @country = country @currency = currency @status = status @account_no = account_no @created_on = created_on @additional_properties = additional_properties end |
Instance Attribute Details
#account_no ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 26 def account_no @account_no end |
#country ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 14 def country @country end |
#created_on ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 30 def created_on @created_on end |
#currency ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 18 def currency @currency end |
#status ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 22 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. country = hash.key?('country') ? hash['country'] : nil currency = hash.key?('currency') ? hash['currency'] : nil status = hash.key?('status') ? hash['status'] : nil account_no = hash.key?('accountNo') ? hash['accountNo'] : nil created_on = hash.key?('createdOn') ? hash['createdOn'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Data16.new(country: country, currency: currency, status: status, account_no: account_no, created_on: created_on, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['country'] = 'country' @_hash['currency'] = 'currency' @_hash['status'] = 'status' @_hash['account_no'] = 'accountNo' @_hash['created_on'] = 'createdOn' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 107 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} country: #{@country.inspect}, currency: #{@currency.inspect}, status:"\ " #{@status.inspect}, account_no: #{@account_no.inspect}, created_on:"\ " #{@created_on.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 99 |
# File 'lib/paysecure_api_documentation_live/models/data16.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} country: #{@country}, currency: #{@currency}, status: #{@status},"\ " account_no: #{@account_no}, created_on: #{@created_on}, additional_properties:"\ " #{@additional_properties}>" end |