Class: PaysecureApiDocumentationLive::Data4
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Data4
- Defined in:
- lib/paysecure_api_documentation_live/models/data4.rb
Overview
Data4 Model.
Instance Attribute Summary collapse
-
#merchant ⇒ Array[Merchant]
TODO: Write general description for this method.
-
#pagination ⇒ Pagination
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(merchant:, pagination:, additional_properties: nil) ⇒ Data4
constructor
A new instance of Data4.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(merchant:, pagination:, additional_properties: nil) ⇒ Data4
Returns a new instance of Data4.
38 39 40 41 42 43 44 45 |
# File 'lib/paysecure_api_documentation_live/models/data4.rb', line 38 def initialize(merchant:, pagination:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @merchant = merchant @pagination = pagination @additional_properties = additional_properties end |
Instance Attribute Details
#merchant ⇒ Array[Merchant]
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/data4.rb', line 14 def merchant @merchant end |
#pagination ⇒ Pagination
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/data4.rb', line 18 def pagination @pagination end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/paysecure_api_documentation_live/models/data4.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it merchant = nil unless hash['merchant'].nil? merchant = [] hash['merchant'].each do |structure| merchant << (Merchant.from_hash(structure) if structure) end end merchant = nil unless hash.key?('merchant') pagination = Pagination.from_hash(hash['pagination']) if hash['pagination'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Data4.new(merchant: merchant, pagination: pagination, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/paysecure_api_documentation_live/models/data4.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['merchant'] = 'merchant' @_hash['pagination'] = 'pagination' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/data4.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/data4.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/paysecure_api_documentation_live/models/data4.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} merchant: #{@merchant.inspect}, pagination: #{@pagination.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/paysecure_api_documentation_live/models/data4.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} merchant: #{@merchant}, pagination: #{@pagination}, additional_properties:"\ " #{@additional_properties}>" end |