Class: PaysecureApiDocumentationLive::Data8

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/data8.rb

Overview

Data8 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(merchant_id:, api_key:, is_sandbox:, additional_properties: nil) ⇒ Data8

Returns a new instance of Data8.



43
44
45
46
47
48
49
50
51
52
# File 'lib/paysecure_api_documentation_live/models/data8.rb', line 43

def initialize(merchant_id:, api_key:, is_sandbox:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @merchant_id = merchant_id
  @api_key = api_key
  @is_sandbox = is_sandbox
  @additional_properties = additional_properties
end

Instance Attribute Details

#api_keyString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/data8.rb', line 18

def api_key
  @api_key
end

#is_sandboxTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/data8.rb', line 22

def is_sandbox
  @is_sandbox
end

#merchant_idInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/data8.rb', line 14

def merchant_id
  @merchant_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/paysecure_api_documentation_live/models/data8.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  merchant_id = hash.key?('merchantId') ? hash['merchantId'] : nil
  api_key = hash.key?('apiKey') ? hash['apiKey'] : nil
  is_sandbox = hash.key?('isSandbox') ? hash['isSandbox'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Data8.new(merchant_id: merchant_id,
            api_key: api_key,
            is_sandbox: is_sandbox,
            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/paysecure_api_documentation_live/models/data8.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['merchant_id'] = 'merchantId'
  @_hash['api_key'] = 'apiKey'
  @_hash['is_sandbox'] = 'isSandbox'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/paysecure_api_documentation_live/models/data8.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/paysecure_api_documentation_live/models/data8.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/paysecure_api_documentation_live/models/data8.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant_id: #{@merchant_id.inspect}, api_key: #{@api_key.inspect},"\
  " is_sandbox: #{@is_sandbox.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/paysecure_api_documentation_live/models/data8.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant_id: #{@merchant_id}, api_key: #{@api_key}, is_sandbox:"\
  " #{@is_sandbox}, additional_properties: #{@additional_properties}>"
end