Class: PaysecureApiDocumentationLive::ExtraParam

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/extra_param.rb

Overview

ExtraParam Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(card_number:, card_holder_name:, expiry_year:, expiry_month:, additional_properties: nil) ⇒ ExtraParam

Returns a new instance of ExtraParam.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/paysecure_api_documentation_live/models/extra_param.rb', line 48

def initialize(card_number:, card_holder_name:, expiry_year:, expiry_month:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @card_number = card_number
  @card_holder_name = card_holder_name
  @expiry_year = expiry_year
  @expiry_month = expiry_month
  @additional_properties = additional_properties
end

Instance Attribute Details

#card_holder_nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/extra_param.rb', line 18

def card_holder_name
  @card_holder_name
end

#card_numberString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/extra_param.rb', line 14

def card_number
  @card_number
end

#expiry_monthString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/extra_param.rb', line 26

def expiry_month
  @expiry_month
end

#expiry_yearString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/extra_param.rb', line 22

def expiry_year
  @expiry_year
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/paysecure_api_documentation_live/models/extra_param.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  card_number = hash.key?('cardNumber') ? hash['cardNumber'] : nil
  card_holder_name =
    hash.key?('cardHolderName') ? hash['cardHolderName'] : nil
  expiry_year = hash.key?('expiryYear') ? hash['expiryYear'] : nil
  expiry_month = hash.key?('expiryMonth') ? hash['expiryMonth'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ExtraParam.new(card_number: card_number,
                 card_holder_name: card_holder_name,
                 expiry_year: expiry_year,
                 expiry_month: expiry_month,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/paysecure_api_documentation_live/models/extra_param.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['card_number'] = 'cardNumber'
  @_hash['card_holder_name'] = 'cardHolderName'
  @_hash['expiry_year'] = 'expiryYear'
  @_hash['expiry_month'] = 'expiryMonth'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/paysecure_api_documentation_live/models/extra_param.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/paysecure_api_documentation_live/models/extra_param.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
100
# File 'lib/paysecure_api_documentation_live/models/extra_param.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} card_number: #{@card_number.inspect}, card_holder_name:"\
  " #{@card_holder_name.inspect}, expiry_year: #{@expiry_year.inspect}, expiry_month:"\
  " #{@expiry_month.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
92
# File 'lib/paysecure_api_documentation_live/models/extra_param.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} card_number: #{@card_number}, card_holder_name: #{@card_holder_name},"\
  " expiry_year: #{@expiry_year}, expiry_month: #{@expiry_month}, additional_properties:"\
  " #{@additional_properties}>"
end