Class: PaysecureApiDocumentationLive::ExtraParam20
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::ExtraParam20
- Defined in:
- lib/paysecure_api_documentation_live/models/extra_param20.rb
Overview
ExtraParam20 Model.
Instance Attribute Summary collapse
-
#crypto_currencies ⇒ String
TODO: Write general description for this method.
-
#param1 ⇒ String
TODO: Write general description for this method.
-
#param3 ⇒ String
TODO: Write general description for this method.
-
#param4 ⇒ String
TODO: Write general description for this method.
-
#show_crypto_conversion ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(param1:, show_crypto_conversion:, crypto_currencies:, param3:, param4:, additional_properties: nil) ⇒ ExtraParam20
constructor
A new instance of ExtraParam20.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(param1:, show_crypto_conversion:, crypto_currencies:, param3:, param4:, additional_properties: nil) ⇒ ExtraParam20
Returns a new instance of ExtraParam20.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 53 def initialize(param1:, show_crypto_conversion:, crypto_currencies:, param3:, param4:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @param1 = param1 @show_crypto_conversion = show_crypto_conversion @crypto_currencies = crypto_currencies @param3 = param3 @param4 = param4 @additional_properties = additional_properties end |
Instance Attribute Details
#crypto_currencies ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 22 def crypto_currencies @crypto_currencies end |
#param1 ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 14 def param1 @param1 end |
#param3 ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 26 def param3 @param3 end |
#param4 ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 30 def param4 @param4 end |
#show_crypto_conversion ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 18 def show_crypto_conversion @show_crypto_conversion end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. param1 = hash.key?('param1') ? hash['param1'] : nil show_crypto_conversion = hash.key?('showCryptoConversion') ? hash['showCryptoConversion'] : nil crypto_currencies = hash.key?('cryptoCurrencies') ? hash['cryptoCurrencies'] : nil param3 = hash.key?('param3') ? hash['param3'] : nil param4 = hash.key?('param4') ? hash['param4'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ExtraParam20.new(param1: param1, show_crypto_conversion: show_crypto_conversion, crypto_currencies: crypto_currencies, param3: param3, param4: param4, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['param1'] = 'param1' @_hash['show_crypto_conversion'] = 'showCryptoConversion' @_hash['crypto_currencies'] = 'cryptoCurrencies' @_hash['param3'] = 'param3' @_hash['param4'] = 'param4' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 110 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} param1: #{@param1.inspect}, show_crypto_conversion:"\ " #{@show_crypto_conversion.inspect}, crypto_currencies: #{@crypto_currencies.inspect},"\ " param3: #{@param3.inspect}, param4: #{@param4.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 101 |
# File 'lib/paysecure_api_documentation_live/models/extra_param20.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} param1: #{@param1}, show_crypto_conversion: #{@show_crypto_conversion},"\ " crypto_currencies: #{@crypto_currencies}, param3: #{@param3}, param4: #{@param4},"\ " additional_properties: #{@additional_properties}>" end |