Class: PaysecureApiDocumentationLive::ExtraParam7
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::ExtraParam7
- Defined in:
- lib/paysecure_api_documentation_live/models/extra_param7.rb
Overview
ExtraParam7 Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
TODO: Write general description for this method.
-
#bank_name ⇒ String
TODO: Write general description for this method.
-
#pay_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(pay_id:, bank_name:, account_name:, additional_properties: nil) ⇒ ExtraParam7
constructor
A new instance of ExtraParam7.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(pay_id:, bank_name:, account_name:, additional_properties: nil) ⇒ ExtraParam7
Returns a new instance of ExtraParam7.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/extra_param7.rb', line 43 def initialize(pay_id:, bank_name:, account_name:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @pay_id = pay_id @bank_name = bank_name @account_name = account_name @additional_properties = additional_properties end |
Instance Attribute Details
#account_name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/extra_param7.rb', line 22 def account_name @account_name end |
#bank_name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/extra_param7.rb', line 18 def bank_name @bank_name end |
#pay_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/extra_param7.rb', line 14 def pay_id @pay_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/paysecure_api_documentation_live/models/extra_param7.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. pay_id = hash.key?('payId') ? hash['payId'] : nil bank_name = hash.key?('bankName') ? hash['bankName'] : nil account_name = hash.key?('accountName') ? hash['accountName'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ExtraParam7.new(pay_id: pay_id, bank_name: bank_name, account_name: account_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/extra_param7.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['pay_id'] = 'payId' @_hash['bank_name'] = 'bankName' @_hash['account_name'] = 'accountName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/extra_param7.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/extra_param7.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/paysecure_api_documentation_live/models/extra_param7.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} pay_id: #{@pay_id.inspect}, bank_name: #{@bank_name.inspect}, account_name:"\ " #{@account_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/paysecure_api_documentation_live/models/extra_param7.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} pay_id: #{@pay_id}, bank_name: #{@bank_name}, account_name:"\ " #{@account_name}, additional_properties: #{@additional_properties}>" end |