Class: PaysecureApiDocumentationLive::Fee

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/fee.rb

Overview

Fee Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type:, amount:, currency:, additional_properties: nil) ⇒ Fee

Returns a new instance of Fee.



43
44
45
46
47
48
49
50
51
# File 'lib/paysecure_api_documentation_live/models/fee.rb', line 43

def initialize(type:, amount:, currency:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type
  @amount = amount
  @currency = currency
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountObject

TODO: Write general description for this method

Returns:

  • (Object)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/fee.rb', line 18

def amount
  @amount
end

#currencyString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/fee.rb', line 22

def currency
  @currency
end

#typeString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/fee.rb', line 14

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/paysecure_api_documentation_live/models/fee.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : nil
  amount = hash.key?('amount') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:FeeAmount), hash['amount']
  ) : nil
  currency = hash.key?('currency') ? hash['currency'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Fee.new(type: type,
          amount: amount,
          currency: currency,
          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/paysecure_api_documentation_live/models/fee.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['amount'] = 'amount'
  @_hash['currency'] = 'currency'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/paysecure_api_documentation_live/models/fee.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/paysecure_api_documentation_live/models/fee.rb', line 34

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Fee | Hash)

    value against the validation is performed.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/paysecure_api_documentation_live/models/fee.rb', line 80

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.type,
                            ->(val) { val.instance_of? String }) and
        UnionTypeLookUp.get(:FeeAmount)
                       .validate(value.amount) and
        APIHelper.valid_type?(value.currency,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['type'],
                          ->(val) { val.instance_of? String }) and
      UnionTypeLookUp.get(:FeeAmount)
                     .validate(value['amount']) and
      APIHelper.valid_type?(value['currency'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



112
113
114
115
116
# File 'lib/paysecure_api_documentation_live/models/fee.rb', line 112

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, amount: #{@amount.inspect}, currency:"\
  " #{@currency.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



105
106
107
108
109
# File 'lib/paysecure_api_documentation_live/models/fee.rb', line 105

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, amount: #{@amount}, currency: #{@currency},"\
  " additional_properties: #{@additional_properties}>"
end