Class: PaysecureApiDocumentationLive::Gateway
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Gateway
- Defined in:
- lib/paysecure_api_documentation_live/models/gateway.rb
Overview
Gateway Model.
Instance Attribute Summary collapse
-
#balances ⇒ Array[Balance]
TODO: Write general description for this method.
-
#error ⇒ String
TODO: Write general description for this method.
-
#gateway_name ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(gateway_name:, status:, error:, balances:, additional_properties: nil) ⇒ Gateway
constructor
A new instance of Gateway.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(gateway_name:, status:, error:, balances:, additional_properties: nil) ⇒ Gateway
Returns a new instance of Gateway.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/paysecure_api_documentation_live/models/gateway.rb', line 50 def initialize(gateway_name:, status:, error:, balances:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @gateway_name = gateway_name @status = status @error = error @balances = balances @additional_properties = additional_properties end |
Instance Attribute Details
#balances ⇒ Array[Balance]
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/gateway.rb', line 26 def balances @balances end |
#error ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/gateway.rb', line 22 def error @error end |
#gateway_name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/gateway.rb', line 14 def gateway_name @gateway_name end |
#status ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/gateway.rb', line 18 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/paysecure_api_documentation_live/models/gateway.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. gateway_name = hash.key?('gatewayName') ? hash['gatewayName'] : nil status = hash.key?('status') ? hash['status'] : nil error = hash.key?('error') ? hash['error'] : nil # Parameter is an array, so we need to iterate through it balances = nil unless hash['balances'].nil? balances = [] hash['balances'].each do |structure| balances << (Balance.from_hash(structure) if structure) end end balances = nil unless hash.key?('balances') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Gateway.new(gateway_name: gateway_name, status: status, error: error, balances: balances, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/gateway.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['gateway_name'] = 'gatewayName' @_hash['status'] = 'status' @_hash['error'] = 'error' @_hash['balances'] = 'balances' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/gateway.rb', line 44 def self.nullables %w[ error ] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/gateway.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/paysecure_api_documentation_live/models/gateway.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} gateway_name: #{@gateway_name.inspect}, status: #{@status.inspect}, error:"\ " #{@error.inspect}, balances: #{@balances.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
97 98 99 100 101 |
# File 'lib/paysecure_api_documentation_live/models/gateway.rb', line 97 def to_s class_name = self.class.name.split('::').last "<#{class_name} gateway_name: #{@gateway_name}, status: #{@status}, error: #{@error},"\ " balances: #{@balances}, additional_properties: #{@additional_properties}>" end |