Class: PaysecureApiDocumentationLive::Gateway1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/gateway1.rb

Overview

Gateway1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(gateway_name:, status:, error:, balances:, additional_properties: nil) ⇒ Gateway1

Returns a new instance of Gateway1.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 48

def initialize(gateway_name:, status:, error:, balances:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @gateway_name = gateway_name
  @status = status
  @error = error
  @balances = balances
  @additional_properties = additional_properties
end

Instance Attribute Details

#balancesArray[Object]

TODO: Write general description for this method

Returns:

  • (Array[Object])


26
27
28
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 26

def balances
  @balances
end

#errorObject

TODO: Write general description for this method

Returns:

  • (Object)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 22

def error
  @error
end

#gateway_nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 14

def gateway_name
  @gateway_name
end

#statusString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 18

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  gateway_name = hash.key?('gatewayName') ? hash['gatewayName'] : nil
  status = hash.key?('status') ? hash['status'] : nil
  error = hash.key?('error') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:Gateway1Error), hash['error']
  ) : nil
  balances = hash.key?('balances') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:Gateway1Balances), hash['balances']
  ) : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Gateway1.new(gateway_name: gateway_name,
               status: status,
               error: error,
               balances: balances,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['gateway_name'] = 'gatewayName'
  @_hash['status'] = 'status'
  @_hash['error'] = 'error'
  @_hash['balances'] = 'balances'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 39

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Gateway1 | Hash)

    value against the validation is performed.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 91

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.gateway_name,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.status,
                              ->(val) { val.instance_of? String }) and
        UnionTypeLookUp.get(:Gateway1Error)
                       .validate(value.error) and
        UnionTypeLookUp.get(:Gateway1Balances)
                       .validate(value.balances)
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['gatewayName'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['status'],
                            ->(val) { val.instance_of? String }) and
      UnionTypeLookUp.get(:Gateway1Error)
                     .validate(value['error']) and
      UnionTypeLookUp.get(:Gateway1Balances)
                     .validate(value['balances'])
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



127
128
129
130
131
132
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 127

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} gateway_name: #{@gateway_name.inspect}, status: #{@status.inspect}, error:"\
  " #{@error.inspect}, balances: #{@balances.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



120
121
122
123
124
# File 'lib/paysecure_api_documentation_live/models/gateway1.rb', line 120

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} gateway_name: #{@gateway_name}, status: #{@status}, error: #{@error},"\
  " balances: #{@balances}, additional_properties: #{@additional_properties}>"
end