Class: PaysecureApiDocumentationLive::Gateway2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Gateway2
- Defined in:
- lib/paysecure_api_documentation_live/models/gateway2.rb
Overview
Gateway2 Model.
Instance Attribute Summary collapse
-
#balances ⇒ Array[String]
TODO: Write general description for this method.
-
#error ⇒ Error
TODO: Write general description for this method.
-
#gateway_name ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(gateway_name:, status:, error:, balances:, additional_properties: nil) ⇒ Gateway2
constructor
A new instance of Gateway2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(gateway_name:, status:, error:, balances:, additional_properties: nil) ⇒ Gateway2
Returns a new instance of Gateway2.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/paysecure_api_documentation_live/models/gateway2.rb', line 48 def initialize(gateway_name:, status:, error:, balances:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @gateway_name = gateway_name @status = status @error = error @balances = balances @additional_properties = additional_properties end |
Instance Attribute Details
#balances ⇒ Array[String]
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/gateway2.rb', line 26 def balances @balances end |
#error ⇒ Error
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/gateway2.rb', line 22 def error @error end |
#gateway_name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/gateway2.rb', line 14 def gateway_name @gateway_name end |
#status ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/gateway2.rb', line 18 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/paysecure_api_documentation_live/models/gateway2.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. gateway_name = hash.key?('gatewayName') ? hash['gatewayName'] : nil status = hash.key?('status') ? hash['status'] : nil error = Error.from_hash(hash['error']) if hash['error'] balances = hash.key?('balances') ? hash['balances'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Gateway2.new(gateway_name: gateway_name, status: status, error: error, balances: balances, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/gateway2.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['gateway_name'] = 'gatewayName' @_hash['status'] = 'status' @_hash['error'] = 'error' @_hash['balances'] = 'balances' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/gateway2.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/gateway2.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/paysecure_api_documentation_live/models/gateway2.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} gateway_name: #{@gateway_name.inspect}, status: #{@status.inspect}, error:"\ " #{@error.inspect}, balances: #{@balances.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/paysecure_api_documentation_live/models/gateway2.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} gateway_name: #{@gateway_name}, status: #{@status}, error: #{@error},"\ " balances: #{@balances}, additional_properties: #{@additional_properties}>" end |