Class: PaysecureApiDocumentationLive::GlobalCollectionApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/apis/global_collection_api.rb

Overview

GlobalCollectionApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from PaysecureApiDocumentationLive::BaseApi

Instance Method Details

#bulk_update_invoice_no(request_id, body) ⇒ ApiResponse

TODO: type endpoint description here here type description here

Parameters:

  • request_id (String)

    Required parameter: TODO: type description

  • body (Array[BulkUpdateInvoiceNoRequest])

    Required parameter: TODO:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 360

def bulk_update_invoice_no(request_id,
                           body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PATCH,
                                 '/api/v1/external/gc/partner/transactions/invoice',
                                 Server::SERVER_3)
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json; charset=utf-8', key: 'content-type'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(BulkUpdateInvoiceNo.method(:from_hash))
                .is_api_response(true))
    .execute
end

#create_brand_id(request_id, body) ⇒ ApiResponse

TODO: type endpoint description here here description here

Parameters:

  • request_id (Integer)

    Required parameter: TODO: type description

  • body (CreateBrandIdRequest)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 262

def create_brand_id(request_id,
                    body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/v1/external/gc/partner/merchant/4230/brand',
                                 Server::SERVER_3)
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json; charset=utf-8', key: 'content-type'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CreateBrandId.method(:from_hash))
                .is_api_response(true))
    .execute
end

#create_merchant_api(request_id, body) ⇒ ApiResponse

TODO: type endpoint description here here description here

Parameters:

  • request_id (String)

    Required parameter: TODO: type description

  • body (CreateMerchantApiRequest)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 68

def create_merchant_api(request_id,
                        body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/v1/external/gc/partner/merchant',
                                 Server::SERVER_3)
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json; charset=utf-8', key: 'content-type'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CreateMerchantApi.method(:from_hash))
                .is_api_response(true))
    .execute
end

#create_merchant_api_token(request_id, body) ⇒ ApiResponse

TODO: type endpoint description here here description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 122

def create_merchant_api_token(request_id,
                              body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/v1/external/gc/partner/merchant/4230/api-key',
                                 Server::SERVER_3)
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json; charset=utf-8', key: 'content-type'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CreateMerchantApiToken.method(:from_hash))
                .is_api_response(true))
    .execute
end

#delete_brand_id(brand_id, request_id) ⇒ ApiResponse

TODO: type endpoint description here here

Parameters:

  • brand_id (String)

    Required parameter: TODO: type description here

  • request_id (Integer)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 288

def delete_brand_id(brand_id,
                    request_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/api/v1/external/gc/partner/merchant/4230/brand',
                                 Server::SERVER_3)
               .query_param(new_parameter(brand_id, key: 'brandId')
                             .is_required(true))
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DeleteBrandId.method(:from_hash))
                .is_api_response(true))
    .execute
end

#delete_merchant_api(merchant_id, request_id) ⇒ ApiResponse

TODO: type endpoint description here here here

Parameters:

  • merchant_id (Integer)

    Required parameter: TODO: type description

  • request_id (Integer)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 43

def delete_merchant_api(merchant_id,
                        request_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/api/v1/external/gc/partner/merchant',
                                 Server::SERVER_3)
               .query_param(new_parameter(merchant_id, key: 'merchantId')
                             .is_required(true))
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DeleteMerchantApi.method(:from_hash))
                .is_api_response(true))
    .execute
end

#delete_merchant_token(token, request_id) ⇒ ApiResponse

TODO: type endpoint description here here

Parameters:

  • token (String)

    Required parameter: TODO: type description here

  • request_id (Integer)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 237

def delete_merchant_token(token,
                          request_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/api/v1/external/gc/partner/merchant/4230/api-key',
                                 Server::SERVER_3)
               .query_param(new_parameter(token, key: 'token')
                             .is_required(true))
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DeleteMerchantToken.method(:from_hash))
                .is_api_response(true))
    .execute
end

#get_global_accounts(request_id) ⇒ ApiResponse

TODO: type endpoint description here here

Parameters:

  • request_id (Integer)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 338

def get_global_accounts(request_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/v1/external/gc/partner/merchant/4212/global-account',
                                 Server::SERVER_3)
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GetGlobalAccounts.method(:from_hash))
                .is_api_response(true))
    .execute
end

#get_merchants(page, size, request_id) ⇒ ApiResponse

TODO: type endpoint description here here

Parameters:

  • page (Integer)

    Required parameter: TODO: type description here

  • size (Integer)

    Required parameter: TODO: type description here

  • request_id (Integer)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 15

def get_merchants(page,
                  size,
                  request_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/v1/external/gc/partner/merchants',
                                 Server::SERVER_3)
               .query_param(new_parameter(page, key: 'page')
                             .is_required(true))
               .query_param(new_parameter(size, key: 'size')
                             .is_required(true))
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GetMerchants.method(:from_hash))
                .is_api_response(true))
    .execute
end

#get_missing_invoice_transactions(page, size, request_id) ⇒ ApiResponse

TODO: type endpoint description here here

Parameters:

  • page (Integer)

    Required parameter: TODO: type description here

  • size (Integer)

    Required parameter: TODO: type description here

  • request_id (Integer)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 169

def get_missing_invoice_transactions(page,
                                     size,
                                     request_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/v1/external/gc/partner/transactions/missing-invoice',
                                 Server::SERVER_3)
               .query_param(new_parameter(page, key: 'page')
                             .is_required(true))
               .query_param(new_parameter(size, key: 'size')
                             .is_required(true))
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GetMissingInvoiceTransactions.method(:from_hash))
                .is_api_response(true))
    .execute
end

#get_settlement_data(from_date, to_date, status, page_no, size, request_id) ⇒ ApiResponse

TODO: type endpoint description here here here

Parameters:

  • from_date (String)

    Required parameter: TODO: type description

  • to_date (String)

    Required parameter: TODO: type description here

  • status (String)

    Required parameter: TODO: type description here

  • page_no (Integer)

    Required parameter: TODO: type description here

  • size (Integer)

    Required parameter: TODO: type description here

  • request_id (Integer)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 201

def get_settlement_data(from_date,
                        to_date,
                        status,
                        page_no,
                        size,
                        request_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/v1/external/gc/partner/settlements',
                                 Server::SERVER_3)
               .query_param(new_parameter(from_date, key: 'fromDate')
                             .is_required(true))
               .query_param(new_parameter(to_date, key: 'toDate')
                             .is_required(true))
               .query_param(new_parameter(status, key: 'status')
                             .is_required(true))
               .query_param(new_parameter(page_no, key: 'pageNo')
                             .is_required(true))
               .query_param(new_parameter(size, key: 'size')
                             .is_required(true))
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GetSettlementData.method(:from_hash))
                .is_api_response(true))
    .execute
end

#get_single_merchant(request_id) ⇒ ApiResponse

TODO: type endpoint description here here

Parameters:

  • request_id (Integer)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 147

def get_single_merchant(request_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/v1/external/gc/partner/merchant/4230',
                                 Server::SERVER_3)
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GetSingleMerchant.method(:from_hash))
                .is_api_response(true))
    .execute
end

#request_global_account(request_id, body) ⇒ ApiResponse

TODO: type endpoint description here here description here

Parameters:

  • request_id (Integer)

    Required parameter: TODO: type description

  • body (RequestGlobalAccountRequest)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 313

def (request_id,
                           body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/v1/external/gc/partner/merchant/4230/global-account',
                                 Server::SERVER_3)
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json; charset=utf-8', key: 'content-type'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(RequestGlobalAccount.method(:from_hash))
                .is_api_response(true))
    .execute
end

#update_merchant(request_id, body) ⇒ ApiResponse

TODO: type endpoint description here here description here

Parameters:

  • request_id (Integer)

    Required parameter: TODO: type description

  • body (UpdateMerchantRequest)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/paysecure_api_documentation_live/apis/global_collection_api.rb', line 95

def update_merchant(request_id,
                    body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/api/v1/external/gc/partner/merchant/4230',
                                 Server::SERVER_3)
               .header_param(new_parameter(request_id, key: 'requestId')
                              .is_required(true))
               .body_param(new_parameter(body)
                            .is_required(true))
               .header_param(new_parameter('application/json; charset=utf-8', key: 'content-type'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('bearer')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(UpdateMerchant.method(:from_hash))
                .is_api_response(true))
    .execute
end