Class: PaysecureApiDocumentationLive::IssuerDetails11

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/issuer_details11.rb

Overview

IssuerDetails11 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(bank_accounts:, legal_name:, brand_name:, additional_properties: nil) ⇒ IssuerDetails11

Returns a new instance of IssuerDetails11.



43
44
45
46
47
48
49
50
51
52
# File 'lib/paysecure_api_documentation_live/models/issuer_details11.rb', line 43

def initialize(bank_accounts:, legal_name:, brand_name:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @bank_accounts = bank_accounts
  @legal_name = legal_name
  @brand_name = brand_name
  @additional_properties = additional_properties
end

Instance Attribute Details

#bank_accountsArray[BankAccount]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/paysecure_api_documentation_live/models/issuer_details11.rb', line 14

def bank_accounts
  @bank_accounts
end

#brand_nameString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/issuer_details11.rb', line 22

def brand_name
  @brand_name
end

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/issuer_details11.rb', line 18

def legal_name
  @legal_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/paysecure_api_documentation_live/models/issuer_details11.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  bank_accounts = nil
  unless hash['bank_accounts'].nil?
    bank_accounts = []
    hash['bank_accounts'].each do |structure|
      bank_accounts << (BankAccount.from_hash(structure) if structure)
    end
  end

  bank_accounts = nil unless hash.key?('bank_accounts')
  legal_name = hash.key?('legal_name') ? hash['legal_name'] : nil
  brand_name = hash.key?('brand_name') ? hash['brand_name'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IssuerDetails11.new(bank_accounts: bank_accounts,
                      legal_name: legal_name,
                      brand_name: brand_name,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/paysecure_api_documentation_live/models/issuer_details11.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['bank_accounts'] = 'bank_accounts'
  @_hash['legal_name'] = 'legal_name'
  @_hash['brand_name'] = 'brand_name'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/paysecure_api_documentation_live/models/issuer_details11.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/paysecure_api_documentation_live/models/issuer_details11.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
99
# File 'lib/paysecure_api_documentation_live/models/issuer_details11.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} bank_accounts: #{@bank_accounts.inspect}, legal_name:"\
  " #{@legal_name.inspect}, brand_name: #{@brand_name.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
# File 'lib/paysecure_api_documentation_live/models/issuer_details11.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} bank_accounts: #{@bank_accounts}, legal_name: #{@legal_name}, brand_name:"\
  " #{@brand_name}, additional_properties: #{@additional_properties}>"
end