Class: PaysecureApiDocumentationLive::M202Success
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::M202Success
- Defined in:
- lib/paysecure_api_documentation_live/models/m202_success.rb
Overview
M202Success Model.
Instance Attribute Summary collapse
-
#amount_unit ⇒ String
TODO: Write general description for this method.
-
#brand_id ⇒ String
TODO: Write general description for this method.
-
#cancel_redirect ⇒ String
TODO: Write general description for this method.
-
#cc_descriptor ⇒ String
TODO: Write general description for this method.
-
#checkout_url ⇒ String
TODO: Write general description for this method.
-
#client ⇒ Client70
TODO: Write general description for this method.
-
#created_on ⇒ Integer
TODO: Write general description for this method.
-
#direct_post_url ⇒ String
TODO: Write general description for this method.
-
#due ⇒ Integer
TODO: Write general description for this method.
-
#error_code ⇒ String
TODO: Write general description for this method.
-
#error_msg ⇒ String
TODO: Write general description for this method.
-
#extra_fee ⇒ String
TODO: Write general description for this method.
-
#failure_callback ⇒ String
TODO: Write general description for this method.
-
#failure_redirect ⇒ String
TODO: Write general description for this method.
-
#force_recurring ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#fraud_score ⇒ String
TODO: Write general description for this method.
-
#is_recurring_token ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#is_test ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#issued ⇒ String
TODO: Write general description for this method.
-
#issuer_details ⇒ IssuerDetails
TODO: Write general description for this method.
-
#merchant_name ⇒ String
TODO: Write general description for this method.
-
#merchant_ref ⇒ String
TODO: Write general description for this method.
-
#merchant_type ⇒ String
TODO: Write general description for this method.
-
#paid_on ⇒ Integer
TODO: Write general description for this method.
-
#payment_method ⇒ String
TODO: Write general description for this method.
-
#payout_process ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#pending_redirect ⇒ String
TODO: Write general description for this method.
-
#platform ⇒ String
TODO: Write general description for this method.
-
#purchase ⇒ Purchase1
TODO: Write general description for this method.
-
#purchase_id ⇒ String
TODO: Write general description for this method.
-
#received_amt ⇒ Float
TODO: Write general description for this method.
-
#redirect_type ⇒ String
TODO: Write general description for this method.
-
#reference_generated ⇒ String
TODO: Write general description for this method.
-
#refund_availability ⇒ String
TODO: Write general description for this method.
-
#refund_upto ⇒ Integer
TODO: Write general description for this method.
-
#refundable_amount ⇒ Float
TODO: Write general description for this method.
-
#saved_card_used ⇒ String
TODO: Write general description for this method.
-
#send_receipt ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#session_id ⇒ String
TODO: Write general description for this method.
-
#skip_capture ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
-
#status_history ⇒ Array[StatusHistory]
TODO: Write general description for this method.
-
#success_callback ⇒ String
TODO: Write general description for this method.
-
#success_redirect ⇒ String
TODO: Write general description for this method.
-
#surcharge ⇒ Float
TODO: Write general description for this method.
-
#surcharge_type ⇒ String
TODO: Write general description for this method.
-
#tax_amount ⇒ Float
TODO: Write general description for this method.
-
#transaction_data ⇒ TransactionData37
TODO: Write general description for this method.
-
#trust_score ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
-
#updated_on ⇒ Integer
TODO: Write general description for this method.
-
#viewed_on ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(purchase_id:, client:, updated_on:, type:, payment_method:, amount_unit:, error_msg:, error_code:, saved_card_used:, redirect_type:, force_recurring:, created_on:, merchant_ref:, merchant_name:, merchant_type:, purchase:, issuer_details:, transaction_data:, status:, status_history:, viewed_on:, is_test:, brand_id:, send_receipt:, is_recurring_token:, skip_capture:, reference_generated:, issued:, due:, refund_upto:, cc_descriptor:, fraud_score:, trust_score:, extra_fee:, paid_on:, received_amt:, tax_amount:, surcharge:, surcharge_type:, session_id:, refund_availability:, refundable_amount:, success_redirect:, failure_redirect:, pending_redirect:, cancel_redirect:, success_callback:, failure_callback:, platform:, checkout_url:, direct_post_url:, payout_process:, additional_properties: nil) ⇒ M202Success
constructor
A new instance of M202Success.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(purchase_id:, client:, updated_on:, type:, payment_method:, amount_unit:, error_msg:, error_code:, saved_card_used:, redirect_type:, force_recurring:, created_on:, merchant_ref:, merchant_name:, merchant_type:, purchase:, issuer_details:, transaction_data:, status:, status_history:, viewed_on:, is_test:, brand_id:, send_receipt:, is_recurring_token:, skip_capture:, reference_generated:, issued:, due:, refund_upto:, cc_descriptor:, fraud_score:, trust_score:, extra_fee:, paid_on:, received_amt:, tax_amount:, surcharge:, surcharge_type:, session_id:, refund_availability:, refundable_amount:, success_redirect:, failure_redirect:, pending_redirect:, cancel_redirect:, success_callback:, failure_callback:, platform:, checkout_url:, direct_post_url:, payout_process:, additional_properties: nil) ⇒ M202Success
Returns a new instance of M202Success.
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 288 def initialize(purchase_id:, client:, updated_on:, type:, payment_method:, amount_unit:, error_msg:, error_code:, saved_card_used:, redirect_type:, force_recurring:, created_on:, merchant_ref:, merchant_name:, merchant_type:, purchase:, issuer_details:, transaction_data:, status:, status_history:, viewed_on:, is_test:, brand_id:, send_receipt:, is_recurring_token:, skip_capture:, reference_generated:, issued:, due:, refund_upto:, cc_descriptor:, fraud_score:, trust_score:, extra_fee:, paid_on:, received_amt:, tax_amount:, surcharge:, surcharge_type:, session_id:, refund_availability:, refundable_amount:, success_redirect:, failure_redirect:, pending_redirect:, cancel_redirect:, success_callback:, failure_callback:, platform:, checkout_url:, direct_post_url:, payout_process:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @purchase_id = purchase_id @client = client @updated_on = updated_on @type = type @payment_method = payment_method @amount_unit = amount_unit @error_msg = error_msg @error_code = error_code @saved_card_used = saved_card_used @redirect_type = redirect_type @force_recurring = force_recurring @created_on = created_on @merchant_ref = merchant_ref @merchant_name = merchant_name @merchant_type = merchant_type @purchase = purchase @issuer_details = issuer_details @transaction_data = transaction_data @status = status @status_history = status_history @viewed_on = viewed_on @is_test = is_test @brand_id = brand_id @send_receipt = send_receipt @is_recurring_token = is_recurring_token @skip_capture = skip_capture @reference_generated = reference_generated @issued = issued @due = due @refund_upto = refund_upto @cc_descriptor = cc_descriptor @fraud_score = fraud_score @trust_score = trust_score @extra_fee = extra_fee @paid_on = paid_on @received_amt = received_amt @tax_amount = tax_amount @surcharge = surcharge @surcharge_type = surcharge_type @session_id = session_id @refund_availability = refund_availability @refundable_amount = refundable_amount @success_redirect = success_redirect @failure_redirect = failure_redirect @pending_redirect = pending_redirect @cancel_redirect = cancel_redirect @success_callback = success_callback @failure_callback = failure_callback @platform = platform @checkout_url = checkout_url @direct_post_url = direct_post_url @payout_process = payout_process @additional_properties = additional_properties end |
Instance Attribute Details
#amount_unit ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 34 def amount_unit @amount_unit end |
#brand_id ⇒ String
TODO: Write general description for this method
102 103 104 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 102 def brand_id @brand_id end |
#cancel_redirect ⇒ String
TODO: Write general description for this method
194 195 196 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 194 def cancel_redirect @cancel_redirect end |
#cc_descriptor ⇒ String
TODO: Write general description for this method
134 135 136 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 134 def cc_descriptor @cc_descriptor end |
#checkout_url ⇒ String
TODO: Write general description for this method
210 211 212 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 210 def checkout_url @checkout_url end |
#client ⇒ Client70
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 18 def client @client end |
#created_on ⇒ Integer
TODO: Write general description for this method
58 59 60 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 58 def created_on @created_on end |
#direct_post_url ⇒ String
TODO: Write general description for this method
214 215 216 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 214 def direct_post_url @direct_post_url end |
#due ⇒ Integer
TODO: Write general description for this method
126 127 128 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 126 def due @due end |
#error_code ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 42 def error_code @error_code end |
#error_msg ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 38 def error_msg @error_msg end |
#extra_fee ⇒ String
TODO: Write general description for this method
146 147 148 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 146 def extra_fee @extra_fee end |
#failure_callback ⇒ String
TODO: Write general description for this method
202 203 204 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 202 def failure_callback @failure_callback end |
#failure_redirect ⇒ String
TODO: Write general description for this method
186 187 188 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 186 def failure_redirect @failure_redirect end |
#force_recurring ⇒ TrueClass | FalseClass
TODO: Write general description for this method
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 54 def force_recurring @force_recurring end |
#fraud_score ⇒ String
TODO: Write general description for this method
138 139 140 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 138 def fraud_score @fraud_score end |
#is_recurring_token ⇒ TrueClass | FalseClass
TODO: Write general description for this method
110 111 112 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 110 def is_recurring_token @is_recurring_token end |
#is_test ⇒ TrueClass | FalseClass
TODO: Write general description for this method
98 99 100 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 98 def is_test @is_test end |
#issued ⇒ String
TODO: Write general description for this method
122 123 124 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 122 def issued @issued end |
#issuer_details ⇒ IssuerDetails
TODO: Write general description for this method
78 79 80 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 78 def issuer_details @issuer_details end |
#merchant_name ⇒ String
TODO: Write general description for this method
66 67 68 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 66 def merchant_name @merchant_name end |
#merchant_ref ⇒ String
TODO: Write general description for this method
62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 62 def merchant_ref @merchant_ref end |
#merchant_type ⇒ String
TODO: Write general description for this method
70 71 72 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 70 def merchant_type @merchant_type end |
#paid_on ⇒ Integer
TODO: Write general description for this method
150 151 152 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 150 def paid_on @paid_on end |
#payment_method ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 30 def payment_method @payment_method end |
#payout_process ⇒ TrueClass | FalseClass
TODO: Write general description for this method
218 219 220 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 218 def payout_process @payout_process end |
#pending_redirect ⇒ String
TODO: Write general description for this method
190 191 192 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 190 def pending_redirect @pending_redirect end |
#platform ⇒ String
TODO: Write general description for this method
206 207 208 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 206 def platform @platform end |
#purchase ⇒ Purchase1
TODO: Write general description for this method
74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 74 def purchase @purchase end |
#purchase_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 14 def purchase_id @purchase_id end |
#received_amt ⇒ Float
TODO: Write general description for this method
154 155 156 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 154 def received_amt @received_amt end |
#redirect_type ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 50 def redirect_type @redirect_type end |
#reference_generated ⇒ String
TODO: Write general description for this method
118 119 120 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 118 def reference_generated @reference_generated end |
#refund_availability ⇒ String
TODO: Write general description for this method
174 175 176 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 174 def refund_availability @refund_availability end |
#refund_upto ⇒ Integer
TODO: Write general description for this method
130 131 132 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 130 def refund_upto @refund_upto end |
#refundable_amount ⇒ Float
TODO: Write general description for this method
178 179 180 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 178 def refundable_amount @refundable_amount end |
#saved_card_used ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 46 def saved_card_used @saved_card_used end |
#send_receipt ⇒ TrueClass | FalseClass
TODO: Write general description for this method
106 107 108 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 106 def send_receipt @send_receipt end |
#session_id ⇒ String
TODO: Write general description for this method
170 171 172 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 170 def session_id @session_id end |
#skip_capture ⇒ TrueClass | FalseClass
TODO: Write general description for this method
114 115 116 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 114 def skip_capture @skip_capture end |
#status ⇒ String
TODO: Write general description for this method
86 87 88 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 86 def status @status end |
#status_history ⇒ Array[StatusHistory]
TODO: Write general description for this method
90 91 92 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 90 def status_history @status_history end |
#success_callback ⇒ String
TODO: Write general description for this method
198 199 200 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 198 def success_callback @success_callback end |
#success_redirect ⇒ String
TODO: Write general description for this method
182 183 184 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 182 def success_redirect @success_redirect end |
#surcharge ⇒ Float
TODO: Write general description for this method
162 163 164 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 162 def surcharge @surcharge end |
#surcharge_type ⇒ String
TODO: Write general description for this method
166 167 168 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 166 def surcharge_type @surcharge_type end |
#tax_amount ⇒ Float
TODO: Write general description for this method
158 159 160 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 158 def tax_amount @tax_amount end |
#transaction_data ⇒ TransactionData37
TODO: Write general description for this method
82 83 84 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 82 def transaction_data @transaction_data end |
#trust_score ⇒ String
TODO: Write general description for this method
142 143 144 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 142 def trust_score @trust_score end |
#type ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 26 def type @type end |
#updated_on ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 22 def updated_on @updated_on end |
#viewed_on ⇒ Integer
TODO: Write general description for this method
94 95 96 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 94 def viewed_on @viewed_on end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 362 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. purchase_id = hash.key?('purchaseId') ? hash['purchaseId'] : nil client = Client70.from_hash(hash['client']) if hash['client'] updated_on = hash.key?('updated_on') ? hash['updated_on'] : nil type = hash.key?('type') ? hash['type'] : nil payment_method = hash.key?('paymentMethod') ? hash['paymentMethod'] : nil amount_unit = hash.key?('amountUnit') ? hash['amountUnit'] : nil error_msg = hash.key?('errorMsg') ? hash['errorMsg'] : nil error_code = hash.key?('errorCode') ? hash['errorCode'] : nil saved_card_used = hash.key?('savedCardUsed') ? hash['savedCardUsed'] : nil redirect_type = hash.key?('redirectType') ? hash['redirectType'] : nil force_recurring = hash.key?('force_recurring') ? hash['force_recurring'] : nil created_on = hash.key?('created_on') ? hash['created_on'] : nil merchant_ref = hash.key?('merchantRef') ? hash['merchantRef'] : nil merchant_name = hash.key?('merchantName') ? hash['merchantName'] : nil merchant_type = hash.key?('merchantType') ? hash['merchantType'] : nil purchase = Purchase1.from_hash(hash['purchase']) if hash['purchase'] issuer_details = IssuerDetails.from_hash(hash['issuer_details']) if hash['issuer_details'] transaction_data = TransactionData37.from_hash(hash['transaction_data']) if hash['transaction_data'] status = hash.key?('status') ? hash['status'] : nil # Parameter is an array, so we need to iterate through it status_history = nil unless hash['status_history'].nil? status_history = [] hash['status_history'].each do |structure| status_history << (StatusHistory.from_hash(structure) if structure) end end status_history = nil unless hash.key?('status_history') viewed_on = hash.key?('viewedOn') ? hash['viewedOn'] : nil is_test = hash.key?('is_test') ? hash['is_test'] : nil brand_id = hash.key?('brand_id') ? hash['brand_id'] : nil send_receipt = hash.key?('send_receipt') ? hash['send_receipt'] : nil is_recurring_token = hash.key?('is_recurring_token') ? hash['is_recurring_token'] : nil skip_capture = hash.key?('skip_capture') ? hash['skip_capture'] : nil reference_generated = hash.key?('reference_generated') ? hash['reference_generated'] : nil issued = hash.key?('issued') ? hash['issued'] : nil due = hash.key?('due') ? hash['due'] : nil refund_upto = hash.key?('refund_upto') ? hash['refund_upto'] : nil cc_descriptor = hash.key?('cc_descriptor') ? hash['cc_descriptor'] : nil fraud_score = hash.key?('fraudScore') ? hash['fraudScore'] : nil trust_score = hash.key?('trustScore') ? hash['trustScore'] : nil extra_fee = hash.key?('extraFee') ? hash['extraFee'] : nil paid_on = hash.key?('paidOn') ? hash['paidOn'] : nil received_amt = hash.key?('receivedAmt') ? hash['receivedAmt'] : nil tax_amount = hash.key?('taxAmount') ? hash['taxAmount'] : nil surcharge = hash.key?('surcharge') ? hash['surcharge'] : nil surcharge_type = hash.key?('surchargeType') ? hash['surchargeType'] : nil session_id = hash.key?('sessionId') ? hash['sessionId'] : nil refund_availability = hash.key?('refund_availability') ? hash['refund_availability'] : nil refundable_amount = hash.key?('refundable_amount') ? hash['refundable_amount'] : nil success_redirect = hash.key?('success_redirect') ? hash['success_redirect'] : nil failure_redirect = hash.key?('failure_redirect') ? hash['failure_redirect'] : nil pending_redirect = hash.key?('pending_redirect') ? hash['pending_redirect'] : nil cancel_redirect = hash.key?('cancel_redirect') ? hash['cancel_redirect'] : nil success_callback = hash.key?('success_callback') ? hash['success_callback'] : nil failure_callback = hash.key?('failure_callback') ? hash['failure_callback'] : nil platform = hash.key?('platform') ? hash['platform'] : nil checkout_url = hash.key?('checkout_url') ? hash['checkout_url'] : nil direct_post_url = hash.key?('direct_post_url') ? hash['direct_post_url'] : nil payout_process = hash.key?('payoutProcess') ? hash['payoutProcess'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. M202Success.new(purchase_id: purchase_id, client: client, updated_on: updated_on, type: type, payment_method: payment_method, amount_unit: amount_unit, error_msg: error_msg, error_code: error_code, saved_card_used: saved_card_used, redirect_type: redirect_type, force_recurring: force_recurring, created_on: created_on, merchant_ref: merchant_ref, merchant_name: merchant_name, merchant_type: merchant_type, purchase: purchase, issuer_details: issuer_details, transaction_data: transaction_data, status: status, status_history: status_history, viewed_on: viewed_on, is_test: is_test, brand_id: brand_id, send_receipt: send_receipt, is_recurring_token: is_recurring_token, skip_capture: skip_capture, reference_generated: reference_generated, issued: issued, due: due, refund_upto: refund_upto, cc_descriptor: cc_descriptor, fraud_score: fraud_score, trust_score: trust_score, extra_fee: extra_fee, paid_on: paid_on, received_amt: received_amt, tax_amount: tax_amount, surcharge: surcharge, surcharge_type: surcharge_type, session_id: session_id, refund_availability: refund_availability, refundable_amount: refundable_amount, success_redirect: success_redirect, failure_redirect: failure_redirect, pending_redirect: pending_redirect, cancel_redirect: cancel_redirect, success_callback: success_callback, failure_callback: failure_callback, platform: platform, checkout_url: checkout_url, direct_post_url: direct_post_url, payout_process: payout_process, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 221 def self.names @_hash = {} if @_hash.nil? @_hash['purchase_id'] = 'purchaseId' @_hash['client'] = 'client' @_hash['updated_on'] = 'updated_on' @_hash['type'] = 'type' @_hash['payment_method'] = 'paymentMethod' @_hash['amount_unit'] = 'amountUnit' @_hash['error_msg'] = 'errorMsg' @_hash['error_code'] = 'errorCode' @_hash['saved_card_used'] = 'savedCardUsed' @_hash['redirect_type'] = 'redirectType' @_hash['force_recurring'] = 'force_recurring' @_hash['created_on'] = 'created_on' @_hash['merchant_ref'] = 'merchantRef' @_hash['merchant_name'] = 'merchantName' @_hash['merchant_type'] = 'merchantType' @_hash['purchase'] = 'purchase' @_hash['issuer_details'] = 'issuer_details' @_hash['transaction_data'] = 'transaction_data' @_hash['status'] = 'status' @_hash['status_history'] = 'status_history' @_hash['viewed_on'] = 'viewedOn' @_hash['is_test'] = 'is_test' @_hash['brand_id'] = 'brand_id' @_hash['send_receipt'] = 'send_receipt' @_hash['is_recurring_token'] = 'is_recurring_token' @_hash['skip_capture'] = 'skip_capture' @_hash['reference_generated'] = 'reference_generated' @_hash['issued'] = 'issued' @_hash['due'] = 'due' @_hash['refund_upto'] = 'refund_upto' @_hash['cc_descriptor'] = 'cc_descriptor' @_hash['fraud_score'] = 'fraudScore' @_hash['trust_score'] = 'trustScore' @_hash['extra_fee'] = 'extraFee' @_hash['paid_on'] = 'paidOn' @_hash['received_amt'] = 'receivedAmt' @_hash['tax_amount'] = 'taxAmount' @_hash['surcharge'] = 'surcharge' @_hash['surcharge_type'] = 'surchargeType' @_hash['session_id'] = 'sessionId' @_hash['refund_availability'] = 'refund_availability' @_hash['refundable_amount'] = 'refundable_amount' @_hash['success_redirect'] = 'success_redirect' @_hash['failure_redirect'] = 'failure_redirect' @_hash['pending_redirect'] = 'pending_redirect' @_hash['cancel_redirect'] = 'cancel_redirect' @_hash['success_callback'] = 'success_callback' @_hash['failure_callback'] = 'failure_callback' @_hash['platform'] = 'platform' @_hash['checkout_url'] = 'checkout_url' @_hash['direct_post_url'] = 'direct_post_url' @_hash['payout_process'] = 'payoutProcess' @_hash end |
.nullables ⇒ Object
An array for nullable fields
284 285 286 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 284 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
279 280 281 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 279 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 531 def inspect class_name = self.class.name.split('::').last "<#{class_name} purchase_id: #{@purchase_id.inspect}, client: #{@client.inspect},"\ " updated_on: #{@updated_on.inspect}, type: #{@type.inspect}, payment_method:"\ " #{@payment_method.inspect}, amount_unit: #{@amount_unit.inspect}, error_msg:"\ " #{@error_msg.inspect}, error_code: #{@error_code.inspect}, saved_card_used:"\ " #{@saved_card_used.inspect}, redirect_type: #{@redirect_type.inspect}, force_recurring:"\ " #{@force_recurring.inspect}, created_on: #{@created_on.inspect}, merchant_ref:"\ " #{@merchant_ref.inspect}, merchant_name: #{@merchant_name.inspect}, merchant_type:"\ " #{@merchant_type.inspect}, purchase: #{@purchase.inspect}, issuer_details:"\ " #{@issuer_details.inspect}, transaction_data: #{@transaction_data.inspect}, status:"\ " #{@status.inspect}, status_history: #{@status_history.inspect}, viewed_on:"\ " #{@viewed_on.inspect}, is_test: #{@is_test.inspect}, brand_id: #{@brand_id.inspect},"\ " send_receipt: #{@send_receipt.inspect}, is_recurring_token:"\ " #{@is_recurring_token.inspect}, skip_capture: #{@skip_capture.inspect},"\ " reference_generated: #{@reference_generated.inspect}, issued: #{@issued.inspect}, due:"\ " #{@due.inspect}, refund_upto: #{@refund_upto.inspect}, cc_descriptor:"\ " #{@cc_descriptor.inspect}, fraud_score: #{@fraud_score.inspect}, trust_score:"\ " #{@trust_score.inspect}, extra_fee: #{@extra_fee.inspect}, paid_on: #{@paid_on.inspect},"\ " received_amt: #{@received_amt.inspect}, tax_amount: #{@tax_amount.inspect}, surcharge:"\ " #{@surcharge.inspect}, surcharge_type: #{@surcharge_type.inspect}, session_id:"\ " #{@session_id.inspect}, refund_availability: #{@refund_availability.inspect},"\ " refundable_amount: #{@refundable_amount.inspect}, success_redirect:"\ " #{@success_redirect.inspect}, failure_redirect: #{@failure_redirect.inspect},"\ " pending_redirect: #{@pending_redirect.inspect}, cancel_redirect:"\ " #{@cancel_redirect.inspect}, success_callback: #{@success_callback.inspect},"\ " failure_callback: #{@failure_callback.inspect}, platform: #{@platform.inspect},"\ " checkout_url: #{@checkout_url.inspect}, direct_post_url: #{@direct_post_url.inspect},"\ " payout_process: #{@payout_process.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/paysecure_api_documentation_live/models/m202_success.rb', line 505 def to_s class_name = self.class.name.split('::').last "<#{class_name} purchase_id: #{@purchase_id}, client: #{@client}, updated_on:"\ " #{@updated_on}, type: #{@type}, payment_method: #{@payment_method}, amount_unit:"\ " #{@amount_unit}, error_msg: #{@error_msg}, error_code: #{@error_code}, saved_card_used:"\ " #{@saved_card_used}, redirect_type: #{@redirect_type}, force_recurring:"\ " #{@force_recurring}, created_on: #{@created_on}, merchant_ref: #{@merchant_ref},"\ " merchant_name: #{@merchant_name}, merchant_type: #{@merchant_type}, purchase:"\ " #{@purchase}, issuer_details: #{@issuer_details}, transaction_data: #{@transaction_data},"\ " status: #{@status}, status_history: #{@status_history}, viewed_on: #{@viewed_on}, is_test:"\ " #{@is_test}, brand_id: #{@brand_id}, send_receipt: #{@send_receipt}, is_recurring_token:"\ " #{@is_recurring_token}, skip_capture: #{@skip_capture}, reference_generated:"\ " #{@reference_generated}, issued: #{@issued}, due: #{@due}, refund_upto: #{@refund_upto},"\ " cc_descriptor: #{@cc_descriptor}, fraud_score: #{@fraud_score}, trust_score:"\ " #{@trust_score}, extra_fee: #{@extra_fee}, paid_on: #{@paid_on}, received_amt:"\ " #{@received_amt}, tax_amount: #{@tax_amount}, surcharge: #{@surcharge}, surcharge_type:"\ " #{@surcharge_type}, session_id: #{@session_id}, refund_availability:"\ " #{@refund_availability}, refundable_amount: #{@refundable_amount}, success_redirect:"\ " #{@success_redirect}, failure_redirect: #{@failure_redirect}, pending_redirect:"\ " #{@pending_redirect}, cancel_redirect: #{@cancel_redirect}, success_callback:"\ " #{@success_callback}, failure_callback: #{@failure_callback}, platform: #{@platform},"\ " checkout_url: #{@checkout_url}, direct_post_url: #{@direct_post_url}, payout_process:"\ " #{@payout_process}, additional_properties: #{@additional_properties}>" end |