Class: PaysecureApiDocumentationLive::OptionalInput

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/optional_input.rb

Overview

OptionalInput Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(last_bets:, last_wins:, total_bonuses:, last_real_bets:, last_real_wins:, total_deposits:, last_bonus_bets:, last_bonus_wins:, average_real_bet:, last_bets_amount:, last_wins_amount:, average_bonus_bet:, bonus_to_deposits:, last_deposit_date:, total_withdrawals:, is_phone_confirmed:, money_in_money_out:, last_deposit_amount:, last_freespins_date:, last_freespins_name:, last_free_bonus_date:, last_free_bonus_name:, total_bonuses_amount:, last_freespins_amount:, last_freespins_status:, last_real_bets_amount:, last_real_wins_amount:, total_deposits_amount:, last_bonus_bets_amount:, last_bonus_wins_amount:, last_free_bonus_amount:, last_free_bonus_status:, last_deposit_bonus_date:, last_deposit_bonus_name:, last_freespins_currency:, last_freespins_wagering:, withdrawals_to_deposits:, last_free_bonus_currency:, last_free_bonus_wagering:, total_withdrawals_amount:, withdrawal_ewallet_email:, last_deposit_bonus_amount:, last_deposit_bonus_status:, last_deposit_bonus_currency:, last_deposit_bonus_wagering:, session:, payment_mode:, card_fullname:, card_bin:, card_hash:, card_last:, card_expire:, avs_result:, cvv_result:, sca_method:, user_bank_account:, user_bank_name:, user_balance:, user_verification_level:, status_3d:, regulation:, payment_provider:, phone_number:, transaction_type:, transaction_amount:, transaction_currency:, merchant_id:, details_url:, name:, person_type:, gender:, additional_properties: nil) ⇒ OptionalInput

Returns a new instance of OptionalInput.



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 385

def initialize(last_bets:, last_wins:, total_bonuses:, last_real_bets:,
               last_real_wins:, total_deposits:, last_bonus_bets:,
               last_bonus_wins:, average_real_bet:, last_bets_amount:,
               last_wins_amount:, average_bonus_bet:, bonus_to_deposits:,
               last_deposit_date:, total_withdrawals:, is_phone_confirmed:,
               money_in_money_out:, last_deposit_amount:,
               last_freespins_date:, last_freespins_name:,
               last_free_bonus_date:, last_free_bonus_name:,
               total_bonuses_amount:, last_freespins_amount:,
               last_freespins_status:, last_real_bets_amount:,
               last_real_wins_amount:, total_deposits_amount:,
               last_bonus_bets_amount:, last_bonus_wins_amount:,
               last_free_bonus_amount:, last_free_bonus_status:,
               last_deposit_bonus_date:, last_deposit_bonus_name:,
               last_freespins_currency:, last_freespins_wagering:,
               withdrawals_to_deposits:, last_free_bonus_currency:,
               last_free_bonus_wagering:, total_withdrawals_amount:,
               withdrawal_ewallet_email:, last_deposit_bonus_amount:,
               last_deposit_bonus_status:, last_deposit_bonus_currency:,
               last_deposit_bonus_wagering:, session:, payment_mode:,
               card_fullname:, card_bin:, card_hash:, card_last:,
               card_expire:, avs_result:, cvv_result:, sca_method:,
               user_bank_account:, user_bank_name:, user_balance:,
               user_verification_level:, status_3d:, regulation:,
               payment_provider:, phone_number:, transaction_type:,
               transaction_amount:, transaction_currency:, merchant_id:,
               details_url:, name:, person_type:, gender:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @last_bets = last_bets
  @last_wins = last_wins
  @total_bonuses = total_bonuses
  @last_real_bets = last_real_bets
  @last_real_wins = last_real_wins
  @total_deposits = total_deposits
  @last_bonus_bets = last_bonus_bets
  @last_bonus_wins = last_bonus_wins
  @average_real_bet = average_real_bet
  @last_bets_amount = last_bets_amount
  @last_wins_amount = last_wins_amount
  @average_bonus_bet = average_bonus_bet
  @bonus_to_deposits = bonus_to_deposits
  @last_deposit_date = last_deposit_date
  @total_withdrawals = total_withdrawals
  @is_phone_confirmed = is_phone_confirmed
  @money_in_money_out = money_in_money_out
  @last_deposit_amount = last_deposit_amount
  @last_freespins_date = last_freespins_date
  @last_freespins_name = last_freespins_name
  @last_free_bonus_date = last_free_bonus_date
  @last_free_bonus_name = last_free_bonus_name
  @total_bonuses_amount = total_bonuses_amount
  @last_freespins_amount = last_freespins_amount
  @last_freespins_status = last_freespins_status
  @last_real_bets_amount = last_real_bets_amount
  @last_real_wins_amount = last_real_wins_amount
  @total_deposits_amount = total_deposits_amount
  @last_bonus_bets_amount = last_bonus_bets_amount
  @last_bonus_wins_amount = last_bonus_wins_amount
  @last_free_bonus_amount = last_free_bonus_amount
  @last_free_bonus_status = last_free_bonus_status
  @last_deposit_bonus_date = last_deposit_bonus_date
  @last_deposit_bonus_name = last_deposit_bonus_name
  @last_freespins_currency = last_freespins_currency
  @last_freespins_wagering = last_freespins_wagering
  @withdrawals_to_deposits = withdrawals_to_deposits
  @last_free_bonus_currency = last_free_bonus_currency
  @last_free_bonus_wagering = last_free_bonus_wagering
  @total_withdrawals_amount = total_withdrawals_amount
  @withdrawal_ewallet_email = withdrawal_ewallet_email
  @last_deposit_bonus_amount = last_deposit_bonus_amount
  @last_deposit_bonus_status = last_deposit_bonus_status
  @last_deposit_bonus_currency = last_deposit_bonus_currency
  @last_deposit_bonus_wagering = last_deposit_bonus_wagering
  @session = session
  @payment_mode = payment_mode
  @card_fullname = card_fullname
  @card_bin = card_bin
  @card_hash = card_hash
  @card_last = card_last
  @card_expire = card_expire
  @avs_result = avs_result
  @cvv_result = cvv_result
  @sca_method = sca_method
  @user_bank_account = 
  @user_bank_name = user_bank_name
  @user_balance = user_balance
  @user_verification_level = user_verification_level
  @status_3d = status_3d
  @regulation = regulation
  @payment_provider = payment_provider
  @phone_number = phone_number
  @transaction_type = transaction_type
  @transaction_amount = transaction_amount
  @transaction_currency = transaction_currency
  @merchant_id = merchant_id
  @details_url = details_url
  @name = name
  @person_type = person_type
  @gender = gender
  @additional_properties = additional_properties
end

Instance Attribute Details

#average_bonus_betString

TODO: Write general description for this method

Returns:

  • (String)


58
59
60
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 58

def average_bonus_bet
  @average_bonus_bet
end

#average_real_betString

TODO: Write general description for this method

Returns:

  • (String)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 46

def average_real_bet
  @average_real_bet
end

#avs_resultString

TODO: Write general description for this method

Returns:

  • (String)


222
223
224
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 222

def avs_result
  @avs_result
end

#bonus_to_depositsString

TODO: Write general description for this method

Returns:

  • (String)


62
63
64
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 62

def bonus_to_deposits
  @bonus_to_deposits
end

#card_binString

TODO: Write general description for this method

Returns:

  • (String)


206
207
208
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 206

def card_bin
  @card_bin
end

#card_expireString

TODO: Write general description for this method

Returns:

  • (String)


218
219
220
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 218

def card_expire
  @card_expire
end

#card_fullnameString

TODO: Write general description for this method

Returns:

  • (String)


202
203
204
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 202

def card_fullname
  @card_fullname
end

#card_hashString

TODO: Write general description for this method

Returns:

  • (String)


210
211
212
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 210

def card_hash
  @card_hash
end

#card_lastString

TODO: Write general description for this method

Returns:

  • (String)


214
215
216
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 214

def card_last
  @card_last
end

#cvv_resultString

TODO: Write general description for this method

Returns:

  • (String)


226
227
228
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 226

def cvv_result
  @cvv_result
end

#details_urlString

TODO: Write general description for this method

Returns:

  • (String)


282
283
284
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 282

def details_url
  @details_url
end

#genderString

TODO: Write general description for this method

Returns:

  • (String)


294
295
296
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 294

def gender
  @gender
end

#is_phone_confirmedString

TODO: Write general description for this method

Returns:

  • (String)


74
75
76
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 74

def is_phone_confirmed
  @is_phone_confirmed
end

#last_betsString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 14

def last_bets
  @last_bets
end

#last_bets_amountString

TODO: Write general description for this method

Returns:

  • (String)


50
51
52
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 50

def last_bets_amount
  @last_bets_amount
end

#last_bonus_betsString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 38

def last_bonus_bets
  @last_bonus_bets
end

#last_bonus_bets_amountString

TODO: Write general description for this method

Returns:

  • (String)


126
127
128
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 126

def last_bonus_bets_amount
  @last_bonus_bets_amount
end

#last_bonus_winsString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 42

def last_bonus_wins
  @last_bonus_wins
end

#last_bonus_wins_amountString

TODO: Write general description for this method

Returns:

  • (String)


130
131
132
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 130

def last_bonus_wins_amount
  @last_bonus_wins_amount
end

#last_deposit_amountString

TODO: Write general description for this method

Returns:

  • (String)


82
83
84
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 82

def last_deposit_amount
  @last_deposit_amount
end

#last_deposit_bonus_amountString

TODO: Write general description for this method

Returns:

  • (String)


178
179
180
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 178

def last_deposit_bonus_amount
  @last_deposit_bonus_amount
end

#last_deposit_bonus_currencyString

TODO: Write general description for this method

Returns:

  • (String)


186
187
188
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 186

def last_deposit_bonus_currency
  @last_deposit_bonus_currency
end

#last_deposit_bonus_dateString

TODO: Write general description for this method

Returns:

  • (String)


142
143
144
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 142

def last_deposit_bonus_date
  @last_deposit_bonus_date
end

#last_deposit_bonus_nameString

TODO: Write general description for this method

Returns:

  • (String)


146
147
148
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 146

def last_deposit_bonus_name
  @last_deposit_bonus_name
end

#last_deposit_bonus_statusString

TODO: Write general description for this method

Returns:

  • (String)


182
183
184
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 182

def last_deposit_bonus_status
  @last_deposit_bonus_status
end

#last_deposit_bonus_wageringString

TODO: Write general description for this method

Returns:

  • (String)


190
191
192
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 190

def last_deposit_bonus_wagering
  @last_deposit_bonus_wagering
end

#last_deposit_dateString

TODO: Write general description for this method

Returns:

  • (String)


66
67
68
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 66

def last_deposit_date
  @last_deposit_date
end

#last_free_bonus_amountString

TODO: Write general description for this method

Returns:

  • (String)


134
135
136
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 134

def last_free_bonus_amount
  @last_free_bonus_amount
end

#last_free_bonus_currencyString

TODO: Write general description for this method

Returns:

  • (String)


162
163
164
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 162

def last_free_bonus_currency
  @last_free_bonus_currency
end

#last_free_bonus_dateString

TODO: Write general description for this method

Returns:

  • (String)


94
95
96
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 94

def last_free_bonus_date
  @last_free_bonus_date
end

#last_free_bonus_nameString

TODO: Write general description for this method

Returns:

  • (String)


98
99
100
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 98

def last_free_bonus_name
  @last_free_bonus_name
end

#last_free_bonus_statusString

TODO: Write general description for this method

Returns:

  • (String)


138
139
140
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 138

def last_free_bonus_status
  @last_free_bonus_status
end

#last_free_bonus_wageringString

TODO: Write general description for this method

Returns:

  • (String)


166
167
168
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 166

def last_free_bonus_wagering
  @last_free_bonus_wagering
end

#last_freespins_amountString

TODO: Write general description for this method

Returns:

  • (String)


106
107
108
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 106

def last_freespins_amount
  @last_freespins_amount
end

#last_freespins_currencyString

TODO: Write general description for this method

Returns:

  • (String)


150
151
152
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 150

def last_freespins_currency
  @last_freespins_currency
end

#last_freespins_dateString

TODO: Write general description for this method

Returns:

  • (String)


86
87
88
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 86

def last_freespins_date
  @last_freespins_date
end

#last_freespins_nameString

TODO: Write general description for this method

Returns:

  • (String)


90
91
92
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 90

def last_freespins_name
  @last_freespins_name
end

#last_freespins_statusString

TODO: Write general description for this method

Returns:

  • (String)


110
111
112
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 110

def last_freespins_status
  @last_freespins_status
end

#last_freespins_wageringString

TODO: Write general description for this method

Returns:

  • (String)


154
155
156
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 154

def last_freespins_wagering
  @last_freespins_wagering
end

#last_real_betsString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 26

def last_real_bets
  @last_real_bets
end

#last_real_bets_amountString

TODO: Write general description for this method

Returns:

  • (String)


114
115
116
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 114

def last_real_bets_amount
  @last_real_bets_amount
end

#last_real_winsString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 30

def last_real_wins
  @last_real_wins
end

#last_real_wins_amountString

TODO: Write general description for this method

Returns:

  • (String)


118
119
120
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 118

def last_real_wins_amount
  @last_real_wins_amount
end

#last_winsString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 18

def last_wins
  @last_wins
end

#last_wins_amountString

TODO: Write general description for this method

Returns:

  • (String)


54
55
56
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 54

def last_wins_amount
  @last_wins_amount
end

#merchant_idString

TODO: Write general description for this method

Returns:

  • (String)


278
279
280
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 278

def merchant_id
  @merchant_id
end

#money_in_money_outString

TODO: Write general description for this method

Returns:

  • (String)


78
79
80
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 78

def money_in_money_out
  @money_in_money_out
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


286
287
288
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 286

def name
  @name
end

#payment_modeString

TODO: Write general description for this method

Returns:

  • (String)


198
199
200
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 198

def payment_mode
  @payment_mode
end

#payment_providerString

TODO: Write general description for this method

Returns:

  • (String)


258
259
260
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 258

def payment_provider
  @payment_provider
end

#person_typeString

TODO: Write general description for this method

Returns:

  • (String)


290
291
292
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 290

def person_type
  @person_type
end

#phone_numberString

TODO: Write general description for this method

Returns:

  • (String)


262
263
264
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 262

def phone_number
  @phone_number
end

#regulationString

TODO: Write general description for this method

Returns:

  • (String)


254
255
256
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 254

def regulation
  @regulation
end

#sca_methodString

TODO: Write general description for this method

Returns:

  • (String)


230
231
232
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 230

def sca_method
  @sca_method
end

#sessionString

TODO: Write general description for this method

Returns:

  • (String)


194
195
196
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 194

def session
  @session
end

#status_3dString

TODO: Write general description for this method

Returns:

  • (String)


250
251
252
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 250

def status_3d
  @status_3d
end

#total_bonusesString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 22

def total_bonuses
  @total_bonuses
end

#total_bonuses_amountString

TODO: Write general description for this method

Returns:

  • (String)


102
103
104
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 102

def total_bonuses_amount
  @total_bonuses_amount
end

#total_depositsString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 34

def total_deposits
  @total_deposits
end

#total_deposits_amountString

TODO: Write general description for this method

Returns:

  • (String)


122
123
124
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 122

def total_deposits_amount
  @total_deposits_amount
end

#total_withdrawalsString

TODO: Write general description for this method

Returns:

  • (String)


70
71
72
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 70

def total_withdrawals
  @total_withdrawals
end

#total_withdrawals_amountString

TODO: Write general description for this method

Returns:

  • (String)


170
171
172
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 170

def total_withdrawals_amount
  @total_withdrawals_amount
end

#transaction_amountString

TODO: Write general description for this method

Returns:

  • (String)


270
271
272
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 270

def transaction_amount
  @transaction_amount
end

#transaction_currencyString

TODO: Write general description for this method

Returns:

  • (String)


274
275
276
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 274

def transaction_currency
  @transaction_currency
end

#transaction_typeString

TODO: Write general description for this method

Returns:

  • (String)


266
267
268
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 266

def transaction_type
  @transaction_type
end

#user_balanceString

TODO: Write general description for this method

Returns:

  • (String)


242
243
244
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 242

def user_balance
  @user_balance
end

#user_bank_accountString

TODO: Write general description for this method

Returns:

  • (String)


234
235
236
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 234

def 
  @user_bank_account
end

#user_bank_nameString

TODO: Write general description for this method

Returns:

  • (String)


238
239
240
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 238

def user_bank_name
  @user_bank_name
end

#user_verification_levelString

TODO: Write general description for this method

Returns:

  • (String)


246
247
248
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 246

def user_verification_level
  @user_verification_level
end

#withdrawal_ewallet_emailString

TODO: Write general description for this method

Returns:

  • (String)


174
175
176
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 174

def withdrawal_ewallet_email
  @withdrawal_ewallet_email
end

#withdrawals_to_depositsString

TODO: Write general description for this method

Returns:

  • (String)


158
159
160
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 158

def withdrawals_to_deposits
  @withdrawals_to_deposits
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 491

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  last_bets = hash.key?('last_bets') ? hash['last_bets'] : nil
  last_wins = hash.key?('last_wins') ? hash['last_wins'] : nil
  total_bonuses = hash.key?('total_bonuses') ? hash['total_bonuses'] : nil
  last_real_bets =
    hash.key?('last_real_bets') ? hash['last_real_bets'] : nil
  last_real_wins =
    hash.key?('last_real_wins') ? hash['last_real_wins'] : nil
  total_deposits =
    hash.key?('total_deposits') ? hash['total_deposits'] : nil
  last_bonus_bets =
    hash.key?('last_bonus_bets') ? hash['last_bonus_bets'] : nil
  last_bonus_wins =
    hash.key?('last_bonus_wins') ? hash['last_bonus_wins'] : nil
  average_real_bet =
    hash.key?('average_real_bet') ? hash['average_real_bet'] : nil
  last_bets_amount =
    hash.key?('last_bets_amount') ? hash['last_bets_amount'] : nil
  last_wins_amount =
    hash.key?('last_wins_amount') ? hash['last_wins_amount'] : nil
  average_bonus_bet =
    hash.key?('average_bonus_bet') ? hash['average_bonus_bet'] : nil
  bonus_to_deposits =
    hash.key?('bonus_to_deposits') ? hash['bonus_to_deposits'] : nil
  last_deposit_date =
    hash.key?('last_deposit_date') ? hash['last_deposit_date'] : nil
  total_withdrawals =
    hash.key?('total_withdrawals') ? hash['total_withdrawals'] : nil
  is_phone_confirmed =
    hash.key?('is_phone_confirmed') ? hash['is_phone_confirmed'] : nil
  money_in_money_out =
    hash.key?('money_in_money_out') ? hash['money_in_money_out'] : nil
  last_deposit_amount =
    hash.key?('last_deposit_amount') ? hash['last_deposit_amount'] : nil
  last_freespins_date =
    hash.key?('last_freespins_date') ? hash['last_freespins_date'] : nil
  last_freespins_name =
    hash.key?('last_freespins_name') ? hash['last_freespins_name'] : nil
  last_free_bonus_date =
    hash.key?('last_free_bonus_date') ? hash['last_free_bonus_date'] : nil
  last_free_bonus_name =
    hash.key?('last_free_bonus_name') ? hash['last_free_bonus_name'] : nil
  total_bonuses_amount =
    hash.key?('total_bonuses_amount') ? hash['total_bonuses_amount'] : nil
  last_freespins_amount =
    hash.key?('last_freespins_amount') ? hash['last_freespins_amount'] : nil
  last_freespins_status =
    hash.key?('last_freespins_status') ? hash['last_freespins_status'] : nil
  last_real_bets_amount =
    hash.key?('last_real_bets_amount') ? hash['last_real_bets_amount'] : nil
  last_real_wins_amount =
    hash.key?('last_real_wins_amount') ? hash['last_real_wins_amount'] : nil
  total_deposits_amount =
    hash.key?('total_deposits_amount') ? hash['total_deposits_amount'] : nil
  last_bonus_bets_amount =
    hash.key?('last_bonus_bets_amount') ? hash['last_bonus_bets_amount'] : nil
  last_bonus_wins_amount =
    hash.key?('last_bonus_wins_amount') ? hash['last_bonus_wins_amount'] : nil
  last_free_bonus_amount =
    hash.key?('last_free_bonus_amount') ? hash['last_free_bonus_amount'] : nil
  last_free_bonus_status =
    hash.key?('last_free_bonus_status') ? hash['last_free_bonus_status'] : nil
  last_deposit_bonus_date =
    hash.key?('last_deposit_bonus_date') ? hash['last_deposit_bonus_date'] : nil
  last_deposit_bonus_name =
    hash.key?('last_deposit_bonus_name') ? hash['last_deposit_bonus_name'] : nil
  last_freespins_currency =
    hash.key?('last_freespins_currency') ? hash['last_freespins_currency'] : nil
  last_freespins_wagering =
    hash.key?('last_freespins_wagering') ? hash['last_freespins_wagering'] : nil
  withdrawals_to_deposits =
    hash.key?('withdrawals_to_deposits') ? hash['withdrawals_to_deposits'] : nil
  last_free_bonus_currency =
    hash.key?('last_free_bonus_currency') ? hash['last_free_bonus_currency'] : nil
  last_free_bonus_wagering =
    hash.key?('last_free_bonus_wagering') ? hash['last_free_bonus_wagering'] : nil
  total_withdrawals_amount =
    hash.key?('total_withdrawals_amount') ? hash['total_withdrawals_amount'] : nil
  withdrawal_ewallet_email =
    hash.key?('withdrawal_ewallet_email') ? hash['withdrawal_ewallet_email'] : nil
  last_deposit_bonus_amount =
    hash.key?('last_deposit_bonus_amount') ? hash['last_deposit_bonus_amount'] : nil
  last_deposit_bonus_status =
    hash.key?('last_deposit_bonus_status') ? hash['last_deposit_bonus_status'] : nil
  last_deposit_bonus_currency =
    hash.key?('last_deposit_bonus_currency') ? hash['last_deposit_bonus_currency'] : nil
  last_deposit_bonus_wagering =
    hash.key?('last_deposit_bonus_wagering') ? hash['last_deposit_bonus_wagering'] : nil
  session = hash.key?('session') ? hash['session'] : nil
  payment_mode = hash.key?('payment_mode') ? hash['payment_mode'] : nil
  card_fullname = hash.key?('card_fullname') ? hash['card_fullname'] : nil
  card_bin = hash.key?('card_bin') ? hash['card_bin'] : nil
  card_hash = hash.key?('card_hash') ? hash['card_hash'] : nil
  card_last = hash.key?('card_last') ? hash['card_last'] : nil
  card_expire = hash.key?('card_expire') ? hash['card_expire'] : nil
  avs_result = hash.key?('avs_result') ? hash['avs_result'] : nil
  cvv_result = hash.key?('cvv_result') ? hash['cvv_result'] : nil
  sca_method = hash.key?('sca_method') ? hash['sca_method'] : nil
   =
    hash.key?('user_bank_account') ? hash['user_bank_account'] : nil
  user_bank_name =
    hash.key?('user_bank_name') ? hash['user_bank_name'] : nil
  user_balance = hash.key?('user_balance') ? hash['user_balance'] : nil
  user_verification_level =
    hash.key?('user_verification_level') ? hash['user_verification_level'] : nil
  status_3d = hash.key?('status_3d') ? hash['status_3d'] : nil
  regulation = hash.key?('regulation') ? hash['regulation'] : nil
  payment_provider =
    hash.key?('payment_provider') ? hash['payment_provider'] : nil
  phone_number = hash.key?('phone_number') ? hash['phone_number'] : nil
  transaction_type =
    hash.key?('transaction_type') ? hash['transaction_type'] : nil
  transaction_amount =
    hash.key?('transaction_amount') ? hash['transaction_amount'] : nil
  transaction_currency =
    hash.key?('transaction_currency') ? hash['transaction_currency'] : nil
  merchant_id = hash.key?('merchant_id') ? hash['merchant_id'] : nil
  details_url = hash.key?('details_url') ? hash['details_url'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  person_type = hash.key?('person_type') ? hash['person_type'] : nil
  gender = hash.key?('gender') ? hash['gender'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OptionalInput.new(last_bets: last_bets,
                    last_wins: last_wins,
                    total_bonuses: total_bonuses,
                    last_real_bets: last_real_bets,
                    last_real_wins: last_real_wins,
                    total_deposits: total_deposits,
                    last_bonus_bets: last_bonus_bets,
                    last_bonus_wins: last_bonus_wins,
                    average_real_bet: average_real_bet,
                    last_bets_amount: last_bets_amount,
                    last_wins_amount: last_wins_amount,
                    average_bonus_bet: average_bonus_bet,
                    bonus_to_deposits: bonus_to_deposits,
                    last_deposit_date: last_deposit_date,
                    total_withdrawals: total_withdrawals,
                    is_phone_confirmed: is_phone_confirmed,
                    money_in_money_out: money_in_money_out,
                    last_deposit_amount: last_deposit_amount,
                    last_freespins_date: last_freespins_date,
                    last_freespins_name: last_freespins_name,
                    last_free_bonus_date: last_free_bonus_date,
                    last_free_bonus_name: last_free_bonus_name,
                    total_bonuses_amount: total_bonuses_amount,
                    last_freespins_amount: last_freespins_amount,
                    last_freespins_status: last_freespins_status,
                    last_real_bets_amount: last_real_bets_amount,
                    last_real_wins_amount: last_real_wins_amount,
                    total_deposits_amount: total_deposits_amount,
                    last_bonus_bets_amount: last_bonus_bets_amount,
                    last_bonus_wins_amount: last_bonus_wins_amount,
                    last_free_bonus_amount: last_free_bonus_amount,
                    last_free_bonus_status: last_free_bonus_status,
                    last_deposit_bonus_date: last_deposit_bonus_date,
                    last_deposit_bonus_name: last_deposit_bonus_name,
                    last_freespins_currency: last_freespins_currency,
                    last_freespins_wagering: last_freespins_wagering,
                    withdrawals_to_deposits: withdrawals_to_deposits,
                    last_free_bonus_currency: last_free_bonus_currency,
                    last_free_bonus_wagering: last_free_bonus_wagering,
                    total_withdrawals_amount: total_withdrawals_amount,
                    withdrawal_ewallet_email: withdrawal_ewallet_email,
                    last_deposit_bonus_amount: last_deposit_bonus_amount,
                    last_deposit_bonus_status: last_deposit_bonus_status,
                    last_deposit_bonus_currency: last_deposit_bonus_currency,
                    last_deposit_bonus_wagering: last_deposit_bonus_wagering,
                    session: session,
                    payment_mode: payment_mode,
                    card_fullname: card_fullname,
                    card_bin: card_bin,
                    card_hash: card_hash,
                    card_last: card_last,
                    card_expire: card_expire,
                    avs_result: avs_result,
                    cvv_result: cvv_result,
                    sca_method: sca_method,
                    user_bank_account: ,
                    user_bank_name: user_bank_name,
                    user_balance: user_balance,
                    user_verification_level: user_verification_level,
                    status_3d: status_3d,
                    regulation: regulation,
                    payment_provider: payment_provider,
                    phone_number: phone_number,
                    transaction_type: transaction_type,
                    transaction_amount: transaction_amount,
                    transaction_currency: transaction_currency,
                    merchant_id: merchant_id,
                    details_url: details_url,
                    name: name,
                    person_type: person_type,
                    gender: gender,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 297

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['last_bets'] = 'last_bets'
  @_hash['last_wins'] = 'last_wins'
  @_hash['total_bonuses'] = 'total_bonuses'
  @_hash['last_real_bets'] = 'last_real_bets'
  @_hash['last_real_wins'] = 'last_real_wins'
  @_hash['total_deposits'] = 'total_deposits'
  @_hash['last_bonus_bets'] = 'last_bonus_bets'
  @_hash['last_bonus_wins'] = 'last_bonus_wins'
  @_hash['average_real_bet'] = 'average_real_bet'
  @_hash['last_bets_amount'] = 'last_bets_amount'
  @_hash['last_wins_amount'] = 'last_wins_amount'
  @_hash['average_bonus_bet'] = 'average_bonus_bet'
  @_hash['bonus_to_deposits'] = 'bonus_to_deposits'
  @_hash['last_deposit_date'] = 'last_deposit_date'
  @_hash['total_withdrawals'] = 'total_withdrawals'
  @_hash['is_phone_confirmed'] = 'is_phone_confirmed'
  @_hash['money_in_money_out'] = 'money_in_money_out'
  @_hash['last_deposit_amount'] = 'last_deposit_amount'
  @_hash['last_freespins_date'] = 'last_freespins_date'
  @_hash['last_freespins_name'] = 'last_freespins_name'
  @_hash['last_free_bonus_date'] = 'last_free_bonus_date'
  @_hash['last_free_bonus_name'] = 'last_free_bonus_name'
  @_hash['total_bonuses_amount'] = 'total_bonuses_amount'
  @_hash['last_freespins_amount'] = 'last_freespins_amount'
  @_hash['last_freespins_status'] = 'last_freespins_status'
  @_hash['last_real_bets_amount'] = 'last_real_bets_amount'
  @_hash['last_real_wins_amount'] = 'last_real_wins_amount'
  @_hash['total_deposits_amount'] = 'total_deposits_amount'
  @_hash['last_bonus_bets_amount'] = 'last_bonus_bets_amount'
  @_hash['last_bonus_wins_amount'] = 'last_bonus_wins_amount'
  @_hash['last_free_bonus_amount'] = 'last_free_bonus_amount'
  @_hash['last_free_bonus_status'] = 'last_free_bonus_status'
  @_hash['last_deposit_bonus_date'] = 'last_deposit_bonus_date'
  @_hash['last_deposit_bonus_name'] = 'last_deposit_bonus_name'
  @_hash['last_freespins_currency'] = 'last_freespins_currency'
  @_hash['last_freespins_wagering'] = 'last_freespins_wagering'
  @_hash['withdrawals_to_deposits'] = 'withdrawals_to_deposits'
  @_hash['last_free_bonus_currency'] = 'last_free_bonus_currency'
  @_hash['last_free_bonus_wagering'] = 'last_free_bonus_wagering'
  @_hash['total_withdrawals_amount'] = 'total_withdrawals_amount'
  @_hash['withdrawal_ewallet_email'] = 'withdrawal_ewallet_email'
  @_hash['last_deposit_bonus_amount'] = 'last_deposit_bonus_amount'
  @_hash['last_deposit_bonus_status'] = 'last_deposit_bonus_status'
  @_hash['last_deposit_bonus_currency'] = 'last_deposit_bonus_currency'
  @_hash['last_deposit_bonus_wagering'] = 'last_deposit_bonus_wagering'
  @_hash['session'] = 'session'
  @_hash['payment_mode'] = 'payment_mode'
  @_hash['card_fullname'] = 'card_fullname'
  @_hash['card_bin'] = 'card_bin'
  @_hash['card_hash'] = 'card_hash'
  @_hash['card_last'] = 'card_last'
  @_hash['card_expire'] = 'card_expire'
  @_hash['avs_result'] = 'avs_result'
  @_hash['cvv_result'] = 'cvv_result'
  @_hash['sca_method'] = 'sca_method'
  @_hash['user_bank_account'] = 'user_bank_account'
  @_hash['user_bank_name'] = 'user_bank_name'
  @_hash['user_balance'] = 'user_balance'
  @_hash['user_verification_level'] = 'user_verification_level'
  @_hash['status_3d'] = 'status_3d'
  @_hash['regulation'] = 'regulation'
  @_hash['payment_provider'] = 'payment_provider'
  @_hash['phone_number'] = 'phone_number'
  @_hash['transaction_type'] = 'transaction_type'
  @_hash['transaction_amount'] = 'transaction_amount'
  @_hash['transaction_currency'] = 'transaction_currency'
  @_hash['merchant_id'] = 'merchant_id'
  @_hash['details_url'] = 'details_url'
  @_hash['name'] = 'name'
  @_hash['person_type'] = 'person_type'
  @_hash['gender'] = 'gender'
  @_hash
end

.nullablesObject

An array for nullable fields



379
380
381
382
383
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 379

def self.nullables
  %w[
    last_bets
  ]
end

.optionalsObject

An array for optional fields



374
375
376
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 374

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 741

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} last_bets: #{@last_bets.inspect}, last_wins: #{@last_wins.inspect},"\
  " total_bonuses: #{@total_bonuses.inspect}, last_real_bets: #{@last_real_bets.inspect},"\
  " last_real_wins: #{@last_real_wins.inspect}, total_deposits: #{@total_deposits.inspect},"\
  " last_bonus_bets: #{@last_bonus_bets.inspect}, last_bonus_wins:"\
  " #{@last_bonus_wins.inspect}, average_real_bet: #{@average_real_bet.inspect},"\
  " last_bets_amount: #{@last_bets_amount.inspect}, last_wins_amount:"\
  " #{@last_wins_amount.inspect}, average_bonus_bet: #{@average_bonus_bet.inspect},"\
  " bonus_to_deposits: #{@bonus_to_deposits.inspect}, last_deposit_date:"\
  " #{@last_deposit_date.inspect}, total_withdrawals: #{@total_withdrawals.inspect},"\
  " is_phone_confirmed: #{@is_phone_confirmed.inspect}, money_in_money_out:"\
  " #{@money_in_money_out.inspect}, last_deposit_amount: #{@last_deposit_amount.inspect},"\
  " last_freespins_date: #{@last_freespins_date.inspect}, last_freespins_name:"\
  " #{@last_freespins_name.inspect}, last_free_bonus_date: #{@last_free_bonus_date.inspect},"\
  " last_free_bonus_name: #{@last_free_bonus_name.inspect}, total_bonuses_amount:"\
  " #{@total_bonuses_amount.inspect}, last_freespins_amount:"\
  " #{@last_freespins_amount.inspect}, last_freespins_status:"\
  " #{@last_freespins_status.inspect}, last_real_bets_amount:"\
  " #{@last_real_bets_amount.inspect}, last_real_wins_amount:"\
  " #{@last_real_wins_amount.inspect}, total_deposits_amount:"\
  " #{@total_deposits_amount.inspect}, last_bonus_bets_amount:"\
  " #{@last_bonus_bets_amount.inspect}, last_bonus_wins_amount:"\
  " #{@last_bonus_wins_amount.inspect}, last_free_bonus_amount:"\
  " #{@last_free_bonus_amount.inspect}, last_free_bonus_status:"\
  " #{@last_free_bonus_status.inspect}, last_deposit_bonus_date:"\
  " #{@last_deposit_bonus_date.inspect}, last_deposit_bonus_name:"\
  " #{@last_deposit_bonus_name.inspect}, last_freespins_currency:"\
  " #{@last_freespins_currency.inspect}, last_freespins_wagering:"\
  " #{@last_freespins_wagering.inspect}, withdrawals_to_deposits:"\
  " #{@withdrawals_to_deposits.inspect}, last_free_bonus_currency:"\
  " #{@last_free_bonus_currency.inspect}, last_free_bonus_wagering:"\
  " #{@last_free_bonus_wagering.inspect}, total_withdrawals_amount:"\
  " #{@total_withdrawals_amount.inspect}, withdrawal_ewallet_email:"\
  " #{@withdrawal_ewallet_email.inspect}, last_deposit_bonus_amount:"\
  " #{@last_deposit_bonus_amount.inspect}, last_deposit_bonus_status:"\
  " #{@last_deposit_bonus_status.inspect}, last_deposit_bonus_currency:"\
  " #{@last_deposit_bonus_currency.inspect}, last_deposit_bonus_wagering:"\
  " #{@last_deposit_bonus_wagering.inspect}, session: #{@session.inspect}, payment_mode:"\
  " #{@payment_mode.inspect}, card_fullname: #{@card_fullname.inspect}, card_bin:"\
  " #{@card_bin.inspect}, card_hash: #{@card_hash.inspect}, card_last: #{@card_last.inspect},"\
  " card_expire: #{@card_expire.inspect}, avs_result: #{@avs_result.inspect}, cvv_result:"\
  " #{@cvv_result.inspect}, sca_method: #{@sca_method.inspect}, user_bank_account:"\
  " #{@user_bank_account.inspect}, user_bank_name: #{@user_bank_name.inspect}, user_balance:"\
  " #{@user_balance.inspect}, user_verification_level: #{@user_verification_level.inspect},"\
  " status_3d: #{@status_3d.inspect}, regulation: #{@regulation.inspect}, payment_provider:"\
  " #{@payment_provider.inspect}, phone_number: #{@phone_number.inspect}, transaction_type:"\
  " #{@transaction_type.inspect}, transaction_amount: #{@transaction_amount.inspect},"\
  " transaction_currency: #{@transaction_currency.inspect}, merchant_id:"\
  " #{@merchant_id.inspect}, details_url: #{@details_url.inspect}, name: #{@name.inspect},"\
  " person_type: #{@person_type.inspect}, gender: #{@gender.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
# File 'lib/paysecure_api_documentation_live/models/optional_input.rb', line 699

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} last_bets: #{@last_bets}, last_wins: #{@last_wins}, total_bonuses:"\
  " #{@total_bonuses}, last_real_bets: #{@last_real_bets}, last_real_wins: #{@last_real_wins},"\
  " total_deposits: #{@total_deposits}, last_bonus_bets: #{@last_bonus_bets}, last_bonus_wins:"\
  " #{@last_bonus_wins}, average_real_bet: #{@average_real_bet}, last_bets_amount:"\
  " #{@last_bets_amount}, last_wins_amount: #{@last_wins_amount}, average_bonus_bet:"\
  " #{@average_bonus_bet}, bonus_to_deposits: #{@bonus_to_deposits}, last_deposit_date:"\
  " #{@last_deposit_date}, total_withdrawals: #{@total_withdrawals}, is_phone_confirmed:"\
  " #{@is_phone_confirmed}, money_in_money_out: #{@money_in_money_out}, last_deposit_amount:"\
  " #{@last_deposit_amount}, last_freespins_date: #{@last_freespins_date},"\
  " last_freespins_name: #{@last_freespins_name}, last_free_bonus_date:"\
  " #{@last_free_bonus_date}, last_free_bonus_name: #{@last_free_bonus_name},"\
  " total_bonuses_amount: #{@total_bonuses_amount}, last_freespins_amount:"\
  " #{@last_freespins_amount}, last_freespins_status: #{@last_freespins_status},"\
  " last_real_bets_amount: #{@last_real_bets_amount}, last_real_wins_amount:"\
  " #{@last_real_wins_amount}, total_deposits_amount: #{@total_deposits_amount},"\
  " last_bonus_bets_amount: #{@last_bonus_bets_amount}, last_bonus_wins_amount:"\
  " #{@last_bonus_wins_amount}, last_free_bonus_amount: #{@last_free_bonus_amount},"\
  " last_free_bonus_status: #{@last_free_bonus_status}, last_deposit_bonus_date:"\
  " #{@last_deposit_bonus_date}, last_deposit_bonus_name: #{@last_deposit_bonus_name},"\
  " last_freespins_currency: #{@last_freespins_currency}, last_freespins_wagering:"\
  " #{@last_freespins_wagering}, withdrawals_to_deposits: #{@withdrawals_to_deposits},"\
  " last_free_bonus_currency: #{@last_free_bonus_currency}, last_free_bonus_wagering:"\
  " #{@last_free_bonus_wagering}, total_withdrawals_amount: #{@total_withdrawals_amount},"\
  " withdrawal_ewallet_email: #{@withdrawal_ewallet_email}, last_deposit_bonus_amount:"\
  " #{@last_deposit_bonus_amount}, last_deposit_bonus_status: #{@last_deposit_bonus_status},"\
  " last_deposit_bonus_currency: #{@last_deposit_bonus_currency}, last_deposit_bonus_wagering:"\
  " #{@last_deposit_bonus_wagering}, session: #{@session}, payment_mode: #{@payment_mode},"\
  " card_fullname: #{@card_fullname}, card_bin: #{@card_bin}, card_hash: #{@card_hash},"\
  " card_last: #{@card_last}, card_expire: #{@card_expire}, avs_result: #{@avs_result},"\
  " cvv_result: #{@cvv_result}, sca_method: #{@sca_method}, user_bank_account:"\
  " #{@user_bank_account}, user_bank_name: #{@user_bank_name}, user_balance: #{@user_balance},"\
  " user_verification_level: #{@user_verification_level}, status_3d: #{@status_3d},"\
  " regulation: #{@regulation}, payment_provider: #{@payment_provider}, phone_number:"\
  " #{@phone_number}, transaction_type: #{@transaction_type}, transaction_amount:"\
  " #{@transaction_amount}, transaction_currency: #{@transaction_currency}, merchant_id:"\
  " #{@merchant_id}, details_url: #{@details_url}, name: #{@name}, person_type:"\
  " #{@person_type}, gender: #{@gender}, additional_properties: #{@additional_properties}>"
end