Class: PaysecureApiDocumentationLive::PauseMandateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/pause_mandate_request.rb

Overview

PauseMandateRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mandate_id:, command:, pause_start_date:, pause_end_date:, additional_properties: nil) ⇒ PauseMandateRequest

Returns a new instance of PauseMandateRequest.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/paysecure_api_documentation_live/models/pause_mandate_request.rb', line 48

def initialize(mandate_id:, command:, pause_start_date:, pause_end_date:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @mandate_id = mandate_id
  @command = command
  @pause_start_date = pause_start_date
  @pause_end_date = pause_end_date
  @additional_properties = additional_properties
end

Instance Attribute Details

#commandString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/pause_mandate_request.rb', line 18

def command
  @command
end

#mandate_idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/pause_mandate_request.rb', line 14

def mandate_id
  @mandate_id
end

#pause_end_dateString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/pause_mandate_request.rb', line 26

def pause_end_date
  @pause_end_date
end

#pause_start_dateString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/pause_mandate_request.rb', line 22

def pause_start_date
  @pause_start_date
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/paysecure_api_documentation_live/models/pause_mandate_request.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mandate_id = hash.key?('mandate_id') ? hash['mandate_id'] : nil
  command = hash.key?('command') ? hash['command'] : nil
  pause_start_date =
    hash.key?('pause_start_date') ? hash['pause_start_date'] : nil
  pause_end_date =
    hash.key?('pause_end_date') ? hash['pause_end_date'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PauseMandateRequest.new(mandate_id: mandate_id,
                          command: command,
                          pause_start_date: pause_start_date,
                          pause_end_date: pause_end_date,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/paysecure_api_documentation_live/models/pause_mandate_request.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mandate_id'] = 'mandate_id'
  @_hash['command'] = 'command'
  @_hash['pause_start_date'] = 'pause_start_date'
  @_hash['pause_end_date'] = 'pause_end_date'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/paysecure_api_documentation_live/models/pause_mandate_request.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/paysecure_api_documentation_live/models/pause_mandate_request.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
101
# File 'lib/paysecure_api_documentation_live/models/pause_mandate_request.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mandate_id: #{@mandate_id.inspect}, command: #{@command.inspect},"\
  " pause_start_date: #{@pause_start_date.inspect}, pause_end_date:"\
  " #{@pause_end_date.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
93
# File 'lib/paysecure_api_documentation_live/models/pause_mandate_request.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mandate_id: #{@mandate_id}, command: #{@command}, pause_start_date:"\
  " #{@pause_start_date}, pause_end_date: #{@pause_end_date}, additional_properties:"\
  " #{@additional_properties}>"
end