Class: PaysecureApiDocumentationLive::PayInDetails3
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::PayInDetails3
- Defined in:
- lib/paysecure_api_documentation_live/models/pay_in_details3.rb
Overview
PayInDetails3 Model.
Instance Attribute Summary collapse
-
#email_address ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#reference_number ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, email_address:, reference_number:, additional_properties: nil) ⇒ PayInDetails3
constructor
A new instance of PayInDetails3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, email_address:, reference_number:, additional_properties: nil) ⇒ PayInDetails3
Returns a new instance of PayInDetails3.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details3.rb', line 43 def initialize(name:, email_address:, reference_number:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name @email_address = email_address @reference_number = reference_number @additional_properties = additional_properties end |
Instance Attribute Details
#email_address ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details3.rb', line 18 def email_address @email_address end |
#name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details3.rb', line 14 def name @name end |
#reference_number ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details3.rb', line 22 def reference_number @reference_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details3.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil email_address = hash.key?('emailAddress') ? hash['emailAddress'] : nil reference_number = hash.key?('reference_number') ? hash['reference_number'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PayInDetails3.new(name: name, email_address: email_address, reference_number: reference_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details3.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['email_address'] = 'emailAddress' @_hash['reference_number'] = 'reference_number' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details3.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details3.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 91 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details3.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, email_address: #{@email_address.inspect},"\ " reference_number: #{@reference_number.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details3.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, email_address: #{@email_address}, reference_number:"\ " #{@reference_number}, additional_properties: #{@additional_properties}>" end |