Class: PaysecureApiDocumentationLive::PayInDetails4
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::PayInDetails4
- Defined in:
- lib/paysecure_api_documentation_live/models/pay_in_details4.rb
Overview
PayInDetails4 Model.
Instance Attribute Summary collapse
-
#payment_method ⇒ String
TODO: Write general description for this method.
-
#reference_number ⇒ String
TODO: Write general description for this method.
-
#transaction_expiry ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(reference_number:, payment_method:, transaction_expiry:, additional_properties: nil) ⇒ PayInDetails4
constructor
A new instance of PayInDetails4.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(reference_number:, payment_method:, transaction_expiry:, additional_properties: nil) ⇒ PayInDetails4
Returns a new instance of PayInDetails4.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details4.rb', line 43 def initialize(reference_number:, payment_method:, transaction_expiry:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @reference_number = reference_number @payment_method = payment_method @transaction_expiry = transaction_expiry @additional_properties = additional_properties end |
Instance Attribute Details
#payment_method ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details4.rb', line 18 def payment_method @payment_method end |
#reference_number ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details4.rb', line 14 def reference_number @reference_number end |
#transaction_expiry ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details4.rb', line 22 def transaction_expiry @transaction_expiry end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details4.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. reference_number = hash.key?('reference_number') ? hash['reference_number'] : nil payment_method = hash.key?('payment_method') ? hash['payment_method'] : nil transaction_expiry = hash.key?('transaction_expiry') ? hash['transaction_expiry'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PayInDetails4.new(reference_number: reference_number, payment_method: payment_method, transaction_expiry: transaction_expiry, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details4.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['reference_number'] = 'reference_number' @_hash['payment_method'] = 'payment_method' @_hash['transaction_expiry'] = 'transaction_expiry' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details4.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details4.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 94 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details4.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} reference_number: #{@reference_number.inspect}, payment_method:"\ " #{@payment_method.inspect}, transaction_expiry: #{@transaction_expiry.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 86 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details4.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} reference_number: #{@reference_number}, payment_method: #{@payment_method},"\ " transaction_expiry: #{@transaction_expiry}, additional_properties:"\ " #{@additional_properties}>" end |