Class: PaysecureApiDocumentationLive::PayOutRequest1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::PayOutRequest1
- Defined in:
- lib/paysecure_api_documentation_live/models/pay_out_request1.rb
Overview
PayOutRequest1 Model.
Instance Attribute Summary collapse
-
#amount ⇒ Integer
TODO: Write general description for this method.
-
#beneficiary_detail ⇒ BeneficiaryDetail1
TODO: Write general description for this method.
-
#brand_id ⇒ String
TODO: Write general description for this method.
-
#client ⇒ Client8
TODO: Write general description for this method.
-
#currency ⇒ String
TODO: Write general description for this method.
-
#failure_callback ⇒ String
TODO: Write general description for this method.
-
#failure_redirect ⇒ String
TODO: Write general description for this method.
-
#payout_method ⇒ String
TODO: Write general description for this method.
-
#pending_redirect ⇒ String
TODO: Write general description for this method.
-
#purpose ⇒ String
TODO: Write general description for this method.
-
#success_callback ⇒ String
TODO: Write general description for this method.
-
#success_redirect ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client:, beneficiary_detail:, payout_method:, brand_id:, amount:, currency:, purpose:, success_redirect:, pending_redirect:, failure_redirect:, success_callback:, failure_callback:, additional_properties: nil) ⇒ PayOutRequest1
constructor
A new instance of PayOutRequest1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client:, beneficiary_detail:, payout_method:, brand_id:, amount:, currency:, purpose:, success_redirect:, pending_redirect:, failure_redirect:, success_callback:, failure_callback:, additional_properties: nil) ⇒ PayOutRequest1
Returns a new instance of PayOutRequest1.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 88 def initialize(client:, beneficiary_detail:, payout_method:, brand_id:, amount:, currency:, purpose:, success_redirect:, pending_redirect:, failure_redirect:, success_callback:, failure_callback:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client = client @beneficiary_detail = beneficiary_detail @payout_method = payout_method @brand_id = brand_id @amount = amount @currency = currency @purpose = purpose @success_redirect = success_redirect @pending_redirect = pending_redirect @failure_redirect = failure_redirect @success_callback = success_callback @failure_callback = failure_callback @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 30 def amount @amount end |
#beneficiary_detail ⇒ BeneficiaryDetail1
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 18 def beneficiary_detail @beneficiary_detail end |
#brand_id ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 26 def brand_id @brand_id end |
#client ⇒ Client8
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 14 def client @client end |
#currency ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 34 def currency @currency end |
#failure_callback ⇒ String
TODO: Write general description for this method
58 59 60 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 58 def failure_callback @failure_callback end |
#failure_redirect ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 50 def failure_redirect @failure_redirect end |
#payout_method ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 22 def payout_method @payout_method end |
#pending_redirect ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 46 def pending_redirect @pending_redirect end |
#purpose ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 38 def purpose @purpose end |
#success_callback ⇒ String
TODO: Write general description for this method
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 54 def success_callback @success_callback end |
#success_redirect ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 42 def success_redirect @success_redirect end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 111 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client = Client8.from_hash(hash['client']) if hash['client'] beneficiary_detail = BeneficiaryDetail1.from_hash(hash['beneficiaryDetail']) if hash['beneficiaryDetail'] payout_method = hash.key?('payoutMethod') ? hash['payoutMethod'] : nil brand_id = hash.key?('brand_id') ? hash['brand_id'] : nil amount = hash.key?('amount') ? hash['amount'] : nil currency = hash.key?('currency') ? hash['currency'] : nil purpose = hash.key?('purpose') ? hash['purpose'] : nil success_redirect = hash.key?('success_redirect') ? hash['success_redirect'] : nil pending_redirect = hash.key?('pending_redirect') ? hash['pending_redirect'] : nil failure_redirect = hash.key?('failure_redirect') ? hash['failure_redirect'] : nil success_callback = hash.key?('success_callback') ? hash['success_callback'] : nil failure_callback = hash.key?('failure_callback') ? hash['failure_callback'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PayOutRequest1.new(client: client, beneficiary_detail: beneficiary_detail, payout_method: payout_method, brand_id: brand_id, amount: amount, currency: currency, purpose: purpose, success_redirect: success_redirect, pending_redirect: pending_redirect, failure_redirect: failure_redirect, success_callback: success_callback, failure_callback: failure_callback, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 61 def self.names @_hash = {} if @_hash.nil? @_hash['client'] = 'client' @_hash['beneficiary_detail'] = 'beneficiaryDetail' @_hash['payout_method'] = 'payoutMethod' @_hash['brand_id'] = 'brand_id' @_hash['amount'] = 'amount' @_hash['currency'] = 'currency' @_hash['purpose'] = 'purpose' @_hash['success_redirect'] = 'success_redirect' @_hash['pending_redirect'] = 'pending_redirect' @_hash['failure_redirect'] = 'failure_redirect' @_hash['success_callback'] = 'success_callback' @_hash['failure_callback'] = 'failure_callback' @_hash end |
.nullables ⇒ Object
An array for nullable fields
84 85 86 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 84 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
79 80 81 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 79 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
169 170 171 172 173 174 175 176 177 178 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 169 def inspect class_name = self.class.name.split('::').last "<#{class_name} client: #{@client.inspect}, beneficiary_detail:"\ " #{@beneficiary_detail.inspect}, payout_method: #{@payout_method.inspect}, brand_id:"\ " #{@brand_id.inspect}, amount: #{@amount.inspect}, currency: #{@currency.inspect}, purpose:"\ " #{@purpose.inspect}, success_redirect: #{@success_redirect.inspect}, pending_redirect:"\ " #{@pending_redirect.inspect}, failure_redirect: #{@failure_redirect.inspect},"\ " success_callback: #{@success_callback.inspect}, failure_callback:"\ " #{@failure_callback.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
158 159 160 161 162 163 164 165 166 |
# File 'lib/paysecure_api_documentation_live/models/pay_out_request1.rb', line 158 def to_s class_name = self.class.name.split('::').last "<#{class_name} client: #{@client}, beneficiary_detail: #{@beneficiary_detail},"\ " payout_method: #{@payout_method}, brand_id: #{@brand_id}, amount: #{@amount}, currency:"\ " #{@currency}, purpose: #{@purpose}, success_redirect: #{@success_redirect},"\ " pending_redirect: #{@pending_redirect}, failure_redirect: #{@failure_redirect},"\ " success_callback: #{@success_callback}, failure_callback: #{@failure_callback},"\ " additional_properties: #{@additional_properties}>" end |