Class: PaysecureApiDocumentationLive::PaymentData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/payment_data.rb

Overview

PaymentData Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(online_payment_cryptogram:, eci_indicator:, additional_properties: nil) ⇒ PaymentData

Returns a new instance of PaymentData.



38
39
40
41
42
43
44
45
46
# File 'lib/paysecure_api_documentation_live/models/payment_data.rb', line 38

def initialize(online_payment_cryptogram:, eci_indicator:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @online_payment_cryptogram = online_payment_cryptogram
  @eci_indicator = eci_indicator
  @additional_properties = additional_properties
end

Instance Attribute Details

#eci_indicatorString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/payment_data.rb', line 18

def eci_indicator
  @eci_indicator
end

#online_payment_cryptogramString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/payment_data.rb', line 14

def online_payment_cryptogram
  @online_payment_cryptogram
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/paysecure_api_documentation_live/models/payment_data.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  online_payment_cryptogram =
    hash.key?('onlinePaymentCryptogram') ? hash['onlinePaymentCryptogram'] : nil
  eci_indicator = hash.key?('eciIndicator') ? hash['eciIndicator'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentData.new(online_payment_cryptogram: online_payment_cryptogram,
                  eci_indicator: eci_indicator,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/paysecure_api_documentation_live/models/payment_data.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['online_payment_cryptogram'] = 'onlinePaymentCryptogram'
  @_hash['eci_indicator'] = 'eciIndicator'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/paysecure_api_documentation_live/models/payment_data.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/paysecure_api_documentation_live/models/payment_data.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
83
# File 'lib/paysecure_api_documentation_live/models/payment_data.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} online_payment_cryptogram: #{@online_payment_cryptogram.inspect},"\
  " eci_indicator: #{@eci_indicator.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/paysecure_api_documentation_live/models/payment_data.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} online_payment_cryptogram: #{@online_payment_cryptogram}, eci_indicator:"\
  " #{@eci_indicator}, additional_properties: #{@additional_properties}>"
end