Class: PaysecureApiDocumentationLive::PayoutManualReviewApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/apis/payout_manual_review_api.rb

Overview

PayoutManualReviewApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from PaysecureApiDocumentationLive::BaseApi

Instance Method Details

#approve_payout(action, body, payout_id) ⇒ ApiResponse

TODO: type endpoint description here here

Parameters:

  • action (String)

    Required parameter: TODO: type description here

  • body (Object)

    Required parameter: TODO: type description here

  • payout_id (String)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/paysecure_api_documentation_live/apis/payout_manual_review_api.rb', line 67

def approve_payout(action,
                   body,
                   payout_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/v1/payouts/{payout_id}/action',
                                 Server::SERVER_3)
               .query_param(new_parameter(action, key: 'action')
                             .is_required(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .template_param(new_parameter(payout_id, key: 'payout_id')
                                .is_required(true)
                                .should_encode(true))
               .body_serializer(APIHelper.method(:json_serialize)))
    .response(new_response_handler
                .is_response_void(true)
                .is_api_response(true))
    .execute
end

#approve_payout_with_remarks(action, body, payout_id) ⇒ ApiResponse

TODO: type endpoint description here type description here here

Parameters:

  • action (String)

    Required parameter: TODO: type description here

  • body (ApprovePayoutWithRemarksRequest)

    Required parameter: TODO:

  • payout_id (String)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/paysecure_api_documentation_live/apis/payout_manual_review_api.rb', line 96

def approve_payout_with_remarks(action,
                                body,
                                payout_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/v1/payouts/{payout_id}/action',
                                 Server::SERVER_3)
               .query_param(new_parameter(action, key: 'action')
                             .is_required(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .template_param(new_parameter(payout_id, key: 'payout_id')
                                .is_required(true)
                                .should_encode(true))
               .body_serializer(proc do |param| param.to_json unless param.nil? end))
    .response(new_response_handler
                .is_response_void(true)
                .is_api_response(true))
    .execute
end

#list_payouts(page_no, page_size, status, timezone, start_date, end_date, payment_method, email, customer_segment) ⇒ ApiResponse

TODO: type endpoint description here here here here description here

Parameters:

  • page_no (Integer)

    Required parameter: TODO: type description here

  • page_size (Integer)

    Required parameter: TODO: type description

  • status (String)

    Required parameter: TODO: type description here

  • timezone (String)

    Required parameter: TODO: type description here

  • start_date (String)

    Required parameter: TODO: type description

  • end_date (String)

    Required parameter: TODO: type description here

  • payment_method (String)

    Required parameter: TODO: type description

  • email (String)

    Required parameter: TODO: type description here

  • customer_segment (String)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/paysecure_api_documentation_live/apis/payout_manual_review_api.rb', line 24

def list_payouts(page_no,
                 page_size,
                 status,
                 timezone,
                 start_date,
                 end_date,
                 payment_method,
                 email,
                 customer_segment)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/v1/external/transactions/payout/list',
                                 Server::SERVER_3)
               .query_param(new_parameter(page_no, key: 'page_no')
                             .is_required(true))
               .query_param(new_parameter(page_size, key: 'page_size')
                             .is_required(true))
               .query_param(new_parameter(status, key: 'status')
                             .is_required(true))
               .query_param(new_parameter(timezone, key: 'timezone')
                             .is_required(true))
               .query_param(new_parameter(start_date, key: 'start_date')
                             .is_required(true))
               .query_param(new_parameter(end_date, key: 'end_date')
                             .is_required(true))
               .query_param(new_parameter(payment_method, key: 'payment_method')
                             .is_required(true))
               .query_param(new_parameter(email, key: 'email')
                             .is_required(true))
               .query_param(new_parameter(customer_segment, key: 'customer_segment')
                             .is_required(true)))
    .response(new_response_handler
                .is_response_void(true)
                .is_api_response(true))
    .execute
end

#reject_payout(action, body, payout_id) ⇒ ApiResponse

TODO: type endpoint description here here

Parameters:

  • action (String)

    Required parameter: TODO: type description here

  • body (Object)

    Required parameter: TODO: type description here

  • payout_id (String)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/paysecure_api_documentation_live/apis/payout_manual_review_api.rb', line 124

def reject_payout(action,
                  body,
                  payout_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/v1/payouts/{payout_id}/action',
                                 Server::SERVER_3)
               .query_param(new_parameter(action, key: 'action')
                             .is_required(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .template_param(new_parameter(payout_id, key: 'payout_id')
                                .is_required(true)
                                .should_encode(true))
               .body_serializer(APIHelper.method(:json_serialize)))
    .response(new_response_handler
                .is_response_void(true)
                .is_api_response(true))
    .execute
end

#reject_payout_with_remarks(action, body, payout_id) ⇒ ApiResponse

TODO: type endpoint description here type description here here

Parameters:

  • action (String)

    Required parameter: TODO: type description here

  • body (RejectPayoutWithRemarksRequest)

    Required parameter: TODO:

  • payout_id (String)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/paysecure_api_documentation_live/apis/payout_manual_review_api.rb', line 153

def reject_payout_with_remarks(action,
                               body,
                               payout_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/v1/payouts/{payout_id}/action',
                                 Server::SERVER_3)
               .query_param(new_parameter(action, key: 'action')
                             .is_required(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .template_param(new_parameter(payout_id, key: 'payout_id')
                                .is_required(true)
                                .should_encode(true))
               .body_serializer(proc do |param| param.to_json unless param.nil? end))
    .response(new_response_handler
                .is_response_void(true)
                .is_api_response(true))
    .execute
end