Class: PaysecureApiDocumentationLive::Product49

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/product49.rb

Overview

Product49 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name:, quantity:, price:, discount:, tax_percent:, additional_properties: nil) ⇒ Product49

Returns a new instance of Product49.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 53

def initialize(name:, quantity:, price:, discount:, tax_percent:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name
  @quantity = quantity
  @price = price
  @discount = discount
  @tax_percent = tax_percent
  @additional_properties = additional_properties
end

Instance Attribute Details

#discountInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 26

def discount
  @discount
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 14

def name
  @name
end

#priceFloat

TODO: Write general description for this method

Returns:

  • (Float)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 22

def price
  @price
end

#quantityInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 18

def quantity
  @quantity
end

#tax_percentString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 30

def tax_percent
  @tax_percent
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  quantity = hash.key?('quantity') ? hash['quantity'] : nil
  price = hash.key?('price') ? hash['price'] : nil
  discount = hash.key?('discount') ? hash['discount'] : nil
  tax_percent = hash.key?('tax_percent') ? hash['tax_percent'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Product49.new(name: name,
                quantity: quantity,
                price: price,
                discount: discount,
                tax_percent: tax_percent,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['quantity'] = 'quantity'
  @_hash['price'] = 'price'
  @_hash['discount'] = 'discount'
  @_hash['tax_percent'] = 'tax_percent'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 44

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
107
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, quantity: #{@quantity.inspect}, price:"\
  " #{@price.inspect}, discount: #{@discount.inspect}, tax_percent: #{@tax_percent.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



94
95
96
97
98
99
# File 'lib/paysecure_api_documentation_live/models/product49.rb', line 94

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, quantity: #{@quantity}, price: #{@price}, discount:"\
  " #{@discount}, tax_percent: #{@tax_percent}, additional_properties:"\
  " #{@additional_properties}>"
end