Class: PaysecureApiDocumentationLive::Product7
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Product7
- Defined in:
- lib/paysecure_api_documentation_live/models/product7.rb
Overview
Product7 Model.
Instance Attribute Summary collapse
-
#name ⇒ String
TODO: Write general description for this method.
-
#price ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, price:, additional_properties: nil) ⇒ Product7
constructor
A new instance of Product7.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, price:, additional_properties: nil) ⇒ Product7
Returns a new instance of Product7.
38 39 40 41 42 43 44 45 |
# File 'lib/paysecure_api_documentation_live/models/product7.rb', line 38 def initialize(name:, price:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name @price = price @additional_properties = additional_properties end |
Instance Attribute Details
#name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/product7.rb', line 14 def name @name end |
#price ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/product7.rb', line 18 def price @price end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/paysecure_api_documentation_live/models/product7.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil price = hash.key?('price') ? hash['price'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Product7.new(name: name, price: price, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/paysecure_api_documentation_live/models/product7.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['price'] = 'price' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/product7.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/product7.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/paysecure_api_documentation_live/models/product7.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, price: #{@price.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/paysecure_api_documentation_live/models/product7.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, price: #{@price}, additional_properties:"\ " #{@additional_properties}>" end |