Class: PaysecureApiDocumentationLive::Purchase24
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Purchase24
- Defined in:
- lib/paysecure_api_documentation_live/models/purchase24.rb
Overview
Purchase24 Model.
Instance Attribute Summary collapse
-
#currency ⇒ String
TODO: Write general description for this method.
-
#debt ⇒ Integer
TODO: Write general description for this method.
-
#email_message ⇒ String
TODO: Write general description for this method.
-
#expire_in_min ⇒ String
TODO: Write general description for this method.
-
#language ⇒ String
TODO: Write general description for this method.
-
#notes ⇒ String
TODO: Write general description for this method.
-
#products ⇒ Array[Product1]
TODO: Write general description for this method.
-
#request_client_details ⇒ Array[String]
TODO: Write general description for this method.
-
#timezone ⇒ String
TODO: Write general description for this method.
-
#total ⇒ Float
TODO: Write general description for this method.
-
#total_formatted ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(currency:, products:, total:, language:, notes:, debt:, total_formatted:, expire_in_min:, request_client_details:, timezone:, email_message:, additional_properties: nil) ⇒ Purchase24
constructor
A new instance of Purchase24.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(currency:, products:, total:, language:, notes:, debt:, total_formatted:, expire_in_min:, request_client_details:, timezone:, email_message:, additional_properties: nil) ⇒ Purchase24
Returns a new instance of Purchase24.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 83 def initialize(currency:, products:, total:, language:, notes:, debt:, total_formatted:, expire_in_min:, request_client_details:, timezone:, email_message:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @currency = currency @products = products @total = total @language = language @notes = notes @debt = debt @total_formatted = total_formatted @expire_in_min = expire_in_min @request_client_details = request_client_details @timezone = timezone @email_message = @additional_properties = additional_properties end |
Instance Attribute Details
#currency ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 14 def currency @currency end |
#debt ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 34 def debt @debt end |
#email_message ⇒ String
TODO: Write general description for this method
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 54 def @email_message end |
#expire_in_min ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 42 def expire_in_min @expire_in_min end |
#language ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 26 def language @language end |
#notes ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 30 def notes @notes end |
#products ⇒ Array[Product1]
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 18 def products @products end |
#request_client_details ⇒ Array[String]
TODO: Write general description for this method
46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 46 def request_client_details @request_client_details end |
#timezone ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 50 def timezone @timezone end |
#total ⇒ Float
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 22 def total @total end |
#total_formatted ⇒ Float
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 38 def total_formatted @total_formatted end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 104 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. currency = hash.key?('currency') ? hash['currency'] : nil # Parameter is an array, so we need to iterate through it products = nil unless hash['products'].nil? products = [] hash['products'].each do |structure| products << (Product1.from_hash(structure) if structure) end end products = nil unless hash.key?('products') total = hash.key?('total') ? hash['total'] : nil language = hash.key?('language') ? hash['language'] : nil notes = hash.key?('notes') ? hash['notes'] : nil debt = hash.key?('debt') ? hash['debt'] : nil total_formatted = hash.key?('total_formatted') ? hash['total_formatted'] : nil expire_in_min = hash.key?('expireInMin') ? hash['expireInMin'] : nil request_client_details = hash.key?('request_client_details') ? hash['request_client_details'] : nil timezone = hash.key?('timezone') ? hash['timezone'] : nil = hash.key?('email_message') ? hash['email_message'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Purchase24.new(currency: currency, products: products, total: total, language: language, notes: notes, debt: debt, total_formatted: total_formatted, expire_in_min: expire_in_min, request_client_details: request_client_details, timezone: timezone, email_message: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 57 def self.names @_hash = {} if @_hash.nil? @_hash['currency'] = 'currency' @_hash['products'] = 'products' @_hash['total'] = 'total' @_hash['language'] = 'language' @_hash['notes'] = 'notes' @_hash['debt'] = 'debt' @_hash['total_formatted'] = 'total_formatted' @_hash['expire_in_min'] = 'expireInMin' @_hash['request_client_details'] = 'request_client_details' @_hash['timezone'] = 'timezone' @_hash['email_message'] = 'email_message' @_hash end |
.nullables ⇒ Object
An array for nullable fields
79 80 81 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 79 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 74 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
164 165 166 167 168 169 170 171 172 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 164 def inspect class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency.inspect}, products: #{@products.inspect}, total:"\ " #{@total.inspect}, language: #{@language.inspect}, notes: #{@notes.inspect}, debt:"\ " #{@debt.inspect}, total_formatted: #{@total_formatted.inspect}, expire_in_min:"\ " #{@expire_in_min.inspect}, request_client_details: #{@request_client_details.inspect},"\ " timezone: #{@timezone.inspect}, email_message: #{@email_message.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
154 155 156 157 158 159 160 161 |
# File 'lib/paysecure_api_documentation_live/models/purchase24.rb', line 154 def to_s class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency}, products: #{@products}, total: #{@total}, language:"\ " #{@language}, notes: #{@notes}, debt: #{@debt}, total_formatted: #{@total_formatted},"\ " expire_in_min: #{@expire_in_min}, request_client_details: #{@request_client_details},"\ " timezone: #{@timezone}, email_message: #{@email_message}, additional_properties:"\ " #{@additional_properties}>" end |