Class: PaysecureApiDocumentationLive::Purchase49

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/purchase49.rb

Overview

Purchase49 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(currency:, products:, total:, language:, notes:, debt:, total_formatted:, tax_amount:, tax_percent:, request_client_details:, timezone:, email_message:, additional_properties: nil) ⇒ Purchase49

Returns a new instance of Purchase49.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 88

def initialize(currency:, products:, total:, language:, notes:, debt:,
               total_formatted:, tax_amount:, tax_percent:,
               request_client_details:, timezone:, email_message:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @currency = currency
  @products = products
  @total = total
  @language = language
  @notes = notes
  @debt = debt
  @total_formatted = total_formatted
  @tax_amount = tax_amount
  @tax_percent = tax_percent
  @request_client_details = request_client_details
  @timezone = timezone
  @email_message = email_message
  @additional_properties = additional_properties
end

Instance Attribute Details

#currencyString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 14

def currency
  @currency
end

#debtInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 34

def debt
  @debt
end

#email_messageString

TODO: Write general description for this method

Returns:

  • (String)


58
59
60
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 58

def email_message
  @email_message
end

#languageString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 26

def language
  @language
end

#notesString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 30

def notes
  @notes
end

#productsArray[Product49]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 18

def products
  @products
end

#request_client_detailsArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


50
51
52
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 50

def request_client_details
  @request_client_details
end

#tax_amountInteger

TODO: Write general description for this method

Returns:

  • (Integer)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 42

def tax_amount
  @tax_amount
end

#tax_percentInteger

TODO: Write general description for this method

Returns:

  • (Integer)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 46

def tax_percent
  @tax_percent
end

#timezoneString

TODO: Write general description for this method

Returns:

  • (String)


54
55
56
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 54

def timezone
  @timezone
end

#totalFloat

TODO: Write general description for this method

Returns:

  • (Float)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 22

def total
  @total
end

#total_formattedInteger

TODO: Write general description for this method

Returns:

  • (Integer)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 38

def total_formatted
  @total_formatted
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 111

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  currency = hash.key?('currency') ? hash['currency'] : nil
  # Parameter is an array, so we need to iterate through it
  products = nil
  unless hash['products'].nil?
    products = []
    hash['products'].each do |structure|
      products << (Product49.from_hash(structure) if structure)
    end
  end

  products = nil unless hash.key?('products')
  total = hash.key?('total') ? hash['total'] : nil
  language = hash.key?('language') ? hash['language'] : nil
  notes = hash.key?('notes') ? hash['notes'] : nil
  debt = hash.key?('debt') ? hash['debt'] : nil
  total_formatted =
    hash.key?('total_formatted') ? hash['total_formatted'] : nil
  tax_amount = hash.key?('taxAmount') ? hash['taxAmount'] : nil
  tax_percent = hash.key?('taxPercent') ? hash['taxPercent'] : nil
  request_client_details =
    hash.key?('request_client_details') ? hash['request_client_details'] : nil
  timezone = hash.key?('timezone') ? hash['timezone'] : nil
  email_message = hash.key?('email_message') ? hash['email_message'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Purchase49.new(currency: currency,
                 products: products,
                 total: total,
                 language: language,
                 notes: notes,
                 debt: debt,
                 total_formatted: total_formatted,
                 tax_amount: tax_amount,
                 tax_percent: tax_percent,
                 request_client_details: request_client_details,
                 timezone: timezone,
                 email_message: email_message,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 61

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['currency'] = 'currency'
  @_hash['products'] = 'products'
  @_hash['total'] = 'total'
  @_hash['language'] = 'language'
  @_hash['notes'] = 'notes'
  @_hash['debt'] = 'debt'
  @_hash['total_formatted'] = 'total_formatted'
  @_hash['tax_amount'] = 'taxAmount'
  @_hash['tax_percent'] = 'taxPercent'
  @_hash['request_client_details'] = 'request_client_details'
  @_hash['timezone'] = 'timezone'
  @_hash['email_message'] = 'email_message'
  @_hash
end

.nullablesObject

An array for nullable fields



84
85
86
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 84

def self.nullables
  []
end

.optionalsObject

An array for optional fields



79
80
81
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 79

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



173
174
175
176
177
178
179
180
181
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 173

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency.inspect}, products: #{@products.inspect}, total:"\
  " #{@total.inspect}, language: #{@language.inspect}, notes: #{@notes.inspect}, debt:"\
  " #{@debt.inspect}, total_formatted: #{@total_formatted.inspect}, tax_amount:"\
  " #{@tax_amount.inspect}, tax_percent: #{@tax_percent.inspect}, request_client_details:"\
  " #{@request_client_details.inspect}, timezone: #{@timezone.inspect}, email_message:"\
  " #{@email_message.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



163
164
165
166
167
168
169
170
# File 'lib/paysecure_api_documentation_live/models/purchase49.rb', line 163

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency}, products: #{@products}, total: #{@total}, language:"\
  " #{@language}, notes: #{@notes}, debt: #{@debt}, total_formatted: #{@total_formatted},"\
  " tax_amount: #{@tax_amount}, tax_percent: #{@tax_percent}, request_client_details:"\
  " #{@request_client_details}, timezone: #{@timezone}, email_message: #{@email_message},"\
  " additional_properties: #{@additional_properties}>"
end