Class: PaysecureApiDocumentationLive::Purchase55
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Purchase55
- Defined in:
- lib/paysecure_api_documentation_live/models/purchase55.rb
Overview
Purchase55 Model.
Instance Attribute Summary collapse
-
#currency ⇒ String
TODO: Write general description for this method.
-
#products ⇒ Array[Product]
TODO: Write general description for this method.
-
#total ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(currency:, products:, total:, additional_properties: nil) ⇒ Purchase55
constructor
A new instance of Purchase55.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(currency:, products:, total:, additional_properties: nil) ⇒ Purchase55
Returns a new instance of Purchase55.
43 44 45 46 47 48 49 50 51 |
# File 'lib/paysecure_api_documentation_live/models/purchase55.rb', line 43 def initialize(currency:, products:, total:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @currency = currency @products = products @total = total @additional_properties = additional_properties end |
Instance Attribute Details
#currency ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/purchase55.rb', line 14 def currency @currency end |
#products ⇒ Array[Product]
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/purchase55.rb', line 18 def products @products end |
#total ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/purchase55.rb', line 22 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/paysecure_api_documentation_live/models/purchase55.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. currency = hash.key?('currency') ? hash['currency'] : nil # Parameter is an array, so we need to iterate through it products = nil unless hash['products'].nil? products = [] hash['products'].each do |structure| products << (Product.from_hash(structure) if structure) end end products = nil unless hash.key?('products') total = hash.key?('total') ? hash['total'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Purchase55.new(currency: currency, products: products, total: total, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/purchase55.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['currency'] = 'currency' @_hash['products'] = 'products' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/purchase55.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/purchase55.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 |
# File 'lib/paysecure_api_documentation_live/models/purchase55.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency.inspect}, products: #{@products.inspect}, total:"\ " #{@total.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/paysecure_api_documentation_live/models/purchase55.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency}, products: #{@products}, total: #{@total},"\ " additional_properties: #{@additional_properties}>" end |