Class: PaysecureApiDocumentationLive::Purchase56

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/purchase56.rb

Overview

Purchase56 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(currency:, products:, total:, language:, notes:, debt:, total_formatted:, tax_amount:, tax_percent:, request_client_details:, email_message:, additional_properties: nil) ⇒ Purchase56

Returns a new instance of Purchase56.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 83

def initialize(currency:, products:, total:, language:, notes:, debt:,
               total_formatted:, tax_amount:, tax_percent:,
               request_client_details:, email_message:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @currency = currency
  @products = products
  @total = total
  @language = language
  @notes = notes
  @debt = debt
  @total_formatted = total_formatted
  @tax_amount = tax_amount
  @tax_percent = tax_percent
  @request_client_details = request_client_details
  @email_message = email_message
  @additional_properties = additional_properties
end

Instance Attribute Details

#currencyString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 14

def currency
  @currency
end

#debtInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 34

def debt
  @debt
end

#email_messageString

TODO: Write general description for this method

Returns:

  • (String)


54
55
56
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 54

def email_message
  @email_message
end

#languageString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 26

def language
  @language
end

#notesString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 30

def notes
  @notes
end

#productsArray[Product1]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 18

def products
  @products
end

#request_client_detailsArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


50
51
52
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 50

def request_client_details
  @request_client_details
end

#tax_amountFloat

TODO: Write general description for this method

Returns:

  • (Float)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 42

def tax_amount
  @tax_amount
end

#tax_percentFloat

TODO: Write general description for this method

Returns:

  • (Float)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 46

def tax_percent
  @tax_percent
end

#totalFloat

TODO: Write general description for this method

Returns:

  • (Float)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 22

def total
  @total
end

#total_formattedFloat

TODO: Write general description for this method

Returns:

  • (Float)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 38

def total_formatted
  @total_formatted
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 105

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  currency = hash.key?('currency') ? hash['currency'] : nil
  # Parameter is an array, so we need to iterate through it
  products = nil
  unless hash['products'].nil?
    products = []
    hash['products'].each do |structure|
      products << (Product1.from_hash(structure) if structure)
    end
  end

  products = nil unless hash.key?('products')
  total = hash.key?('total') ? hash['total'] : nil
  language = hash.key?('language') ? hash['language'] : nil
  notes = hash.key?('notes') ? hash['notes'] : nil
  debt = hash.key?('debt') ? hash['debt'] : nil
  total_formatted =
    hash.key?('total_formatted') ? hash['total_formatted'] : nil
  tax_amount = hash.key?('taxAmount') ? hash['taxAmount'] : nil
  tax_percent = hash.key?('taxPercent') ? hash['taxPercent'] : nil
  request_client_details =
    hash.key?('request_client_details') ? hash['request_client_details'] : nil
  email_message = hash.key?('email_message') ? hash['email_message'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Purchase56.new(currency: currency,
                 products: products,
                 total: total,
                 language: language,
                 notes: notes,
                 debt: debt,
                 total_formatted: total_formatted,
                 tax_amount: tax_amount,
                 tax_percent: tax_percent,
                 request_client_details: request_client_details,
                 email_message: email_message,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 57

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['currency'] = 'currency'
  @_hash['products'] = 'products'
  @_hash['total'] = 'total'
  @_hash['language'] = 'language'
  @_hash['notes'] = 'notes'
  @_hash['debt'] = 'debt'
  @_hash['total_formatted'] = 'total_formatted'
  @_hash['tax_amount'] = 'taxAmount'
  @_hash['tax_percent'] = 'taxPercent'
  @_hash['request_client_details'] = 'request_client_details'
  @_hash['email_message'] = 'email_message'
  @_hash
end

.nullablesObject

An array for nullable fields



79
80
81
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 79

def self.nullables
  []
end

.optionalsObject

An array for optional fields



74
75
76
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 74

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



165
166
167
168
169
170
171
172
173
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 165

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency.inspect}, products: #{@products.inspect}, total:"\
  " #{@total.inspect}, language: #{@language.inspect}, notes: #{@notes.inspect}, debt:"\
  " #{@debt.inspect}, total_formatted: #{@total_formatted.inspect}, tax_amount:"\
  " #{@tax_amount.inspect}, tax_percent: #{@tax_percent.inspect}, request_client_details:"\
  " #{@request_client_details.inspect}, email_message: #{@email_message.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



155
156
157
158
159
160
161
162
# File 'lib/paysecure_api_documentation_live/models/purchase56.rb', line 155

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency}, products: #{@products}, total: #{@total}, language:"\
  " #{@language}, notes: #{@notes}, debt: #{@debt}, total_formatted: #{@total_formatted},"\
  " tax_amount: #{@tax_amount}, tax_percent: #{@tax_percent}, request_client_details:"\
  " #{@request_client_details}, email_message: #{@email_message}, additional_properties:"\
  " #{@additional_properties}>"
end