Class: PaysecureApiDocumentationLive::Purchase7
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Purchase7
- Defined in:
- lib/paysecure_api_documentation_live/models/purchase7.rb
Overview
Purchase7 Model.
Instance Attribute Summary collapse
-
#currency ⇒ String
TODO: Write general description for this method.
-
#expire_in_min ⇒ String
TODO: Write general description for this method.
-
#products ⇒ Array[Product7]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(currency:, expire_in_min:, products:, additional_properties: nil) ⇒ Purchase7
constructor
A new instance of Purchase7.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(currency:, expire_in_min:, products:, additional_properties: nil) ⇒ Purchase7
Returns a new instance of Purchase7.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/purchase7.rb', line 43 def initialize(currency:, expire_in_min:, products:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @currency = currency @expire_in_min = expire_in_min @products = products @additional_properties = additional_properties end |
Instance Attribute Details
#currency ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/purchase7.rb', line 14 def currency @currency end |
#expire_in_min ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/purchase7.rb', line 18 def expire_in_min @expire_in_min end |
#products ⇒ Array[Product7]
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/purchase7.rb', line 22 def products @products end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/paysecure_api_documentation_live/models/purchase7.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. currency = hash.key?('currency') ? hash['currency'] : nil expire_in_min = hash.key?('expireInMin') ? hash['expireInMin'] : nil # Parameter is an array, so we need to iterate through it products = nil unless hash['products'].nil? products = [] hash['products'].each do |structure| products << (Product7.from_hash(structure) if structure) end end products = nil unless hash.key?('products') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Purchase7.new(currency: currency, expire_in_min: expire_in_min, products: products, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/purchase7.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['currency'] = 'currency' @_hash['expire_in_min'] = 'expireInMin' @_hash['products'] = 'products' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/purchase7.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/purchase7.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 |
# File 'lib/paysecure_api_documentation_live/models/purchase7.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency.inspect}, expire_in_min: #{@expire_in_min.inspect},"\ " products: #{@products.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/paysecure_api_documentation_live/models/purchase7.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency}, expire_in_min: #{@expire_in_min}, products:"\ " #{@products}, additional_properties: #{@additional_properties}>" end |