Class: PaysecureApiDocumentationLive::PurchaseSessionRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/purchase_session_request.rb

Overview

PurchaseSessionRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(customer_id:, merchant_ref:, currency:, products:, total_amount:, payment_method:, success_redirect:, failure_redirect:, pending_redirect:, success_callback:, failure_callback:, extra_param:, additional_properties: nil) ⇒ PurchaseSessionRequest

Returns a new instance of PurchaseSessionRequest.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 88

def initialize(customer_id:, merchant_ref:, currency:, products:,
               total_amount:, payment_method:, success_redirect:,
               failure_redirect:, pending_redirect:, success_callback:,
               failure_callback:, extra_param:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @customer_id = customer_id
  @merchant_ref = merchant_ref
  @currency = currency
  @products = products
  @total_amount = total_amount
  @payment_method = payment_method
  @success_redirect = success_redirect
  @failure_redirect = failure_redirect
  @pending_redirect = pending_redirect
  @success_callback = success_callback
  @failure_callback = failure_callback
  @extra_param = extra_param
  @additional_properties = additional_properties
end

Instance Attribute Details

#currencyString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 22

def currency
  @currency
end

#customer_idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 14

def customer_id
  @customer_id
end

#extra_paramExtraParam20

TODO: Write general description for this method

Returns:



58
59
60
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 58

def extra_param
  @extra_param
end

#failure_callbackString

TODO: Write general description for this method

Returns:

  • (String)


54
55
56
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 54

def failure_callback
  @failure_callback
end

#failure_redirectString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 42

def failure_redirect
  @failure_redirect
end

#merchant_refString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 18

def merchant_ref
  @merchant_ref
end

#payment_methodString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 34

def payment_method
  @payment_method
end

#pending_redirectString

TODO: Write general description for this method

Returns:

  • (String)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 46

def pending_redirect
  @pending_redirect
end

#productsArray[Product]

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 26

def products
  @products
end

#success_callbackString

TODO: Write general description for this method

Returns:

  • (String)


50
51
52
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 50

def success_callback
  @success_callback
end

#success_redirectString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 38

def success_redirect
  @success_redirect
end

#total_amountString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 30

def total_amount
  @total_amount
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 111

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  customer_id = hash.key?('customerId') ? hash['customerId'] : nil
  merchant_ref = hash.key?('merchantRef') ? hash['merchantRef'] : nil
  currency = hash.key?('currency') ? hash['currency'] : nil
  # Parameter is an array, so we need to iterate through it
  products = nil
  unless hash['products'].nil?
    products = []
    hash['products'].each do |structure|
      products << (Product.from_hash(structure) if structure)
    end
  end

  products = nil unless hash.key?('products')
  total_amount = hash.key?('totalAmount') ? hash['totalAmount'] : nil
  payment_method = hash.key?('paymentMethod') ? hash['paymentMethod'] : nil
  success_redirect =
    hash.key?('success_redirect') ? hash['success_redirect'] : nil
  failure_redirect =
    hash.key?('failure_redirect') ? hash['failure_redirect'] : nil
  pending_redirect =
    hash.key?('pending_redirect') ? hash['pending_redirect'] : nil
  success_callback =
    hash.key?('success_callback') ? hash['success_callback'] : nil
  failure_callback =
    hash.key?('failure_callback') ? hash['failure_callback'] : nil
  extra_param = ExtraParam20.from_hash(hash['extraParam']) if hash['extraParam']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PurchaseSessionRequest.new(customer_id: customer_id,
                             merchant_ref: merchant_ref,
                             currency: currency,
                             products: products,
                             total_amount: total_amount,
                             payment_method: payment_method,
                             success_redirect: success_redirect,
                             failure_redirect: failure_redirect,
                             pending_redirect: pending_redirect,
                             success_callback: success_callback,
                             failure_callback: failure_callback,
                             extra_param: extra_param,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 61

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['customer_id'] = 'customerId'
  @_hash['merchant_ref'] = 'merchantRef'
  @_hash['currency'] = 'currency'
  @_hash['products'] = 'products'
  @_hash['total_amount'] = 'totalAmount'
  @_hash['payment_method'] = 'paymentMethod'
  @_hash['success_redirect'] = 'success_redirect'
  @_hash['failure_redirect'] = 'failure_redirect'
  @_hash['pending_redirect'] = 'pending_redirect'
  @_hash['success_callback'] = 'success_callback'
  @_hash['failure_callback'] = 'failure_callback'
  @_hash['extra_param'] = 'extraParam'
  @_hash
end

.nullablesObject

An array for nullable fields



84
85
86
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 84

def self.nullables
  []
end

.optionalsObject

An array for optional fields



79
80
81
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 79

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



177
178
179
180
181
182
183
184
185
186
187
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 177

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id.inspect}, merchant_ref:"\
  " #{@merchant_ref.inspect}, currency: #{@currency.inspect}, products: #{@products.inspect},"\
  " total_amount: #{@total_amount.inspect}, payment_method: #{@payment_method.inspect},"\
  " success_redirect: #{@success_redirect.inspect}, failure_redirect:"\
  " #{@failure_redirect.inspect}, pending_redirect: #{@pending_redirect.inspect},"\
  " success_callback: #{@success_callback.inspect}, failure_callback:"\
  " #{@failure_callback.inspect}, extra_param: #{@extra_param.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



166
167
168
169
170
171
172
173
174
# File 'lib/paysecure_api_documentation_live/models/purchase_session_request.rb', line 166

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id}, merchant_ref: #{@merchant_ref}, currency:"\
  " #{@currency}, products: #{@products}, total_amount: #{@total_amount}, payment_method:"\
  " #{@payment_method}, success_redirect: #{@success_redirect}, failure_redirect:"\
  " #{@failure_redirect}, pending_redirect: #{@pending_redirect}, success_callback:"\
  " #{@success_callback}, failure_callback: #{@failure_callback}, extra_param:"\
  " #{@extra_param}, additional_properties: #{@additional_properties}>"
end