Class: PaysecureApiDocumentationLive::PurchasesDecryptedFlowRequest1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::PurchasesDecryptedFlowRequest1
- Defined in:
- lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb
Overview
PurchasesDecryptedFlowRequest1 Model.
Instance Attribute Summary collapse
-
#brand_id ⇒ String
TODO: Write general description for this method.
-
#client ⇒ Client57
TODO: Write general description for this method.
-
#extra_param ⇒ ExtraParam5
TODO: Write general description for this method.
-
#failure_redirect ⇒ String
TODO: Write general description for this method.
-
#payment_method ⇒ String
TODO: Write general description for this method.
-
#pending_redirect ⇒ String
TODO: Write general description for this method.
-
#purchase ⇒ Purchase
TODO: Write general description for this method.
-
#success_redirect ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client:, purchase:, payment_method:, brand_id:, success_redirect:, pending_redirect:, failure_redirect:, extra_param:, additional_properties: nil) ⇒ PurchasesDecryptedFlowRequest1
constructor
A new instance of PurchasesDecryptedFlowRequest1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client:, purchase:, payment_method:, brand_id:, success_redirect:, pending_redirect:, failure_redirect:, extra_param:, additional_properties: nil) ⇒ PurchasesDecryptedFlowRequest1
Returns a new instance of PurchasesDecryptedFlowRequest1.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 68 def initialize(client:, purchase:, payment_method:, brand_id:, success_redirect:, pending_redirect:, failure_redirect:, extra_param:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client = client @purchase = purchase @payment_method = payment_method @brand_id = brand_id @success_redirect = success_redirect @pending_redirect = pending_redirect @failure_redirect = failure_redirect @extra_param = extra_param @additional_properties = additional_properties end |
Instance Attribute Details
#brand_id ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 26 def brand_id @brand_id end |
#client ⇒ Client57
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 14 def client @client end |
#extra_param ⇒ ExtraParam5
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 42 def extra_param @extra_param end |
#failure_redirect ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 38 def failure_redirect @failure_redirect end |
#payment_method ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 22 def payment_method @payment_method end |
#pending_redirect ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 34 def pending_redirect @pending_redirect end |
#purchase ⇒ Purchase
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 18 def purchase @purchase end |
#success_redirect ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 30 def success_redirect @success_redirect end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 86 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client = Client57.from_hash(hash['client']) if hash['client'] purchase = Purchase.from_hash(hash['purchase']) if hash['purchase'] payment_method = hash.key?('paymentMethod') ? hash['paymentMethod'] : nil brand_id = hash.key?('brand_id') ? hash['brand_id'] : nil success_redirect = hash.key?('success_redirect') ? hash['success_redirect'] : nil pending_redirect = hash.key?('pending_redirect') ? hash['pending_redirect'] : nil failure_redirect = hash.key?('failure_redirect') ? hash['failure_redirect'] : nil extra_param = ExtraParam5.from_hash(hash['extraParam']) if hash['extraParam'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PurchasesDecryptedFlowRequest1.new(client: client, purchase: purchase, payment_method: payment_method, brand_id: brand_id, success_redirect: success_redirect, pending_redirect: pending_redirect, failure_redirect: failure_redirect, extra_param: extra_param, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['client'] = 'client' @_hash['purchase'] = 'purchase' @_hash['payment_method'] = 'paymentMethod' @_hash['brand_id'] = 'brand_id' @_hash['success_redirect'] = 'success_redirect' @_hash['pending_redirect'] = 'pending_redirect' @_hash['failure_redirect'] = 'failure_redirect' @_hash['extra_param'] = 'extraParam' @_hash end |
.nullables ⇒ Object
An array for nullable fields
64 65 66 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 64 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 59 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
131 132 133 134 135 136 137 138 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 131 def inspect class_name = self.class.name.split('::').last "<#{class_name} client: #{@client.inspect}, purchase: #{@purchase.inspect}, payment_method:"\ " #{@payment_method.inspect}, brand_id: #{@brand_id.inspect}, success_redirect:"\ " #{@success_redirect.inspect}, pending_redirect: #{@pending_redirect.inspect},"\ " failure_redirect: #{@failure_redirect.inspect}, extra_param: #{@extra_param.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
122 123 124 125 126 127 128 |
# File 'lib/paysecure_api_documentation_live/models/purchases_decrypted_flow_request1.rb', line 122 def to_s class_name = self.class.name.split('::').last "<#{class_name} client: #{@client}, purchase: #{@purchase}, payment_method:"\ " #{@payment_method}, brand_id: #{@brand_id}, success_redirect: #{@success_redirect},"\ " pending_redirect: #{@pending_redirect}, failure_redirect: #{@failure_redirect},"\ " extra_param: #{@extra_param}, additional_properties: #{@additional_properties}>" end |