Class: PaysecureApiDocumentationLive::RefundErrorException

Inherits:
APIException
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/exceptions/refund_error_exception.rb

Overview

Refund - Error class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ RefundErrorException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



23
24
25
26
27
# File 'lib/paysecure_api_documentation_live/exceptions/refund_error_exception.rb', line 23

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#codeString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/exceptions/refund_error_exception.rb', line 18

def code
  @code
end

#messageString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/exceptions/refund_error_exception.rb', line 14

def message
  @message
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



46
47
48
49
# File 'lib/paysecure_api_documentation_live/exceptions/refund_error_exception.rb', line 46

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} message: #{@message.inspect}, code: #{@code.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



40
41
42
43
# File 'lib/paysecure_api_documentation_live/exceptions/refund_error_exception.rb', line 40

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} message: #{@message}, code: #{@code}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



32
33
34
35
36
37
# File 'lib/paysecure_api_documentation_live/exceptions/refund_error_exception.rb', line 32

def unbox(hash)
  return nil unless hash

  @message = hash.key?('message') ? hash['message'] : nil
  @code = hash.key?('code') ? hash['code'] : nil
end