Class: PaysecureApiDocumentationLive::Settlement
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Settlement
- Defined in:
- lib/paysecure_api_documentation_live/models/settlement.rb
Overview
Settlement Model.
Instance Attribute Summary collapse
-
#amount ⇒ Integer
TODO: Write general description for this method.
-
#currency ⇒ String
TODO: Write general description for this method.
-
#settled_on ⇒ Integer
TODO: Write general description for this method.
-
#settlement_id ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(settlement_id:, amount:, currency:, status:, settled_on:, additional_properties: nil) ⇒ Settlement
constructor
A new instance of Settlement.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(settlement_id:, amount:, currency:, status:, settled_on:, additional_properties: nil) ⇒ Settlement
Returns a new instance of Settlement.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 53 def initialize(settlement_id:, amount:, currency:, status:, settled_on:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @settlement_id = settlement_id @amount = amount @currency = currency @status = status @settled_on = settled_on @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 18 def amount @amount end |
#currency ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 22 def currency @currency end |
#settled_on ⇒ Integer
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 30 def settled_on @settled_on end |
#settlement_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 14 def settlement_id @settlement_id end |
#status ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 26 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. settlement_id = hash.key?('settlementId') ? hash['settlementId'] : nil amount = hash.key?('amount') ? hash['amount'] : nil currency = hash.key?('currency') ? hash['currency'] : nil status = hash.key?('status') ? hash['status'] : nil settled_on = hash.key?('settledOn') ? hash['settledOn'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Settlement.new(settlement_id: settlement_id, amount: amount, currency: currency, status: status, settled_on: settled_on, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['settlement_id'] = 'settlementId' @_hash['amount'] = 'amount' @_hash['currency'] = 'currency' @_hash['status'] = 'status' @_hash['settled_on'] = 'settledOn' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 107 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} settlement_id: #{@settlement_id.inspect}, amount: #{@amount.inspect},"\ " currency: #{@currency.inspect}, status: #{@status.inspect}, settled_on:"\ " #{@settled_on.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 99 |
# File 'lib/paysecure_api_documentation_live/models/settlement.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} settlement_id: #{@settlement_id}, amount: #{@amount}, currency:"\ " #{@currency}, status: #{@status}, settled_on: #{@settled_on}, additional_properties:"\ " #{@additional_properties}>" end |