Class: PaysecureApiDocumentationLive::Success2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Success2
- Defined in:
- lib/paysecure_api_documentation_live/models/success2.rb
Overview
Success2 Model.
Instance Attribute Summary collapse
-
#brand_id ⇒ String
TODO: Write general description for this method.
-
#cancel_redirect ⇒ String
TODO: Write general description for this method.
-
#cc_descriptor ⇒ String
TODO: Write general description for this method.
-
#checkout_url ⇒ String
TODO: Write general description for this method.
-
#client ⇒ Client6
TODO: Write general description for this method.
-
#created_from_ip ⇒ String
TODO: Write general description for this method.
-
#created_on ⇒ Integer
TODO: Write general description for this method.
-
#direct_post_url ⇒ String
TODO: Write general description for this method.
-
#due ⇒ Integer
TODO: Write general description for this method.
-
#failure_redirect ⇒ String
TODO: Write general description for this method.
-
#force_recurring ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#is_recurring_token ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#is_test ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#issued ⇒ String
TODO: Write general description for this method.
-
#issuer_details ⇒ IssuerDetails1
TODO: Write general description for this method.
-
#platform ⇒ String
TODO: Write general description for this method.
-
#purchase ⇒ Purchase2
TODO: Write general description for this method.
-
#purchase_id ⇒ String
TODO: Write general description for this method.
-
#reference_generated ⇒ String
TODO: Write general description for this method.
-
#refund_availability ⇒ String
TODO: Write general description for this method.
-
#refund_upto ⇒ Integer
TODO: Write general description for this method.
-
#refundable_amount ⇒ Integer
TODO: Write general description for this method.
-
#send_receipt ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#skip_capture ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
-
#status_history ⇒ Array[StatusHistory]
TODO: Write general description for this method.
-
#success_callback ⇒ String
TODO: Write general description for this method.
-
#success_redirect ⇒ String
TODO: Write general description for this method.
-
#transaction_data ⇒ TransactionData
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
-
#updated_on ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(purchase_id:, client:, updated_on:, type:, force_recurring:, created_on:, purchase:, issuer_details:, transaction_data:, status:, status_history:, is_test:, brand_id:, send_receipt:, is_recurring_token:, skip_capture:, reference_generated:, issued:, due:, refund_upto:, cc_descriptor:, refund_availability:, refundable_amount:, success_redirect:, failure_redirect:, cancel_redirect:, success_callback:, platform:, created_from_ip:, checkout_url:, direct_post_url:, additional_properties: nil) ⇒ Success2
constructor
A new instance of Success2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(purchase_id:, client:, updated_on:, type:, force_recurring:, created_on:, purchase:, issuer_details:, transaction_data:, status:, status_history:, is_test:, brand_id:, send_receipt:, is_recurring_token:, skip_capture:, reference_generated:, issued:, due:, refund_upto:, cc_descriptor:, refund_availability:, refundable_amount:, success_redirect:, failure_redirect:, cancel_redirect:, success_callback:, platform:, created_from_ip:, checkout_url:, direct_post_url:, additional_properties: nil) ⇒ Success2
Returns a new instance of Success2.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 183 def initialize(purchase_id:, client:, updated_on:, type:, force_recurring:, created_on:, purchase:, issuer_details:, transaction_data:, status:, status_history:, is_test:, brand_id:, send_receipt:, is_recurring_token:, skip_capture:, reference_generated:, issued:, due:, refund_upto:, cc_descriptor:, refund_availability:, refundable_amount:, success_redirect:, failure_redirect:, cancel_redirect:, success_callback:, platform:, created_from_ip:, checkout_url:, direct_post_url:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @purchase_id = purchase_id @client = client @updated_on = updated_on @type = type @force_recurring = force_recurring @created_on = created_on @purchase = purchase @issuer_details = issuer_details @transaction_data = transaction_data @status = status @status_history = status_history @is_test = is_test @brand_id = brand_id @send_receipt = send_receipt @is_recurring_token = is_recurring_token @skip_capture = skip_capture @reference_generated = reference_generated @issued = issued @due = due @refund_upto = refund_upto @cc_descriptor = cc_descriptor @refund_availability = refund_availability @refundable_amount = refundable_amount @success_redirect = success_redirect @failure_redirect = failure_redirect @cancel_redirect = cancel_redirect @success_callback = success_callback @platform = platform @created_from_ip = created_from_ip @checkout_url = checkout_url @direct_post_url = direct_post_url @additional_properties = additional_properties end |
Instance Attribute Details
#brand_id ⇒ String
TODO: Write general description for this method
62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 62 def brand_id @brand_id end |
#cancel_redirect ⇒ String
TODO: Write general description for this method
114 115 116 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 114 def cancel_redirect @cancel_redirect end |
#cc_descriptor ⇒ String
TODO: Write general description for this method
94 95 96 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 94 def cc_descriptor @cc_descriptor end |
#checkout_url ⇒ String
TODO: Write general description for this method
130 131 132 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 130 def checkout_url @checkout_url end |
#client ⇒ Client6
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 18 def client @client end |
#created_from_ip ⇒ String
TODO: Write general description for this method
126 127 128 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 126 def created_from_ip @created_from_ip end |
#created_on ⇒ Integer
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 34 def created_on @created_on end |
#direct_post_url ⇒ String
TODO: Write general description for this method
134 135 136 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 134 def direct_post_url @direct_post_url end |
#due ⇒ Integer
TODO: Write general description for this method
86 87 88 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 86 def due @due end |
#failure_redirect ⇒ String
TODO: Write general description for this method
110 111 112 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 110 def failure_redirect @failure_redirect end |
#force_recurring ⇒ TrueClass | FalseClass
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 30 def force_recurring @force_recurring end |
#is_recurring_token ⇒ TrueClass | FalseClass
TODO: Write general description for this method
70 71 72 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 70 def is_recurring_token @is_recurring_token end |
#is_test ⇒ TrueClass | FalseClass
TODO: Write general description for this method
58 59 60 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 58 def is_test @is_test end |
#issued ⇒ String
TODO: Write general description for this method
82 83 84 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 82 def issued @issued end |
#issuer_details ⇒ IssuerDetails1
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 42 def issuer_details @issuer_details end |
#platform ⇒ String
TODO: Write general description for this method
122 123 124 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 122 def platform @platform end |
#purchase ⇒ Purchase2
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 38 def purchase @purchase end |
#purchase_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 14 def purchase_id @purchase_id end |
#reference_generated ⇒ String
TODO: Write general description for this method
78 79 80 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 78 def reference_generated @reference_generated end |
#refund_availability ⇒ String
TODO: Write general description for this method
98 99 100 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 98 def refund_availability @refund_availability end |
#refund_upto ⇒ Integer
TODO: Write general description for this method
90 91 92 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 90 def refund_upto @refund_upto end |
#refundable_amount ⇒ Integer
TODO: Write general description for this method
102 103 104 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 102 def refundable_amount @refundable_amount end |
#send_receipt ⇒ TrueClass | FalseClass
TODO: Write general description for this method
66 67 68 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 66 def send_receipt @send_receipt end |
#skip_capture ⇒ TrueClass | FalseClass
TODO: Write general description for this method
74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 74 def skip_capture @skip_capture end |
#status ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 50 def status @status end |
#status_history ⇒ Array[StatusHistory]
TODO: Write general description for this method
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 54 def status_history @status_history end |
#success_callback ⇒ String
TODO: Write general description for this method
118 119 120 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 118 def success_callback @success_callback end |
#success_redirect ⇒ String
TODO: Write general description for this method
106 107 108 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 106 def success_redirect @success_redirect end |
#transaction_data ⇒ TransactionData
TODO: Write general description for this method
46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 46 def transaction_data @transaction_data end |
#type ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 26 def type @type end |
#updated_on ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 22 def updated_on @updated_on end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 230 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. purchase_id = hash.key?('purchaseId') ? hash['purchaseId'] : nil client = Client6.from_hash(hash['client']) if hash['client'] updated_on = hash.key?('updated_on') ? hash['updated_on'] : nil type = hash.key?('type') ? hash['type'] : nil force_recurring = hash.key?('force_recurring') ? hash['force_recurring'] : nil created_on = hash.key?('created_on') ? hash['created_on'] : nil purchase = Purchase2.from_hash(hash['purchase']) if hash['purchase'] issuer_details = IssuerDetails1.from_hash(hash['issuer_details']) if hash['issuer_details'] transaction_data = TransactionData.from_hash(hash['transaction_data']) if hash['transaction_data'] status = hash.key?('status') ? hash['status'] : nil # Parameter is an array, so we need to iterate through it status_history = nil unless hash['status_history'].nil? status_history = [] hash['status_history'].each do |structure| status_history << (StatusHistory.from_hash(structure) if structure) end end status_history = nil unless hash.key?('status_history') is_test = hash.key?('is_test') ? hash['is_test'] : nil brand_id = hash.key?('brand_id') ? hash['brand_id'] : nil send_receipt = hash.key?('send_receipt') ? hash['send_receipt'] : nil is_recurring_token = hash.key?('is_recurring_token') ? hash['is_recurring_token'] : nil skip_capture = hash.key?('skip_capture') ? hash['skip_capture'] : nil reference_generated = hash.key?('reference_generated') ? hash['reference_generated'] : nil issued = hash.key?('issued') ? hash['issued'] : nil due = hash.key?('due') ? hash['due'] : nil refund_upto = hash.key?('refund_upto') ? hash['refund_upto'] : nil cc_descriptor = hash.key?('cc_descriptor') ? hash['cc_descriptor'] : nil refund_availability = hash.key?('refund_availability') ? hash['refund_availability'] : nil refundable_amount = hash.key?('refundable_amount') ? hash['refundable_amount'] : nil success_redirect = hash.key?('success_redirect') ? hash['success_redirect'] : nil failure_redirect = hash.key?('failure_redirect') ? hash['failure_redirect'] : nil cancel_redirect = hash.key?('cancel_redirect') ? hash['cancel_redirect'] : nil success_callback = hash.key?('success_callback') ? hash['success_callback'] : nil platform = hash.key?('platform') ? hash['platform'] : nil created_from_ip = hash.key?('created_from_ip') ? hash['created_from_ip'] : nil checkout_url = hash.key?('checkout_url') ? hash['checkout_url'] : nil direct_post_url = hash.key?('direct_post_url') ? hash['direct_post_url'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Success2.new(purchase_id: purchase_id, client: client, updated_on: updated_on, type: type, force_recurring: force_recurring, created_on: created_on, purchase: purchase, issuer_details: issuer_details, transaction_data: transaction_data, status: status, status_history: status_history, is_test: is_test, brand_id: brand_id, send_receipt: send_receipt, is_recurring_token: is_recurring_token, skip_capture: skip_capture, reference_generated: reference_generated, issued: issued, due: due, refund_upto: refund_upto, cc_descriptor: cc_descriptor, refund_availability: refund_availability, refundable_amount: refundable_amount, success_redirect: success_redirect, failure_redirect: failure_redirect, cancel_redirect: cancel_redirect, success_callback: success_callback, platform: platform, created_from_ip: created_from_ip, checkout_url: checkout_url, direct_post_url: direct_post_url, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 137 def self.names @_hash = {} if @_hash.nil? @_hash['purchase_id'] = 'purchaseId' @_hash['client'] = 'client' @_hash['updated_on'] = 'updated_on' @_hash['type'] = 'type' @_hash['force_recurring'] = 'force_recurring' @_hash['created_on'] = 'created_on' @_hash['purchase'] = 'purchase' @_hash['issuer_details'] = 'issuer_details' @_hash['transaction_data'] = 'transaction_data' @_hash['status'] = 'status' @_hash['status_history'] = 'status_history' @_hash['is_test'] = 'is_test' @_hash['brand_id'] = 'brand_id' @_hash['send_receipt'] = 'send_receipt' @_hash['is_recurring_token'] = 'is_recurring_token' @_hash['skip_capture'] = 'skip_capture' @_hash['reference_generated'] = 'reference_generated' @_hash['issued'] = 'issued' @_hash['due'] = 'due' @_hash['refund_upto'] = 'refund_upto' @_hash['cc_descriptor'] = 'cc_descriptor' @_hash['refund_availability'] = 'refund_availability' @_hash['refundable_amount'] = 'refundable_amount' @_hash['success_redirect'] = 'success_redirect' @_hash['failure_redirect'] = 'failure_redirect' @_hash['cancel_redirect'] = 'cancel_redirect' @_hash['success_callback'] = 'success_callback' @_hash['platform'] = 'platform' @_hash['created_from_ip'] = 'created_from_ip' @_hash['checkout_url'] = 'checkout_url' @_hash['direct_post_url'] = 'direct_post_url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
179 180 181 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 179 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
174 175 176 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 174 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 348 def inspect class_name = self.class.name.split('::').last "<#{class_name} purchase_id: #{@purchase_id.inspect}, client: #{@client.inspect},"\ " updated_on: #{@updated_on.inspect}, type: #{@type.inspect}, force_recurring:"\ " #{@force_recurring.inspect}, created_on: #{@created_on.inspect}, purchase:"\ " #{@purchase.inspect}, issuer_details: #{@issuer_details.inspect}, transaction_data:"\ " #{@transaction_data.inspect}, status: #{@status.inspect}, status_history:"\ " #{@status_history.inspect}, is_test: #{@is_test.inspect}, brand_id: #{@brand_id.inspect},"\ " send_receipt: #{@send_receipt.inspect}, is_recurring_token:"\ " #{@is_recurring_token.inspect}, skip_capture: #{@skip_capture.inspect},"\ " reference_generated: #{@reference_generated.inspect}, issued: #{@issued.inspect}, due:"\ " #{@due.inspect}, refund_upto: #{@refund_upto.inspect}, cc_descriptor:"\ " #{@cc_descriptor.inspect}, refund_availability: #{@refund_availability.inspect},"\ " refundable_amount: #{@refundable_amount.inspect}, success_redirect:"\ " #{@success_redirect.inspect}, failure_redirect: #{@failure_redirect.inspect},"\ " cancel_redirect: #{@cancel_redirect.inspect}, success_callback:"\ " #{@success_callback.inspect}, platform: #{@platform.inspect}, created_from_ip:"\ " #{@created_from_ip.inspect}, checkout_url: #{@checkout_url.inspect}, direct_post_url:"\ " #{@direct_post_url.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/paysecure_api_documentation_live/models/success2.rb', line 330 def to_s class_name = self.class.name.split('::').last "<#{class_name} purchase_id: #{@purchase_id}, client: #{@client}, updated_on:"\ " #{@updated_on}, type: #{@type}, force_recurring: #{@force_recurring}, created_on:"\ " #{@created_on}, purchase: #{@purchase}, issuer_details: #{@issuer_details},"\ " transaction_data: #{@transaction_data}, status: #{@status}, status_history:"\ " #{@status_history}, is_test: #{@is_test}, brand_id: #{@brand_id}, send_receipt:"\ " #{@send_receipt}, is_recurring_token: #{@is_recurring_token}, skip_capture:"\ " #{@skip_capture}, reference_generated: #{@reference_generated}, issued: #{@issued}, due:"\ " #{@due}, refund_upto: #{@refund_upto}, cc_descriptor: #{@cc_descriptor},"\ " refund_availability: #{@refund_availability}, refundable_amount: #{@refundable_amount},"\ " success_redirect: #{@success_redirect}, failure_redirect: #{@failure_redirect},"\ " cancel_redirect: #{@cancel_redirect}, success_callback: #{@success_callback}, platform:"\ " #{@platform}, created_from_ip: #{@created_from_ip}, checkout_url: #{@checkout_url},"\ " direct_post_url: #{@direct_post_url}, additional_properties: #{@additional_properties}>" end |