Class: PaysecureApiDocumentationLive::Success21

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/success21.rb

Overview

Success21 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(payout_id:, client:, updated_on:, payout_method:, amount_unit:, amount:, error_msg:, purpose:, created_on:, merchant_ref:, status:, status_history:, currency:, payment_on:, tax_amount:, tax_percent:, redirect_type:, extra_param:, success_callback:, failure_callback:, additional_properties: nil) ⇒ Success21

Returns a new instance of Success21.



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 128

def initialize(payout_id:, client:, updated_on:, payout_method:,
               amount_unit:, amount:, error_msg:, purpose:, created_on:,
               merchant_ref:, status:, status_history:, currency:,
               payment_on:, tax_amount:, tax_percent:, redirect_type:,
               extra_param:, success_callback:, failure_callback:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @payout_id = payout_id
  @client = client
  @updated_on = updated_on
  @payout_method = payout_method
  @amount_unit = amount_unit
  @amount = amount
  @error_msg = error_msg
  @purpose = purpose
  @created_on = created_on
  @merchant_ref = merchant_ref
  @status = status
  @status_history = status_history
  @currency = currency
  @payment_on = payment_on
  @tax_amount = tax_amount
  @tax_percent = tax_percent
  @redirect_type = redirect_type
  @extra_param = extra_param
  @success_callback = success_callback
  @failure_callback = failure_callback
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountFloat

TODO: Write general description for this method

Returns:

  • (Float)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 34

def amount
  @amount
end

#amount_unitString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 30

def amount_unit
  @amount_unit
end

#clientClient80

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 18

def client
  @client
end

#created_onInteger

TODO: Write general description for this method

Returns:

  • (Integer)


46
47
48
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 46

def created_on
  @created_on
end

#currencyString

TODO: Write general description for this method

Returns:

  • (String)


62
63
64
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 62

def currency
  @currency
end

#error_msgString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 38

def error_msg
  @error_msg
end

#extra_paramExtraParam13

TODO: Write general description for this method

Returns:



82
83
84
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 82

def extra_param
  @extra_param
end

#failure_callbackString

TODO: Write general description for this method

Returns:

  • (String)


90
91
92
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 90

def failure_callback
  @failure_callback
end

#merchant_refString

TODO: Write general description for this method

Returns:

  • (String)


50
51
52
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 50

def merchant_ref
  @merchant_ref
end

#payment_onInteger

TODO: Write general description for this method

Returns:

  • (Integer)


66
67
68
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 66

def payment_on
  @payment_on
end

#payout_idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 14

def payout_id
  @payout_id
end

#payout_methodString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 26

def payout_method
  @payout_method
end

#purposeString

TODO: Write general description for this method

Returns:

  • (String)


42
43
44
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 42

def purpose
  @purpose
end

#redirect_typeString

TODO: Write general description for this method

Returns:

  • (String)


78
79
80
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 78

def redirect_type
  @redirect_type
end

#statusString

TODO: Write general description for this method

Returns:

  • (String)


54
55
56
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 54

def status
  @status
end

#status_historyArray[StatusHistory]

TODO: Write general description for this method

Returns:



58
59
60
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 58

def status_history
  @status_history
end

#success_callbackString

TODO: Write general description for this method

Returns:

  • (String)


86
87
88
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 86

def success_callback
  @success_callback
end

#tax_amountFloat

TODO: Write general description for this method

Returns:

  • (Float)


70
71
72
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 70

def tax_amount
  @tax_amount
end

#tax_percentFloat

TODO: Write general description for this method

Returns:

  • (Float)


74
75
76
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 74

def tax_percent
  @tax_percent
end

#updated_onInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 22

def updated_on
  @updated_on
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 161

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  payout_id = hash.key?('payoutId') ? hash['payoutId'] : nil
  client = Client80.from_hash(hash['client']) if hash['client']
  updated_on = hash.key?('updated_on') ? hash['updated_on'] : nil
  payout_method = hash.key?('payoutMethod') ? hash['payoutMethod'] : nil
  amount_unit = hash.key?('amountUnit') ? hash['amountUnit'] : nil
  amount = hash.key?('amount') ? hash['amount'] : nil
  error_msg = hash.key?('errorMsg') ? hash['errorMsg'] : nil
  purpose = hash.key?('purpose') ? hash['purpose'] : nil
  created_on = hash.key?('created_on') ? hash['created_on'] : nil
  merchant_ref = hash.key?('merchantRef') ? hash['merchantRef'] : nil
  status = hash.key?('status') ? hash['status'] : nil
  # Parameter is an array, so we need to iterate through it
  status_history = nil
  unless hash['status_history'].nil?
    status_history = []
    hash['status_history'].each do |structure|
      status_history << (StatusHistory.from_hash(structure) if structure)
    end
  end

  status_history = nil unless hash.key?('status_history')
  currency = hash.key?('currency') ? hash['currency'] : nil
  payment_on = hash.key?('paymentOn') ? hash['paymentOn'] : nil
  tax_amount = hash.key?('taxAmount') ? hash['taxAmount'] : nil
  tax_percent = hash.key?('taxPercent') ? hash['taxPercent'] : nil
  redirect_type = hash.key?('redirectType') ? hash['redirectType'] : nil
  extra_param = ExtraParam13.from_hash(hash['extraParam']) if hash['extraParam']
  success_callback =
    hash.key?('success_callback') ? hash['success_callback'] : nil
  failure_callback =
    hash.key?('failure_callback') ? hash['failure_callback'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Success21.new(payout_id: payout_id,
                client: client,
                updated_on: updated_on,
                payout_method: payout_method,
                amount_unit: amount_unit,
                amount: amount,
                error_msg: error_msg,
                purpose: purpose,
                created_on: created_on,
                merchant_ref: merchant_ref,
                status: status,
                status_history: status_history,
                currency: currency,
                payment_on: payment_on,
                tax_amount: tax_amount,
                tax_percent: tax_percent,
                redirect_type: redirect_type,
                extra_param: extra_param,
                success_callback: success_callback,
                failure_callback: failure_callback,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 93

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['payout_id'] = 'payoutId'
  @_hash['client'] = 'client'
  @_hash['updated_on'] = 'updated_on'
  @_hash['payout_method'] = 'payoutMethod'
  @_hash['amount_unit'] = 'amountUnit'
  @_hash['amount'] = 'amount'
  @_hash['error_msg'] = 'errorMsg'
  @_hash['purpose'] = 'purpose'
  @_hash['created_on'] = 'created_on'
  @_hash['merchant_ref'] = 'merchantRef'
  @_hash['status'] = 'status'
  @_hash['status_history'] = 'status_history'
  @_hash['currency'] = 'currency'
  @_hash['payment_on'] = 'paymentOn'
  @_hash['tax_amount'] = 'taxAmount'
  @_hash['tax_percent'] = 'taxPercent'
  @_hash['redirect_type'] = 'redirectType'
  @_hash['extra_param'] = 'extraParam'
  @_hash['success_callback'] = 'success_callback'
  @_hash['failure_callback'] = 'failure_callback'
  @_hash
end

.nullablesObject

An array for nullable fields



124
125
126
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 124

def self.nullables
  []
end

.optionalsObject

An array for optional fields



119
120
121
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 119

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 242

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} payout_id: #{@payout_id.inspect}, client: #{@client.inspect}, updated_on:"\
  " #{@updated_on.inspect}, payout_method: #{@payout_method.inspect}, amount_unit:"\
  " #{@amount_unit.inspect}, amount: #{@amount.inspect}, error_msg: #{@error_msg.inspect},"\
  " purpose: #{@purpose.inspect}, created_on: #{@created_on.inspect}, merchant_ref:"\
  " #{@merchant_ref.inspect}, status: #{@status.inspect}, status_history:"\
  " #{@status_history.inspect}, currency: #{@currency.inspect}, payment_on:"\
  " #{@payment_on.inspect}, tax_amount: #{@tax_amount.inspect}, tax_percent:"\
  " #{@tax_percent.inspect}, redirect_type: #{@redirect_type.inspect}, extra_param:"\
  " #{@extra_param.inspect}, success_callback: #{@success_callback.inspect}, failure_callback:"\
  " #{@failure_callback.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



229
230
231
232
233
234
235
236
237
238
239
# File 'lib/paysecure_api_documentation_live/models/success21.rb', line 229

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} payout_id: #{@payout_id}, client: #{@client}, updated_on: #{@updated_on},"\
  " payout_method: #{@payout_method}, amount_unit: #{@amount_unit}, amount: #{@amount},"\
  " error_msg: #{@error_msg}, purpose: #{@purpose}, created_on: #{@created_on}, merchant_ref:"\
  " #{@merchant_ref}, status: #{@status}, status_history: #{@status_history}, currency:"\
  " #{@currency}, payment_on: #{@payment_on}, tax_amount: #{@tax_amount}, tax_percent:"\
  " #{@tax_percent}, redirect_type: #{@redirect_type}, extra_param: #{@extra_param},"\
  " success_callback: #{@success_callback}, failure_callback: #{@failure_callback},"\
  " additional_properties: #{@additional_properties}>"
end