Class: PaysecureApiDocumentationLive::Success32

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/success32.rb

Overview

Success32 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(session_url:, brand_id:, customer_id:, session_id:, expiry_on:, created_on:, expiry_in_mins:, additional_properties: nil) ⇒ Success32

Returns a new instance of Success32.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 63

def initialize(session_url:, brand_id:, customer_id:, session_id:,
               expiry_on:, created_on:, expiry_in_mins:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @session_url = session_url
  @brand_id = brand_id
  @customer_id = customer_id
  @session_id = session_id
  @expiry_on = expiry_on
  @created_on = created_on
  @expiry_in_mins = expiry_in_mins
  @additional_properties = additional_properties
end

Instance Attribute Details

#brand_idString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 18

def brand_id
  @brand_id
end

#created_onInteger

TODO: Write general description for this method

Returns:

  • (Integer)


34
35
36
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 34

def created_on
  @created_on
end

#customer_idString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 22

def customer_id
  @customer_id
end

#expiry_in_minsString

TODO: Write general description for this method

Returns:

  • (String)


38
39
40
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 38

def expiry_in_mins
  @expiry_in_mins
end

#expiry_onInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 30

def expiry_on
  @expiry_on
end

#session_idString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 26

def session_id
  @session_id
end

#session_urlString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 14

def session_url
  @session_url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 80

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  session_url = hash.key?('sessionUrl') ? hash['sessionUrl'] : nil
  brand_id = hash.key?('brandId') ? hash['brandId'] : nil
  customer_id = hash.key?('customerId') ? hash['customerId'] : nil
  session_id = hash.key?('sessionId') ? hash['sessionId'] : nil
  expiry_on = hash.key?('expiryOn') ? hash['expiryOn'] : nil
  created_on = hash.key?('createdOn') ? hash['createdOn'] : nil
  expiry_in_mins =
    hash.key?('expiry_in_mins') ? hash['expiry_in_mins'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Success32.new(session_url: session_url,
                brand_id: brand_id,
                customer_id: customer_id,
                session_id: session_id,
                expiry_on: expiry_on,
                created_on: created_on,
                expiry_in_mins: expiry_in_mins,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['session_url'] = 'sessionUrl'
  @_hash['brand_id'] = 'brandId'
  @_hash['customer_id'] = 'customerId'
  @_hash['session_id'] = 'sessionId'
  @_hash['expiry_on'] = 'expiryOn'
  @_hash['created_on'] = 'createdOn'
  @_hash['expiry_in_mins'] = 'expiry_in_mins'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 54

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



121
122
123
124
125
126
127
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 121

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} session_url: #{@session_url.inspect}, brand_id: #{@brand_id.inspect},"\
  " customer_id: #{@customer_id.inspect}, session_id: #{@session_id.inspect}, expiry_on:"\
  " #{@expiry_on.inspect}, created_on: #{@created_on.inspect}, expiry_in_mins:"\
  " #{@expiry_in_mins.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



112
113
114
115
116
117
118
# File 'lib/paysecure_api_documentation_live/models/success32.rb', line 112

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} session_url: #{@session_url}, brand_id: #{@brand_id}, customer_id:"\
  " #{@customer_id}, session_id: #{@session_id}, expiry_on: #{@expiry_on}, created_on:"\
  " #{@created_on}, expiry_in_mins: #{@expiry_in_mins}, additional_properties:"\
  " #{@additional_properties}>"
end