Class: PaysecureApiDocumentationLive::Success39
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Success39
- Defined in:
- lib/paysecure_api_documentation_live/models/success39.rb
Overview
Success39 Model.
Instance Attribute Summary collapse
-
#mandate_id ⇒ String
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#revoke_date ⇒ Integer
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mandate_id:, message:, revoke_date:, status:, additional_properties: nil) ⇒ Success39
constructor
A new instance of Success39.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mandate_id:, message:, revoke_date:, status:, additional_properties: nil) ⇒ Success39
Returns a new instance of Success39.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/paysecure_api_documentation_live/models/success39.rb', line 48 def initialize(mandate_id:, message:, revoke_date:, status:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mandate_id = mandate_id @message = @revoke_date = revoke_date @status = status @additional_properties = additional_properties end |
Instance Attribute Details
#mandate_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/success39.rb', line 14 def mandate_id @mandate_id end |
#message ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/success39.rb', line 18 def @message end |
#revoke_date ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/success39.rb', line 22 def revoke_date @revoke_date end |
#status ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/success39.rb', line 26 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/paysecure_api_documentation_live/models/success39.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mandate_id = hash.key?('mandateId') ? hash['mandateId'] : nil = hash.key?('message') ? hash['message'] : nil revoke_date = hash.key?('revokeDate') ? hash['revokeDate'] : nil status = hash.key?('status') ? hash['status'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Success39.new(mandate_id: mandate_id, message: , revoke_date: revoke_date, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/success39.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['mandate_id'] = 'mandateId' @_hash['message'] = 'message' @_hash['revoke_date'] = 'revokeDate' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/success39.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/success39.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/paysecure_api_documentation_live/models/success39.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} mandate_id: #{@mandate_id.inspect}, message: #{@message.inspect},"\ " revoke_date: #{@revoke_date.inspect}, status: #{@status.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/paysecure_api_documentation_live/models/success39.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} mandate_id: #{@mandate_id}, message: #{@message}, revoke_date:"\ " #{@revoke_date}, status: #{@status}, additional_properties: #{@additional_properties}>" end |