Class: PaysecureApiDocumentationLive::Success6
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Success6
- Defined in:
- lib/paysecure_api_documentation_live/models/success6.rb
Overview
Success6 Model.
Instance Attribute Summary collapse
-
#balance ⇒ String
TODO: Write general description for this method.
-
#currency ⇒ String
TODO: Write general description for this method.
-
#payment_method ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(currency:, balance:, payment_method:, status:, additional_properties: nil) ⇒ Success6
constructor
A new instance of Success6.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(currency:, balance:, payment_method:, status:, additional_properties: nil) ⇒ Success6
Returns a new instance of Success6.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/paysecure_api_documentation_live/models/success6.rb', line 48 def initialize(currency:, balance:, payment_method:, status:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @currency = currency @balance = balance @payment_method = payment_method @status = status @additional_properties = additional_properties end |
Instance Attribute Details
#balance ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/success6.rb', line 18 def balance @balance end |
#currency ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/success6.rb', line 14 def currency @currency end |
#payment_method ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/success6.rb', line 22 def payment_method @payment_method end |
#status ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/success6.rb', line 26 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/paysecure_api_documentation_live/models/success6.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. currency = hash.key?('currency') ? hash['currency'] : nil balance = hash.key?('balance') ? hash['balance'] : nil payment_method = hash.key?('paymentMethod') ? hash['paymentMethod'] : nil status = hash.key?('status') ? hash['status'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Success6.new(currency: currency, balance: balance, payment_method: payment_method, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/success6.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['currency'] = 'currency' @_hash['balance'] = 'balance' @_hash['payment_method'] = 'paymentMethod' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/success6.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/success6.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/paysecure_api_documentation_live/models/success6.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency.inspect}, balance: #{@balance.inspect},"\ " payment_method: #{@payment_method.inspect}, status: #{@status.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/paysecure_api_documentation_live/models/success6.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency}, balance: #{@balance}, payment_method:"\ " #{@payment_method}, status: #{@status}, additional_properties: #{@additional_properties}>" end |