Class: PaysecureApiDocumentationLive::Success8
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Success8
- Defined in:
- lib/paysecure_api_documentation_live/models/success8.rb
Overview
Success8 Model.
Instance Attribute Summary collapse
-
#amount ⇒ Float
TODO: Write general description for this method.
-
#amount_unit ⇒ String
TODO: Write general description for this method.
-
#client ⇒ Client29
TODO: Write general description for this method.
-
#created_on ⇒ Integer
TODO: Write general description for this method.
-
#currency ⇒ String
TODO: Write general description for this method.
-
#error_msg ⇒ String
TODO: Write general description for this method.
-
#failure_callback ⇒ String
TODO: Write general description for this method.
-
#failure_redirect ⇒ String
TODO: Write general description for this method.
-
#merchant_name ⇒ String
TODO: Write general description for this method.
-
#payout_id ⇒ String
TODO: Write general description for this method.
-
#payout_method ⇒ String
TODO: Write general description for this method.
-
#pending_redirect ⇒ String
TODO: Write general description for this method.
-
#purpose ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
-
#status_history ⇒ Array[StatusHistory]
TODO: Write general description for this method.
-
#success_callback ⇒ String
TODO: Write general description for this method.
-
#success_redirect ⇒ String
TODO: Write general description for this method.
-
#updated_on ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payout_id:, client:, updated_on:, payout_method:, amount_unit:, amount:, error_msg:, created_on:, merchant_name:, status:, status_history:, currency:, purpose:, success_redirect:, pending_redirect:, failure_redirect:, success_callback:, failure_callback:, additional_properties: nil) ⇒ Success8
constructor
A new instance of Success8.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payout_id:, client:, updated_on:, payout_method:, amount_unit:, amount:, error_msg:, created_on:, merchant_name:, status:, status_history:, currency:, purpose:, success_redirect:, pending_redirect:, failure_redirect:, success_callback:, failure_callback:, additional_properties: nil) ⇒ Success8
Returns a new instance of Success8.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 118 def initialize(payout_id:, client:, updated_on:, payout_method:, amount_unit:, amount:, error_msg:, created_on:, merchant_name:, status:, status_history:, currency:, purpose:, success_redirect:, pending_redirect:, failure_redirect:, success_callback:, failure_callback:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @payout_id = payout_id @client = client @updated_on = updated_on @payout_method = payout_method @amount_unit = amount_unit @amount = amount @error_msg = error_msg @created_on = created_on @merchant_name = merchant_name @status = status @status_history = status_history @currency = currency @purpose = purpose @success_redirect = success_redirect @pending_redirect = pending_redirect @failure_redirect = failure_redirect @success_callback = success_callback @failure_callback = failure_callback @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Float
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 34 def amount @amount end |
#amount_unit ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 30 def amount_unit @amount_unit end |
#client ⇒ Client29
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 18 def client @client end |
#created_on ⇒ Integer
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 42 def created_on @created_on end |
#currency ⇒ String
TODO: Write general description for this method
58 59 60 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 58 def currency @currency end |
#error_msg ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 38 def error_msg @error_msg end |
#failure_callback ⇒ String
TODO: Write general description for this method
82 83 84 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 82 def failure_callback @failure_callback end |
#failure_redirect ⇒ String
TODO: Write general description for this method
74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 74 def failure_redirect @failure_redirect end |
#merchant_name ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 46 def merchant_name @merchant_name end |
#payout_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 14 def payout_id @payout_id end |
#payout_method ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 26 def payout_method @payout_method end |
#pending_redirect ⇒ String
TODO: Write general description for this method
70 71 72 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 70 def pending_redirect @pending_redirect end |
#purpose ⇒ String
TODO: Write general description for this method
62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 62 def purpose @purpose end |
#status ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 50 def status @status end |
#status_history ⇒ Array[StatusHistory]
TODO: Write general description for this method
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 54 def status_history @status_history end |
#success_callback ⇒ String
TODO: Write general description for this method
78 79 80 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 78 def success_callback @success_callback end |
#success_redirect ⇒ String
TODO: Write general description for this method
66 67 68 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 66 def success_redirect @success_redirect end |
#updated_on ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 22 def updated_on @updated_on end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 149 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payout_id = hash.key?('payoutId') ? hash['payoutId'] : nil client = Client29.from_hash(hash['client']) if hash['client'] updated_on = hash.key?('updated_on') ? hash['updated_on'] : nil payout_method = hash.key?('payoutMethod') ? hash['payoutMethod'] : nil amount_unit = hash.key?('amountUnit') ? hash['amountUnit'] : nil amount = hash.key?('amount') ? hash['amount'] : nil error_msg = hash.key?('errorMsg') ? hash['errorMsg'] : nil created_on = hash.key?('created_on') ? hash['created_on'] : nil merchant_name = hash.key?('merchantName') ? hash['merchantName'] : nil status = hash.key?('status') ? hash['status'] : nil # Parameter is an array, so we need to iterate through it status_history = nil unless hash['status_history'].nil? status_history = [] hash['status_history'].each do |structure| status_history << (StatusHistory.from_hash(structure) if structure) end end status_history = nil unless hash.key?('status_history') currency = hash.key?('currency') ? hash['currency'] : nil purpose = hash.key?('purpose') ? hash['purpose'] : nil success_redirect = hash.key?('success_redirect') ? hash['success_redirect'] : nil pending_redirect = hash.key?('pending_redirect') ? hash['pending_redirect'] : nil failure_redirect = hash.key?('failure_redirect') ? hash['failure_redirect'] : nil success_callback = hash.key?('success_callback') ? hash['success_callback'] : nil failure_callback = hash.key?('failure_callback') ? hash['failure_callback'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Success8.new(payout_id: payout_id, client: client, updated_on: updated_on, payout_method: payout_method, amount_unit: amount_unit, amount: amount, error_msg: error_msg, created_on: created_on, merchant_name: merchant_name, status: status, status_history: status_history, currency: currency, purpose: purpose, success_redirect: success_redirect, pending_redirect: pending_redirect, failure_redirect: failure_redirect, success_callback: success_callback, failure_callback: failure_callback, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 85 def self.names @_hash = {} if @_hash.nil? @_hash['payout_id'] = 'payoutId' @_hash['client'] = 'client' @_hash['updated_on'] = 'updated_on' @_hash['payout_method'] = 'payoutMethod' @_hash['amount_unit'] = 'amountUnit' @_hash['amount'] = 'amount' @_hash['error_msg'] = 'errorMsg' @_hash['created_on'] = 'created_on' @_hash['merchant_name'] = 'merchantName' @_hash['status'] = 'status' @_hash['status_history'] = 'status_history' @_hash['currency'] = 'currency' @_hash['purpose'] = 'purpose' @_hash['success_redirect'] = 'success_redirect' @_hash['pending_redirect'] = 'pending_redirect' @_hash['failure_redirect'] = 'failure_redirect' @_hash['success_callback'] = 'success_callback' @_hash['failure_callback'] = 'failure_callback' @_hash end |
.nullables ⇒ Object
An array for nullable fields
114 115 116 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 114 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
109 110 111 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 109 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 229 def inspect class_name = self.class.name.split('::').last "<#{class_name} payout_id: #{@payout_id.inspect}, client: #{@client.inspect}, updated_on:"\ " #{@updated_on.inspect}, payout_method: #{@payout_method.inspect}, amount_unit:"\ " #{@amount_unit.inspect}, amount: #{@amount.inspect}, error_msg: #{@error_msg.inspect},"\ " created_on: #{@created_on.inspect}, merchant_name: #{@merchant_name.inspect}, status:"\ " #{@status.inspect}, status_history: #{@status_history.inspect}, currency:"\ " #{@currency.inspect}, purpose: #{@purpose.inspect}, success_redirect:"\ " #{@success_redirect.inspect}, pending_redirect: #{@pending_redirect.inspect},"\ " failure_redirect: #{@failure_redirect.inspect}, success_callback:"\ " #{@success_callback.inspect}, failure_callback: #{@failure_callback.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/paysecure_api_documentation_live/models/success8.rb', line 216 def to_s class_name = self.class.name.split('::').last "<#{class_name} payout_id: #{@payout_id}, client: #{@client}, updated_on: #{@updated_on},"\ " payout_method: #{@payout_method}, amount_unit: #{@amount_unit}, amount: #{@amount},"\ " error_msg: #{@error_msg}, created_on: #{@created_on}, merchant_name: #{@merchant_name},"\ " status: #{@status}, status_history: #{@status_history}, currency: #{@currency}, purpose:"\ " #{@purpose}, success_redirect: #{@success_redirect}, pending_redirect:"\ " #{@pending_redirect}, failure_redirect: #{@failure_redirect}, success_callback:"\ " #{@success_callback}, failure_callback: #{@failure_callback}, additional_properties:"\ " #{@additional_properties}>" end |