Class: PaysecureApiDocumentationLive::Transaction
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Transaction
- Defined in:
- lib/paysecure_api_documentation_live/models/transaction.rb
Overview
Transaction Model.
Instance Attribute Summary collapse
-
#amount ⇒ Integer
TODO: Write general description for this method.
-
#created_date ⇒ Integer
TODO: Write general description for this method.
-
#currency ⇒ String
TODO: Write general description for this method.
-
#transaction_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(transaction_id:, amount:, currency:, created_date:, additional_properties: nil) ⇒ Transaction
constructor
A new instance of Transaction.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(transaction_id:, amount:, currency:, created_date:, additional_properties: nil) ⇒ Transaction
Returns a new instance of Transaction.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/paysecure_api_documentation_live/models/transaction.rb', line 48 def initialize(transaction_id:, amount:, currency:, created_date:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @transaction_id = transaction_id @amount = amount @currency = currency @created_date = created_date @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/transaction.rb', line 18 def amount @amount end |
#created_date ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/transaction.rb', line 26 def created_date @created_date end |
#currency ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/transaction.rb', line 22 def currency @currency end |
#transaction_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/transaction.rb', line 14 def transaction_id @transaction_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/paysecure_api_documentation_live/models/transaction.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. transaction_id = hash.key?('transactionId') ? hash['transactionId'] : nil amount = hash.key?('amount') ? hash['amount'] : nil currency = hash.key?('currency') ? hash['currency'] : nil created_date = hash.key?('createdDate') ? hash['createdDate'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Transaction.new(transaction_id: transaction_id, amount: amount, currency: currency, created_date: created_date, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/transaction.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['transaction_id'] = 'transactionId' @_hash['amount'] = 'amount' @_hash['currency'] = 'currency' @_hash['created_date'] = 'createdDate' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/transaction.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/transaction.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/paysecure_api_documentation_live/models/transaction.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} transaction_id: #{@transaction_id.inspect}, amount: #{@amount.inspect},"\ " currency: #{@currency.inspect}, created_date: #{@created_date.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 91 |
# File 'lib/paysecure_api_documentation_live/models/transaction.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} transaction_id: #{@transaction_id}, amount: #{@amount}, currency:"\ " #{@currency}, created_date: #{@created_date}, additional_properties:"\ " #{@additional_properties}>" end |