Class: PaysecureApiDocumentationLive::TransactionData7

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/transaction_data7.rb

Overview

TransactionData7 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(payment_method:, flow:, extra:, country:, attempts:, additional_properties: nil) ⇒ TransactionData7

Returns a new instance of TransactionData7.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 53

def initialize(payment_method:, flow:, extra:, country:, attempts:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @payment_method = payment_method
  @flow = flow
  @extra = extra
  @country = country
  @attempts = attempts
  @additional_properties = additional_properties
end

Instance Attribute Details

#attemptsArray[Attempt5]

TODO: Write general description for this method

Returns:



30
31
32
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 30

def attempts
  @attempts
end

#countryString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 26

def country
  @country
end

#extraExtra10

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 22

def extra
  @extra
end

#flowString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 18

def flow
  @flow
end

#payment_methodString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 14

def payment_method
  @payment_method
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  payment_method =
    hash.key?('payment_method') ? hash['payment_method'] : nil
  flow = hash.key?('flow') ? hash['flow'] : nil
  extra = Extra10.from_hash(hash['extra']) if hash['extra']
  country = hash.key?('country') ? hash['country'] : nil
  # Parameter is an array, so we need to iterate through it
  attempts = nil
  unless hash['attempts'].nil?
    attempts = []
    hash['attempts'].each do |structure|
      attempts << (Attempt5.from_hash(structure) if structure)
    end
  end

  attempts = nil unless hash.key?('attempts')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransactionData7.new(payment_method: payment_method,
                       flow: flow,
                       extra: extra,
                       country: country,
                       attempts: attempts,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['payment_method'] = 'payment_method'
  @_hash['flow'] = 'flow'
  @_hash['extra'] = 'extra'
  @_hash['country'] = 'country'
  @_hash['attempts'] = 'attempts'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 44

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



112
113
114
115
116
117
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 112

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} payment_method: #{@payment_method.inspect}, flow: #{@flow.inspect}, extra:"\
  " #{@extra.inspect}, country: #{@country.inspect}, attempts: #{@attempts.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



104
105
106
107
108
109
# File 'lib/paysecure_api_documentation_live/models/transaction_data7.rb', line 104

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} payment_method: #{@payment_method}, flow: #{@flow}, extra: #{@extra},"\
  " country: #{@country}, attempts: #{@attempts}, additional_properties:"\
  " #{@additional_properties}>"
end