Class: PaysecureApiDocumentationLive::TransactionReportingApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/apis/transaction_reporting_api.rb

Overview

TransactionReportingApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from PaysecureApiDocumentationLive::BaseApi

Instance Method Details

#get_detailed_transaction_details(page_no, page_size, include_subtransactions, brand_id) ⇒ ApiResponse

Retrieves the complete details for a specific transaction. This includes customer info, payment method details, bank response codes, and hierarchy metadata (parent/child transactions).

Additional query parameters for this usecase:

Parameter Notes
include_subtransactions Mandatory.
Possible Values: true/false



If true, includes child transactions (e.g., recurring payments). | here parameter: TODO: type description here

Parameters:

  • page_no (Integer)

    Required parameter: TODO: type description here

  • page_size (Integer)

    Required parameter: TODO: type description

  • include_subtransactions (TrueClass | FalseClass)

    Required

  • brand_id (String)

    Required parameter: TODO: type description here

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/paysecure_api_documentation_live/apis/transaction_reporting_api.rb', line 123

def get_detailed_transaction_details(page_no,
                                     page_size,
                                     include_subtransactions,
                                     brand_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/v1/external/transactions/data/69e20fd928bea6ca2e31b17c',
                                 Server::SERVER_3)
               .query_param(new_parameter(page_no, key: 'page_no')
                             .is_required(true))
               .query_param(new_parameter(page_size, key: 'page_size')
                             .is_required(true))
               .query_param(new_parameter(include_subtransactions, key: 'include_subtransactions')
                             .is_required(true))
               .header_param(new_parameter(brand_id, key: 'BrandId')
                              .is_required(true)))
    .response(new_response_handler
                .is_response_void(true)
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             Success44Exception))
    .execute
end

#list_transactions(page_no, page_size, transaction_id, start_date, end_date, last_updated_start, last_updated_end, customer_id, status, currency, is_sandbox, brand_id) ⇒ ApiResponse

Fetches a paginated list of transactions. This endpoint is optimized for high-volume retrieval and returns a summary view of each transaction (ID and Status).

Important Path Params to consider:

Fields Description
page_no The index number of the page to retrieve.
Zero-based

indexing: The first page is 0, the second is 1, etc.
Example: To get the third page of results, send page_no=2 | | page_size | The number of records to return per page.
Minimum: 1
Maximum: 100 (or whatever your API limit is).
Usage: A larger page_size reduces the number of API calls but increases payload size. | | transaction_id | If you want to filter with a specific transaction id. Multiple ids are not supported.
If a transaction id is passed, it has the highest priority. All the below mentioned filters are ommitted. | | start_date | If you want to filter between 2 dates.
Format: 2026-01-07 16:12:00 +05:30
Base timezone is in UTC. | | end_date | If you want to filter between 2 dates
Format: 2026-01-07 16:12:00 +05:30
Base timezone is in UTC. | | last_updated_start | If you want to filter with the last updated date of a transaction.
Format: 2026-01-07 16:12:00 +05:30
Base timezone is in UTC. | | last_updated_end | If you want to filter with the last updated date of a transaction.
Format: 2026-01-07 16:12:00 +05:30
Base timezone is in UTC. | | customer_id | If you want to filter with a specific customer id. Multiple ids are not supported. | | status | If you want to filter with the status. | | currency | If you want to filter with the currency. | here here here description here description here here description here

Parameters:

  • page_no (Integer)

    Required parameter: TODO: type description here

  • page_size (Integer)

    Required parameter: TODO: type description

  • transaction_id (String)

    Required parameter: TODO: type description

  • start_date (String)

    Required parameter: TODO: type description

  • end_date (String)

    Required parameter: TODO: type description here

  • last_updated_start (String)

    Required parameter: TODO: type

  • last_updated_end (String)

    Required parameter: TODO: type

  • customer_id (String)

    Required parameter: TODO: type description

  • status (String)

    Required parameter: TODO: type description here

  • currency (String)

    Required parameter: TODO: type description here

  • is_sandbox (TrueClass | FalseClass)

    Required parameter: TODO: type

  • brand_id (String)

    Required parameter: TODO: type description here

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/paysecure_api_documentation_live/apis/transaction_reporting_api.rb', line 58

def list_transactions(page_no,
                      page_size,
                      transaction_id,
                      start_date,
                      end_date,
                      last_updated_start,
                      last_updated_end,
                      customer_id,
                      status,
                      currency,
                      is_sandbox,
                      brand_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/v1/external/transactions/list',
                                 Server::SERVER_3)
               .query_param(new_parameter(page_no, key: 'page_no')
                             .is_required(true))
               .query_param(new_parameter(page_size, key: 'page_size')
                             .is_required(true))
               .query_param(new_parameter(transaction_id, key: 'transaction_id')
                             .is_required(true))
               .query_param(new_parameter(start_date, key: 'start_date')
                             .is_required(true))
               .query_param(new_parameter(end_date, key: 'end_date')
                             .is_required(true))
               .query_param(new_parameter(last_updated_start, key: 'last_updated_start')
                             .is_required(true))
               .query_param(new_parameter(last_updated_end, key: 'last_updated_end')
                             .is_required(true))
               .query_param(new_parameter(customer_id, key: 'customer_id')
                             .is_required(true))
               .query_param(new_parameter(status, key: 'status')
                             .is_required(true))
               .query_param(new_parameter(currency, key: 'currency')
                             .is_required(true))
               .query_param(new_parameter(is_sandbox, key: 'is_sandbox')
                             .is_required(true))
               .header_param(new_parameter(brand_id, key: 'BrandId')
                              .is_required(true)))
    .response(new_response_handler
                .is_response_void(true)
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             Success42Exception))
    .execute
end