Class: PaysecureApiDocumentationLive::UpdateMerchant

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/update_merchant.rb

Overview

UpdateMerchant Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(status:, data:, message:, req_id:, additional_properties: nil) ⇒ UpdateMerchant

Returns a new instance of UpdateMerchant.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/paysecure_api_documentation_live/models/update_merchant.rb', line 48

def initialize(status:, data:, message:, req_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @status = status
  @data = data
  @message = message
  @req_id = req_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#dataData7

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/paysecure_api_documentation_live/models/update_merchant.rb', line 18

def data
  @data
end

#messageString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/update_merchant.rb', line 22

def message
  @message
end

#req_idString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/paysecure_api_documentation_live/models/update_merchant.rb', line 26

def req_id
  @req_id
end

#statusString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/update_merchant.rb', line 14

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/paysecure_api_documentation_live/models/update_merchant.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  status = hash.key?('status') ? hash['status'] : nil
  data = Data7.from_hash(hash['data']) if hash['data']
  message = hash.key?('message') ? hash['message'] : nil
  req_id = hash.key?('reqId') ? hash['reqId'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UpdateMerchant.new(status: status,
                     data: data,
                     message: message,
                     req_id: req_id,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/paysecure_api_documentation_live/models/update_merchant.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status'] = 'status'
  @_hash['data'] = 'data'
  @_hash['message'] = 'message'
  @_hash['req_id'] = 'reqId'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/paysecure_api_documentation_live/models/update_merchant.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/paysecure_api_documentation_live/models/update_merchant.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
98
# File 'lib/paysecure_api_documentation_live/models/update_merchant.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, data: #{@data.inspect}, message:"\
  " #{@message.inspect}, req_id: #{@req_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/paysecure_api_documentation_live/models/update_merchant.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, data: #{@data}, message: #{@message}, req_id:"\
  " #{@req_id}, additional_properties: #{@additional_properties}>"
end