Class: PaysecureApiDocumentationLive::WhitelistUploadFailureException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- PaysecureApiDocumentationLive::WhitelistUploadFailureException
- Defined in:
- lib/paysecure_api_documentation_live/exceptions/whitelist_upload_failure_exception.rb
Overview
Whitelist Upload failure class.
Instance Attribute Summary collapse
-
#code ⇒ String
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ WhitelistUploadFailureException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ WhitelistUploadFailureException
The constructor.
27 28 29 30 31 |
# File 'lib/paysecure_api_documentation_live/exceptions/whitelist_upload_failure_exception.rb', line 27 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#code ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/exceptions/whitelist_upload_failure_exception.rb', line 18 def code @code end |
#message ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/exceptions/whitelist_upload_failure_exception.rb', line 14 def @message end |
#status ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/exceptions/whitelist_upload_failure_exception.rb', line 22 def status @status end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
51 52 53 54 55 |
# File 'lib/paysecure_api_documentation_live/exceptions/whitelist_upload_failure_exception.rb', line 51 def inspect class_name = self.class.name.split('::').last "<#{class_name} message: #{@message.inspect}, code: #{@code.inspect}, status:"\ " #{@status.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
45 46 47 48 |
# File 'lib/paysecure_api_documentation_live/exceptions/whitelist_upload_failure_exception.rb', line 45 def to_s class_name = self.class.name.split('::').last "<#{class_name} message: #{@message}, code: #{@code}, status: #{@status}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
36 37 38 39 40 41 42 |
# File 'lib/paysecure_api_documentation_live/exceptions/whitelist_upload_failure_exception.rb', line 36 def unbox(hash) return nil unless hash @message = hash.key?('message') ? hash['message'] : nil @code = hash.key?('code') ? hash['code'] : nil @status = hash.key?('status') ? hash['status'] : nil end |