Class: PaysecureApiDocumentationLive::WhitelistUploadSuccess

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paysecure_api_documentation_live/models/whitelist_upload_success.rb

Overview

WhitelistUploadSuccess Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(total_records:, total_approved:, status:, additional_properties: nil) ⇒ WhitelistUploadSuccess

Returns a new instance of WhitelistUploadSuccess.



43
44
45
46
47
48
49
50
51
52
# File 'lib/paysecure_api_documentation_live/models/whitelist_upload_success.rb', line 43

def initialize(total_records:, total_approved:, status:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @total_records = total_records
  @total_approved = total_approved
  @status = status
  @additional_properties = additional_properties
end

Instance Attribute Details

#statusString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/paysecure_api_documentation_live/models/whitelist_upload_success.rb', line 22

def status
  @status
end

#total_approvedInteger

TODO: Write general description for this method

Returns:

  • (Integer)


18
19
20
# File 'lib/paysecure_api_documentation_live/models/whitelist_upload_success.rb', line 18

def total_approved
  @total_approved
end

#total_recordsInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/paysecure_api_documentation_live/models/whitelist_upload_success.rb', line 14

def total_records
  @total_records
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/paysecure_api_documentation_live/models/whitelist_upload_success.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  total_records = hash.key?('totalRecords') ? hash['totalRecords'] : nil
  total_approved = hash.key?('totalApproved') ? hash['totalApproved'] : nil
  status = hash.key?('status') ? hash['status'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WhitelistUploadSuccess.new(total_records: total_records,
                             total_approved: total_approved,
                             status: status,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/paysecure_api_documentation_live/models/whitelist_upload_success.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['total_records'] = 'totalRecords'
  @_hash['total_approved'] = 'totalApproved'
  @_hash['status'] = 'status'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/paysecure_api_documentation_live/models/whitelist_upload_success.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/paysecure_api_documentation_live/models/whitelist_upload_success.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
90
# File 'lib/paysecure_api_documentation_live/models/whitelist_upload_success.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} total_records: #{@total_records.inspect}, total_approved:"\
  " #{@total_approved.inspect}, status: #{@status.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/paysecure_api_documentation_live/models/whitelist_upload_success.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} total_records: #{@total_records}, total_approved: #{@total_approved},"\
  " status: #{@status}, additional_properties: #{@additional_properties}>"
end