Class: PaysecureApiDocumentationLive::Client6
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Client6
- Defined in:
- lib/paysecure_api_documentation_live/models/client6.rb
Overview
Client6 Model.
Instance Attribute Summary collapse
-
#bcc ⇒ Array[String]
TODO: Write general description for this method.
-
#brand_name ⇒ String
TODO: Write general description for this method.
-
#cc ⇒ Array[String]
TODO: Write general description for this method.
-
#city ⇒ String
TODO: Write general description for this method.
-
#country ⇒ String
TODO: Write general description for this method.
-
#date_of_birth ⇒ String
TODO: Write general description for this method.
-
#email ⇒ String
TODO: Write general description for this method.
-
#full_name ⇒ String
TODO: Write general description for this method.
-
#legal_name ⇒ String
TODO: Write general description for this method.
-
#personal_code ⇒ String
TODO: Write general description for this method.
-
#phone ⇒ String
TODO: Write general description for this method.
-
#registration_number ⇒ String
TODO: Write general description for this method.
-
#shipping_city ⇒ String
TODO: Write general description for this method.
-
#shipping_country ⇒ String
TODO: Write general description for this method.
-
#shipping_street_address ⇒ String
TODO: Write general description for this method.
-
#shipping_zip_code ⇒ String
TODO: Write general description for this method.
-
#state_code ⇒ String
TODO: Write general description for this method.
-
#street_address ⇒ String
TODO: Write general description for this method.
-
#tax_number ⇒ String
TODO: Write general description for this method.
-
#zip_code ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(email:, phone:, full_name:, date_of_birth:, personal_code:, street_address:, country:, city:, zip_code:, shipping_street_address:, shipping_country:, shipping_city:, shipping_zip_code:, cc:, bcc:, legal_name:, brand_name:, registration_number:, tax_number:, state_code:, additional_properties: nil) ⇒ Client6
constructor
A new instance of Client6.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(email:, phone:, full_name:, date_of_birth:, personal_code:, street_address:, country:, city:, zip_code:, shipping_street_address:, shipping_country:, shipping_city:, shipping_zip_code:, cc:, bcc:, legal_name:, brand_name:, registration_number:, tax_number:, state_code:, additional_properties: nil) ⇒ Client6
Returns a new instance of Client6.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 128 def initialize(email:, phone:, full_name:, date_of_birth:, personal_code:, street_address:, country:, city:, zip_code:, shipping_street_address:, shipping_country:, shipping_city:, shipping_zip_code:, cc:, bcc:, legal_name:, brand_name:, registration_number:, tax_number:, state_code:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @email = email @phone = phone @full_name = full_name @date_of_birth = date_of_birth @personal_code = personal_code @street_address = street_address @country = country @city = city @zip_code = zip_code @shipping_street_address = shipping_street_address @shipping_country = shipping_country @shipping_city = shipping_city @shipping_zip_code = shipping_zip_code @cc = cc @bcc = bcc @legal_name = legal_name @brand_name = brand_name @registration_number = registration_number @tax_number = tax_number @state_code = state_code @additional_properties = additional_properties end |
Instance Attribute Details
#bcc ⇒ Array[String]
TODO: Write general description for this method
70 71 72 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 70 def bcc @bcc end |
#brand_name ⇒ String
TODO: Write general description for this method
78 79 80 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 78 def brand_name @brand_name end |
#cc ⇒ Array[String]
TODO: Write general description for this method
66 67 68 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 66 def cc @cc end |
#city ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 42 def city @city end |
#country ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 38 def country @country end |
#date_of_birth ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 26 def date_of_birth @date_of_birth end |
#email ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 14 def email @email end |
#full_name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 22 def full_name @full_name end |
#legal_name ⇒ String
TODO: Write general description for this method
74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 74 def legal_name @legal_name end |
#personal_code ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 30 def personal_code @personal_code end |
#phone ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 18 def phone @phone end |
#registration_number ⇒ String
TODO: Write general description for this method
82 83 84 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 82 def registration_number @registration_number end |
#shipping_city ⇒ String
TODO: Write general description for this method
58 59 60 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 58 def shipping_city @shipping_city end |
#shipping_country ⇒ String
TODO: Write general description for this method
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 54 def shipping_country @shipping_country end |
#shipping_street_address ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 50 def shipping_street_address @shipping_street_address end |
#shipping_zip_code ⇒ String
TODO: Write general description for this method
62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 62 def shipping_zip_code @shipping_zip_code end |
#state_code ⇒ String
TODO: Write general description for this method
90 91 92 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 90 def state_code @state_code end |
#street_address ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 34 def street_address @street_address end |
#tax_number ⇒ String
TODO: Write general description for this method
86 87 88 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 86 def tax_number @tax_number end |
#zip_code ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 46 def zip_code @zip_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 161 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. email = hash.key?('email') ? hash['email'] : nil phone = hash.key?('phone') ? hash['phone'] : nil full_name = hash.key?('full_name') ? hash['full_name'] : nil date_of_birth = hash.key?('date_of_birth') ? hash['date_of_birth'] : nil personal_code = hash.key?('personal_code') ? hash['personal_code'] : nil street_address = hash.key?('street_address') ? hash['street_address'] : nil country = hash.key?('country') ? hash['country'] : nil city = hash.key?('city') ? hash['city'] : nil zip_code = hash.key?('zip_code') ? hash['zip_code'] : nil shipping_street_address = hash.key?('shipping_street_address') ? hash['shipping_street_address'] : nil shipping_country = hash.key?('shipping_country') ? hash['shipping_country'] : nil shipping_city = hash.key?('shipping_city') ? hash['shipping_city'] : nil shipping_zip_code = hash.key?('shipping_zip_code') ? hash['shipping_zip_code'] : nil cc = hash.key?('cc') ? hash['cc'] : nil bcc = hash.key?('bcc') ? hash['bcc'] : nil legal_name = hash.key?('legal_name') ? hash['legal_name'] : nil brand_name = hash.key?('brand_name') ? hash['brand_name'] : nil registration_number = hash.key?('registration_number') ? hash['registration_number'] : nil tax_number = hash.key?('tax_number') ? hash['tax_number'] : nil state_code = hash.key?('stateCode') ? hash['stateCode'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Client6.new(email: email, phone: phone, full_name: full_name, date_of_birth: date_of_birth, personal_code: personal_code, street_address: street_address, country: country, city: city, zip_code: zip_code, shipping_street_address: shipping_street_address, shipping_country: shipping_country, shipping_city: shipping_city, shipping_zip_code: shipping_zip_code, cc: cc, bcc: bcc, legal_name: legal_name, brand_name: brand_name, registration_number: registration_number, tax_number: tax_number, state_code: state_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 93 def self.names @_hash = {} if @_hash.nil? @_hash['email'] = 'email' @_hash['phone'] = 'phone' @_hash['full_name'] = 'full_name' @_hash['date_of_birth'] = 'date_of_birth' @_hash['personal_code'] = 'personal_code' @_hash['street_address'] = 'street_address' @_hash['country'] = 'country' @_hash['city'] = 'city' @_hash['zip_code'] = 'zip_code' @_hash['shipping_street_address'] = 'shipping_street_address' @_hash['shipping_country'] = 'shipping_country' @_hash['shipping_city'] = 'shipping_city' @_hash['shipping_zip_code'] = 'shipping_zip_code' @_hash['cc'] = 'cc' @_hash['bcc'] = 'bcc' @_hash['legal_name'] = 'legal_name' @_hash['brand_name'] = 'brand_name' @_hash['registration_number'] = 'registration_number' @_hash['tax_number'] = 'tax_number' @_hash['state_code'] = 'stateCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
124 125 126 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 124 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
119 120 121 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 119 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 236 def inspect class_name = self.class.name.split('::').last "<#{class_name} email: #{@email.inspect}, phone: #{@phone.inspect}, full_name:"\ " #{@full_name.inspect}, date_of_birth: #{@date_of_birth.inspect}, personal_code:"\ " #{@personal_code.inspect}, street_address: #{@street_address.inspect}, country:"\ " #{@country.inspect}, city: #{@city.inspect}, zip_code: #{@zip_code.inspect},"\ " shipping_street_address: #{@shipping_street_address.inspect}, shipping_country:"\ " #{@shipping_country.inspect}, shipping_city: #{@shipping_city.inspect}, shipping_zip_code:"\ " #{@shipping_zip_code.inspect}, cc: #{@cc.inspect}, bcc: #{@bcc.inspect}, legal_name:"\ " #{@legal_name.inspect}, brand_name: #{@brand_name.inspect}, registration_number:"\ " #{@registration_number.inspect}, tax_number: #{@tax_number.inspect}, state_code:"\ " #{@state_code.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/paysecure_api_documentation_live/models/client6.rb', line 223 def to_s class_name = self.class.name.split('::').last "<#{class_name} email: #{@email}, phone: #{@phone}, full_name: #{@full_name},"\ " date_of_birth: #{@date_of_birth}, personal_code: #{@personal_code}, street_address:"\ " #{@street_address}, country: #{@country}, city: #{@city}, zip_code: #{@zip_code},"\ " shipping_street_address: #{@shipping_street_address}, shipping_country:"\ " #{@shipping_country}, shipping_city: #{@shipping_city}, shipping_zip_code:"\ " #{@shipping_zip_code}, cc: #{@cc}, bcc: #{@bcc}, legal_name: #{@legal_name}, brand_name:"\ " #{@brand_name}, registration_number: #{@registration_number}, tax_number: #{@tax_number},"\ " state_code: #{@state_code}, additional_properties: #{@additional_properties}>" end |