Class: PaysecureApiDocumentationLive::Extra
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Extra
- Defined in:
- lib/paysecure_api_documentation_live/models/extra.rb
Overview
Extra Model.
Instance Attribute Summary collapse
-
#amount ⇒ Integer
TODO: Write general description for this method.
-
#card_brand ⇒ String
TODO: Write general description for this method.
-
#card_issuer ⇒ String
TODO: Write general description for this method.
-
#card_issuer_country ⇒ String
TODO: Write general description for this method.
-
#cardholder_name ⇒ String
TODO: Write general description for this method.
-
#expiry_month ⇒ String
TODO: Write general description for this method.
-
#expiry_year ⇒ String
TODO: Write general description for this method.
-
#masked_pan ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(expiry_month:, amount:, card_issuer:, masked_pan:, card_brand:, card_issuer_country:, cardholder_name:, expiry_year:, additional_properties: nil) ⇒ Extra
constructor
A new instance of Extra.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(expiry_month:, amount:, card_issuer:, masked_pan:, card_brand:, card_issuer_country:, cardholder_name:, expiry_year:, additional_properties: nil) ⇒ Extra
Returns a new instance of Extra.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 68 def initialize(expiry_month:, amount:, card_issuer:, masked_pan:, card_brand:, card_issuer_country:, cardholder_name:, expiry_year:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @expiry_month = expiry_month @amount = amount @card_issuer = card_issuer @masked_pan = masked_pan @card_brand = card_brand @card_issuer_country = card_issuer_country @cardholder_name = cardholder_name @expiry_year = expiry_year @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 18 def amount @amount end |
#card_brand ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 30 def card_brand @card_brand end |
#card_issuer ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 22 def card_issuer @card_issuer end |
#card_issuer_country ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 34 def card_issuer_country @card_issuer_country end |
#cardholder_name ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 38 def cardholder_name @cardholder_name end |
#expiry_month ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 14 def expiry_month @expiry_month end |
#expiry_year ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 42 def expiry_year @expiry_year end |
#masked_pan ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 26 def masked_pan @masked_pan end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 86 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. expiry_month = hash.key?('expiry_month') ? hash['expiry_month'] : nil amount = hash.key?('amount') ? hash['amount'] : nil card_issuer = hash.key?('card_issuer') ? hash['card_issuer'] : nil masked_pan = hash.key?('masked_pan') ? hash['masked_pan'] : nil card_brand = hash.key?('card_brand') ? hash['card_brand'] : nil card_issuer_country = hash.key?('card_issuer_country') ? hash['card_issuer_country'] : nil cardholder_name = hash.key?('cardholder_name') ? hash['cardholder_name'] : nil expiry_year = hash.key?('expiry_year') ? hash['expiry_year'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Extra.new(expiry_month: expiry_month, amount: amount, card_issuer: card_issuer, masked_pan: masked_pan, card_brand: card_brand, card_issuer_country: card_issuer_country, cardholder_name: cardholder_name, expiry_year: expiry_year, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['expiry_month'] = 'expiry_month' @_hash['amount'] = 'amount' @_hash['card_issuer'] = 'card_issuer' @_hash['masked_pan'] = 'masked_pan' @_hash['card_brand'] = 'card_brand' @_hash['card_issuer_country'] = 'card_issuer_country' @_hash['cardholder_name'] = 'cardholder_name' @_hash['expiry_year'] = 'expiry_year' @_hash end |
.nullables ⇒ Object
An array for nullable fields
64 65 66 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 64 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 59 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
130 131 132 133 134 135 136 137 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 130 def inspect class_name = self.class.name.split('::').last "<#{class_name} expiry_month: #{@expiry_month.inspect}, amount: #{@amount.inspect},"\ " card_issuer: #{@card_issuer.inspect}, masked_pan: #{@masked_pan.inspect}, card_brand:"\ " #{@card_brand.inspect}, card_issuer_country: #{@card_issuer_country.inspect},"\ " cardholder_name: #{@cardholder_name.inspect}, expiry_year: #{@expiry_year.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
121 122 123 124 125 126 127 |
# File 'lib/paysecure_api_documentation_live/models/extra.rb', line 121 def to_s class_name = self.class.name.split('::').last "<#{class_name} expiry_month: #{@expiry_month}, amount: #{@amount}, card_issuer:"\ " #{@card_issuer}, masked_pan: #{@masked_pan}, card_brand: #{@card_brand},"\ " card_issuer_country: #{@card_issuer_country}, cardholder_name: #{@cardholder_name},"\ " expiry_year: #{@expiry_year}, additional_properties: #{@additional_properties}>" end |