Class: PaysecureApiDocumentationLive::Extra57
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Extra57
- Defined in:
- lib/paysecure_api_documentation_live/models/extra57.rb
Overview
Extra57 Model.
Instance Attribute Summary collapse
-
#amount ⇒ Float
TODO: Write general description for this method.
-
#card_brand ⇒ String
TODO: Write general description for this method.
-
#card_issuer ⇒ String
TODO: Write general description for this method.
-
#card_issuer_country ⇒ String
TODO: Write general description for this method.
-
#card_type ⇒ String
TODO: Write general description for this method.
-
#cardholder_name ⇒ String
TODO: Write general description for this method.
-
#expiry_month ⇒ String
TODO: Write general description for this method.
-
#expiry_year ⇒ String
TODO: Write general description for this method.
-
#masked_pan ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount:, masked_pan:, card_brand:, card_issuer_country:, cardholder_name:, expiry_month: SKIP, card_issuer: SKIP, card_type: SKIP, expiry_year: SKIP, additional_properties: nil) ⇒ Extra57
constructor
A new instance of Extra57.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount:, masked_pan:, card_brand:, card_issuer_country:, cardholder_name:, expiry_month: SKIP, card_issuer: SKIP, card_type: SKIP, expiry_year: SKIP, additional_properties: nil) ⇒ Extra57
Returns a new instance of Extra57.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 78 def initialize(amount:, masked_pan:, card_brand:, card_issuer_country:, cardholder_name:, expiry_month: SKIP, card_issuer: SKIP, card_type: SKIP, expiry_year: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @amount = amount @masked_pan = masked_pan @card_brand = card_brand @card_issuer_country = card_issuer_country @cardholder_name = cardholder_name @expiry_month = expiry_month unless expiry_month == SKIP @card_issuer = card_issuer unless card_issuer == SKIP @card_type = card_type unless card_type == SKIP @expiry_year = expiry_year unless expiry_year == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 14 def amount @amount end |
#card_brand ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 22 def card_brand @card_brand end |
#card_issuer ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 38 def card_issuer @card_issuer end |
#card_issuer_country ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 26 def card_issuer_country @card_issuer_country end |
#card_type ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 42 def card_type @card_type end |
#cardholder_name ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 30 def cardholder_name @cardholder_name end |
#expiry_month ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 34 def expiry_month @expiry_month end |
#expiry_year ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 46 def expiry_year @expiry_year end |
#masked_pan ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 18 def masked_pan @masked_pan end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 98 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount = hash.key?('amount') ? hash['amount'] : nil masked_pan = hash.key?('masked_pan') ? hash['masked_pan'] : nil card_brand = hash.key?('card_brand') ? hash['card_brand'] : nil card_issuer_country = hash.key?('card_issuer_country') ? hash['card_issuer_country'] : nil cardholder_name = hash.key?('cardholder_name') ? hash['cardholder_name'] : nil expiry_month = hash.key?('expiry_month') ? hash['expiry_month'] : SKIP card_issuer = hash.key?('card_issuer') ? hash['card_issuer'] : SKIP card_type = hash.key?('card_type') ? hash['card_type'] : SKIP expiry_year = hash.key?('expiry_year') ? hash['expiry_year'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Extra57.new(amount: amount, masked_pan: masked_pan, card_brand: card_brand, card_issuer_country: card_issuer_country, cardholder_name: cardholder_name, expiry_month: expiry_month, card_issuer: card_issuer, card_type: card_type, expiry_year: expiry_year, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 49 def self.names @_hash = {} if @_hash.nil? @_hash['amount'] = 'amount' @_hash['masked_pan'] = 'masked_pan' @_hash['card_brand'] = 'card_brand' @_hash['card_issuer_country'] = 'card_issuer_country' @_hash['cardholder_name'] = 'cardholder_name' @_hash['expiry_month'] = 'expiry_month' @_hash['card_issuer'] = 'card_issuer' @_hash['card_type'] = 'card_type' @_hash['expiry_year'] = 'expiry_year' @_hash end |
.nullables ⇒ Object
An array for nullable fields
74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 74 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
64 65 66 67 68 69 70 71 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 64 def self.optionals %w[ expiry_month card_issuer card_type expiry_year ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
144 145 146 147 148 149 150 151 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 144 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount.inspect}, masked_pan: #{@masked_pan.inspect}, card_brand:"\ " #{@card_brand.inspect}, card_issuer_country: #{@card_issuer_country.inspect},"\ " cardholder_name: #{@cardholder_name.inspect}, expiry_month: #{@expiry_month.inspect},"\ " card_issuer: #{@card_issuer.inspect}, card_type: #{@card_type.inspect}, expiry_year:"\ " #{@expiry_year.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
135 136 137 138 139 140 141 |
# File 'lib/paysecure_api_documentation_live/models/extra57.rb', line 135 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount}, masked_pan: #{@masked_pan}, card_brand: #{@card_brand},"\ " card_issuer_country: #{@card_issuer_country}, cardholder_name: #{@cardholder_name},"\ " expiry_month: #{@expiry_month}, card_issuer: #{@card_issuer}, card_type: #{@card_type},"\ " expiry_year: #{@expiry_year}, additional_properties: #{@additional_properties}>" end |