Class: PaysecureApiDocumentationLive::ExtraParam8
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::ExtraParam8
- Defined in:
- lib/paysecure_api_documentation_live/models/extra_param8.rb
Overview
ExtraParam8 Model.
Instance Attribute Summary collapse
-
#client_fee ⇒ Float
TODO: Write general description for this method.
-
#to_address ⇒ Array[ToAddress]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_fee:, to_address:, additional_properties: nil) ⇒ ExtraParam8
constructor
A new instance of ExtraParam8.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_fee:, to_address:, additional_properties: nil) ⇒ ExtraParam8
Returns a new instance of ExtraParam8.
38 39 40 41 42 43 44 45 |
# File 'lib/paysecure_api_documentation_live/models/extra_param8.rb', line 38 def initialize(client_fee:, to_address:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_fee = client_fee @to_address = to_address @additional_properties = additional_properties end |
Instance Attribute Details
#client_fee ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/extra_param8.rb', line 14 def client_fee @client_fee end |
#to_address ⇒ Array[ToAddress]
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/extra_param8.rb', line 18 def to_address @to_address end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/paysecure_api_documentation_live/models/extra_param8.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_fee = hash.key?('clientFee') ? hash['clientFee'] : nil # Parameter is an array, so we need to iterate through it to_address = nil unless hash['toAddress'].nil? to_address = [] hash['toAddress'].each do |structure| to_address << (ToAddress.from_hash(structure) if structure) end end to_address = nil unless hash.key?('toAddress') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ExtraParam8.new(client_fee: client_fee, to_address: to_address, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/paysecure_api_documentation_live/models/extra_param8.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['client_fee'] = 'clientFee' @_hash['to_address'] = 'toAddress' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/extra_param8.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/extra_param8.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/paysecure_api_documentation_live/models/extra_param8.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_fee: #{@client_fee.inspect}, to_address: #{@to_address.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/paysecure_api_documentation_live/models/extra_param8.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_fee: #{@client_fee}, to_address: #{@to_address},"\ " additional_properties: #{@additional_properties}>" end |