Class: PaysecureApiDocumentationLive::GetBalanceApiV2OrchestrationApi
- Inherits:
-
BaseApi
- Object
- BaseApi
- PaysecureApiDocumentationLive::GetBalanceApiV2OrchestrationApi
- Defined in:
- lib/paysecure_api_documentation_live/apis/get_balance_api_v2_orchestration_api.rb
Overview
GetBalanceApiV2OrchestrationApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#checking_balance(body) ⇒ ApiResponse
API for checking available balance 1.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from PaysecureApiDocumentationLive::BaseApi
Instance Method Details
#checking_balance(body) ⇒ ApiResponse
API for checking available balance
-
URL :- /getBalance/
-
RequestType: POST
-
Request Body
Note: Currency is not a mandatory parameter. If no parameter is specified then all respective currency balances would be provided, if any specific currency parameter is provided then only that currency balance would be provided. description here
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/paysecure_api_documentation_live/apis/get_balance_api_v2_orchestration_api.rb', line 23 def checking_balance(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/', Server::SERVER_4) .body_param(new_parameter(body) .is_required(true)) .header_param(new_parameter('application/json; charset=utf-8', key: 'content-type')) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end)) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(CheckingBalancePayoutSuccess2.method(:from_hash)) .is_api_response(true)) .execute end |