Class: PaysecureApiDocumentationLive::GooglepayDecryptedPayload
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::GooglepayDecryptedPayload
- Defined in:
- lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb
Overview
GooglepayDecryptedPayload Model.
Instance Attribute Summary collapse
-
#gateway_merchant_id ⇒ String
TODO: Write general description for this method.
-
#message_expiration ⇒ String
TODO: Write general description for this method.
-
#message_id ⇒ String
TODO: Write general description for this method.
-
#payment_method ⇒ String
TODO: Write general description for this method.
-
#payment_method_details ⇒ PaymentMethodDetails
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(message_expiration:, message_id:, payment_method:, payment_method_details:, gateway_merchant_id:, additional_properties: nil) ⇒ GooglepayDecryptedPayload
constructor
A new instance of GooglepayDecryptedPayload.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(message_expiration:, message_id:, payment_method:, payment_method_details:, gateway_merchant_id:, additional_properties: nil) ⇒ GooglepayDecryptedPayload
Returns a new instance of GooglepayDecryptedPayload.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 53 def initialize(message_expiration:, message_id:, payment_method:, payment_method_details:, gateway_merchant_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @message_expiration = @message_id = @payment_method = payment_method @payment_method_details = payment_method_details @gateway_merchant_id = gateway_merchant_id @additional_properties = additional_properties end |
Instance Attribute Details
#gateway_merchant_id ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 30 def gateway_merchant_id @gateway_merchant_id end |
#message_expiration ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 14 def @message_expiration end |
#message_id ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 18 def @message_id end |
#payment_method ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 22 def payment_method @payment_method end |
#payment_method_details ⇒ PaymentMethodDetails
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 26 def payment_method_details @payment_method_details end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 68 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash.key?('messageExpiration') ? hash['messageExpiration'] : nil = hash.key?('messageId') ? hash['messageId'] : nil payment_method = hash.key?('paymentMethod') ? hash['paymentMethod'] : nil payment_method_details = PaymentMethodDetails.from_hash(hash['paymentMethodDetails']) if hash['paymentMethodDetails'] gateway_merchant_id = hash.key?('gatewayMerchantId') ? hash['gatewayMerchantId'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GooglepayDecryptedPayload.new(message_expiration: , message_id: , payment_method: payment_method, payment_method_details: payment_method_details, gateway_merchant_id: gateway_merchant_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['message_expiration'] = 'messageExpiration' @_hash['message_id'] = 'messageId' @_hash['payment_method'] = 'paymentMethod' @_hash['payment_method_details'] = 'paymentMethodDetails' @_hash['gateway_merchant_id'] = 'gatewayMerchantId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
107 108 109 110 111 112 113 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 107 def inspect class_name = self.class.name.split('::').last "<#{class_name} message_expiration: #{@message_expiration.inspect}, message_id:"\ " #{@message_id.inspect}, payment_method: #{@payment_method.inspect},"\ " payment_method_details: #{@payment_method_details.inspect}, gateway_merchant_id:"\ " #{@gateway_merchant_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
98 99 100 101 102 103 104 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_decrypted_payload.rb', line 98 def to_s class_name = self.class.name.split('::').last "<#{class_name} message_expiration: #{@message_expiration}, message_id: #{@message_id},"\ " payment_method: #{@payment_method}, payment_method_details: #{@payment_method_details},"\ " gateway_merchant_id: #{@gateway_merchant_id}, additional_properties:"\ " #{@additional_properties}>" end |