Class: PaysecureApiDocumentationLive::GooglepayParam1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::GooglepayParam1
- Defined in:
- lib/paysecure_api_documentation_live/models/googlepay_param1.rb
Overview
GooglepayParam1 Model.
Instance Attribute Summary collapse
-
#google_merchant_id ⇒ String
TODO: Write general description for this method.
-
#googlepay_decrypted_payload ⇒ GooglepayDecryptedPayload
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(google_merchant_id:, googlepay_decrypted_payload:, additional_properties: nil) ⇒ GooglepayParam1
constructor
A new instance of GooglepayParam1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(google_merchant_id:, googlepay_decrypted_payload:, additional_properties: nil) ⇒ GooglepayParam1
Returns a new instance of GooglepayParam1.
38 39 40 41 42 43 44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_param1.rb', line 38 def initialize(google_merchant_id:, googlepay_decrypted_payload:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @google_merchant_id = google_merchant_id @googlepay_decrypted_payload = googlepay_decrypted_payload @additional_properties = additional_properties end |
Instance Attribute Details
#google_merchant_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_param1.rb', line 14 def google_merchant_id @google_merchant_id end |
#googlepay_decrypted_payload ⇒ GooglepayDecryptedPayload
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_param1.rb', line 18 def googlepay_decrypted_payload @googlepay_decrypted_payload end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_param1.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. google_merchant_id = hash.key?('google_merchant_id') ? hash['google_merchant_id'] : nil if hash['googlepay_decrypted_payload'] googlepay_decrypted_payload = GooglepayDecryptedPayload.from_hash(hash['googlepay_decrypted_payload']) end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GooglepayParam1.new(google_merchant_id: google_merchant_id, googlepay_decrypted_payload: googlepay_decrypted_payload, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_param1.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['google_merchant_id'] = 'google_merchant_id' @_hash['googlepay_decrypted_payload'] = 'googlepay_decrypted_payload' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_param1.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_param1.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 85 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_param1.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} google_merchant_id: #{@google_merchant_id.inspect},"\ " googlepay_decrypted_payload: #{@googlepay_decrypted_payload.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/paysecure_api_documentation_live/models/googlepay_param1.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} google_merchant_id: #{@google_merchant_id}, googlepay_decrypted_payload:"\ " #{@googlepay_decrypted_payload}, additional_properties: #{@additional_properties}>" end |