Class: PaysecureApiDocumentationLive::PauseMandate
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::PauseMandate
- Defined in:
- lib/paysecure_api_documentation_live/models/pause_mandate.rb
Overview
PauseMandate Model.
Instance Attribute Summary collapse
-
#mandate_id ⇒ String
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#pause_end_date ⇒ Integer
TODO: Write general description for this method.
-
#pause_start_date ⇒ Integer
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mandate_id:, pause_end_date:, message:, pause_start_date:, status:, additional_properties: nil) ⇒ PauseMandate
constructor
A new instance of PauseMandate.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mandate_id:, pause_end_date:, message:, pause_start_date:, status:, additional_properties: nil) ⇒ PauseMandate
Returns a new instance of PauseMandate.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 53 def initialize(mandate_id:, pause_end_date:, message:, pause_start_date:, status:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mandate_id = mandate_id @pause_end_date = pause_end_date @message = @pause_start_date = pause_start_date @status = status @additional_properties = additional_properties end |
Instance Attribute Details
#mandate_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 14 def mandate_id @mandate_id end |
#message ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 22 def @message end |
#pause_end_date ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 18 def pause_end_date @pause_end_date end |
#pause_start_date ⇒ Integer
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 26 def pause_start_date @pause_start_date end |
#status ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 30 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mandate_id = hash.key?('mandateId') ? hash['mandateId'] : nil pause_end_date = hash.key?('pauseEndDate') ? hash['pauseEndDate'] : nil = hash.key?('message') ? hash['message'] : nil pause_start_date = hash.key?('pauseStartDate') ? hash['pauseStartDate'] : nil status = hash.key?('status') ? hash['status'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PauseMandate.new(mandate_id: mandate_id, pause_end_date: pause_end_date, message: , pause_start_date: pause_start_date, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['mandate_id'] = 'mandateId' @_hash['pause_end_date'] = 'pauseEndDate' @_hash['message'] = 'message' @_hash['pause_start_date'] = 'pauseStartDate' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 109 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} mandate_id: #{@mandate_id.inspect}, pause_end_date:"\ " #{@pause_end_date.inspect}, message: #{@message.inspect}, pause_start_date:"\ " #{@pause_start_date.inspect}, status: #{@status.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 100 |
# File 'lib/paysecure_api_documentation_live/models/pause_mandate.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} mandate_id: #{@mandate_id}, pause_end_date: #{@pause_end_date}, message:"\ " #{@message}, pause_start_date: #{@pause_start_date}, status: #{@status},"\ " additional_properties: #{@additional_properties}>" end |