Class: PaysecureApiDocumentationLive::PayInDetails10
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::PayInDetails10
- Defined in:
- lib/paysecure_api_documentation_live/models/pay_in_details10.rb
Overview
PayInDetails10 Model.
Instance Attribute Summary collapse
-
#generated_link ⇒ String
TODO: Write general description for this method.
-
#gpay_uri ⇒ String
TODO: Write general description for this method.
-
#paytm_uri ⇒ String
TODO: Write general description for this method.
-
#phonepe_uri ⇒ String
TODO: Write general description for this method.
-
#qr_code ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(qr_code:, gpay_uri:, phonepe_uri:, paytm_uri:, generated_link:, additional_properties: nil) ⇒ PayInDetails10
constructor
A new instance of PayInDetails10.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(qr_code:, gpay_uri:, phonepe_uri:, paytm_uri:, generated_link:, additional_properties: nil) ⇒ PayInDetails10
Returns a new instance of PayInDetails10.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 53 def initialize(qr_code:, gpay_uri:, phonepe_uri:, paytm_uri:, generated_link:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @qr_code = qr_code @gpay_uri = gpay_uri @phonepe_uri = phonepe_uri @paytm_uri = paytm_uri @generated_link = generated_link @additional_properties = additional_properties end |
Instance Attribute Details
#generated_link ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 30 def generated_link @generated_link end |
#gpay_uri ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 18 def gpay_uri @gpay_uri end |
#paytm_uri ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 26 def paytm_uri @paytm_uri end |
#phonepe_uri ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 22 def phonepe_uri @phonepe_uri end |
#qr_code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 14 def qr_code @qr_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. qr_code = hash.key?('qrCode') ? hash['qrCode'] : nil gpay_uri = hash.key?('gpayUri') ? hash['gpayUri'] : nil phonepe_uri = hash.key?('phonepeUri') ? hash['phonepeUri'] : nil paytm_uri = hash.key?('paytmUri') ? hash['paytmUri'] : nil generated_link = hash.key?('generatedLink') ? hash['generatedLink'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PayInDetails10.new(qr_code: qr_code, gpay_uri: gpay_uri, phonepe_uri: phonepe_uri, paytm_uri: paytm_uri, generated_link: generated_link, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['qr_code'] = 'qrCode' @_hash['gpay_uri'] = 'gpayUri' @_hash['phonepe_uri'] = 'phonepeUri' @_hash['paytm_uri'] = 'paytmUri' @_hash['generated_link'] = 'generatedLink' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 107 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} qr_code: #{@qr_code.inspect}, gpay_uri: #{@gpay_uri.inspect}, phonepe_uri:"\ " #{@phonepe_uri.inspect}, paytm_uri: #{@paytm_uri.inspect}, generated_link:"\ " #{@generated_link.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 99 |
# File 'lib/paysecure_api_documentation_live/models/pay_in_details10.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} qr_code: #{@qr_code}, gpay_uri: #{@gpay_uri}, phonepe_uri: #{@phonepe_uri},"\ " paytm_uri: #{@paytm_uri}, generated_link: #{@generated_link}, additional_properties:"\ " #{@additional_properties}>" end |