Class: PaysecureApiDocumentationLive::Purchase17
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Purchase17
- Defined in:
- lib/paysecure_api_documentation_live/models/purchase17.rb
Overview
Purchase17 Model.
Instance Attribute Summary collapse
-
#currency ⇒ String
TODO: Write general description for this method.
-
#language ⇒ String
TODO: Write general description for this method.
-
#products ⇒ Array[Product17]
TODO: Write general description for this method.
-
#timezone ⇒ String
TODO: Write general description for this method.
-
#total ⇒ Float
TODO: Write general description for this method.
-
#total_formatted ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(currency:, products:, total:, language:, total_formatted:, timezone:, additional_properties: nil) ⇒ Purchase17
constructor
A new instance of Purchase17.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(currency:, products:, total:, language:, total_formatted:, timezone:, additional_properties: nil) ⇒ Purchase17
Returns a new instance of Purchase17.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 58 def initialize(currency:, products:, total:, language:, total_formatted:, timezone:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @currency = currency @products = products @total = total @language = language @total_formatted = total_formatted @timezone = timezone @additional_properties = additional_properties end |
Instance Attribute Details
#currency ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 14 def currency @currency end |
#language ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 26 def language @language end |
#products ⇒ Array[Product17]
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 18 def products @products end |
#timezone ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 34 def timezone @timezone end |
#total ⇒ Float
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 22 def total @total end |
#total_formatted ⇒ Float
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 30 def total_formatted @total_formatted end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. currency = hash.key?('currency') ? hash['currency'] : nil # Parameter is an array, so we need to iterate through it products = nil unless hash['products'].nil? products = [] hash['products'].each do |structure| products << (Product17.from_hash(structure) if structure) end end products = nil unless hash.key?('products') total = hash.key?('total') ? hash['total'] : nil language = hash.key?('language') ? hash['language'] : nil total_formatted = hash.key?('total_formatted') ? hash['total_formatted'] : nil timezone = hash.key?('timezone') ? hash['timezone'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Purchase17.new(currency: currency, products: products, total: total, language: language, total_formatted: total_formatted, timezone: timezone, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['currency'] = 'currency' @_hash['products'] = 'products' @_hash['total'] = 'total' @_hash['language'] = 'language' @_hash['total_formatted'] = 'total_formatted' @_hash['timezone'] = 'timezone' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
120 121 122 123 124 125 126 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 120 def inspect class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency.inspect}, products: #{@products.inspect}, total:"\ " #{@total.inspect}, language: #{@language.inspect}, total_formatted:"\ " #{@total_formatted.inspect}, timezone: #{@timezone.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
112 113 114 115 116 117 |
# File 'lib/paysecure_api_documentation_live/models/purchase17.rb', line 112 def to_s class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency}, products: #{@products}, total: #{@total}, language:"\ " #{@language}, total_formatted: #{@total_formatted}, timezone: #{@timezone},"\ " additional_properties: #{@additional_properties}>" end |