Class: PaysecureApiDocumentationLive::Success19
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- PaysecureApiDocumentationLive::Success19
- Defined in:
- lib/paysecure_api_documentation_live/models/success19.rb
Overview
Success19 Model.
Instance Attribute Summary collapse
-
#address ⇒ String
TODO: Write general description for this method.
-
#brand_id ⇒ String
TODO: Write general description for this method.
-
#city ⇒ String
TODO: Write general description for this method.
-
#country ⇒ String
TODO: Write general description for this method.
-
#created_on ⇒ Integer
TODO: Write general description for this method.
-
#cust_reg_date ⇒ String
TODO: Write general description for this method.
-
#customer_id ⇒ String
TODO: Write general description for this method.
-
#date_of_birth ⇒ String
TODO: Write general description for this method.
-
#email_id ⇒ String
TODO: Write general description for this method.
-
#extra_param ⇒ ExtraParam10
TODO: Write general description for this method.
-
#full_name ⇒ String
TODO: Write general description for this method.
-
#last_activity ⇒ Integer
TODO: Write general description for this method.
-
#last_updated ⇒ Integer
TODO: Write general description for this method.
-
#merchant_customer_id ⇒ String
TODO: Write general description for this method.
-
#phone_no ⇒ String
TODO: Write general description for this method.
-
#state_code ⇒ String
TODO: Write general description for this method.
-
#success_trans ⇒ Integer
TODO: Write general description for this method.
-
#zip_code ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(customer_id:, merchant_customer_id:, full_name:, email_id:, date_of_birth:, phone_no:, brand_id:, city:, zip_code:, address:, country:, state_code:, cust_reg_date:, success_trans:, created_on:, last_updated:, last_activity:, extra_param:, additional_properties: nil) ⇒ Success19
constructor
A new instance of Success19.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(customer_id:, merchant_customer_id:, full_name:, email_id:, date_of_birth:, phone_no:, brand_id:, city:, zip_code:, address:, country:, state_code:, cust_reg_date:, success_trans:, created_on:, last_updated:, last_activity:, extra_param:, additional_properties: nil) ⇒ Success19
Returns a new instance of Success19.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 118 def initialize(customer_id:, merchant_customer_id:, full_name:, email_id:, date_of_birth:, phone_no:, brand_id:, city:, zip_code:, address:, country:, state_code:, cust_reg_date:, success_trans:, created_on:, last_updated:, last_activity:, extra_param:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @customer_id = customer_id @merchant_customer_id = merchant_customer_id @full_name = full_name @email_id = email_id @date_of_birth = date_of_birth @phone_no = phone_no @brand_id = brand_id @city = city @zip_code = zip_code @address = address @country = country @state_code = state_code @cust_reg_date = cust_reg_date @success_trans = success_trans @created_on = created_on @last_updated = last_updated @last_activity = last_activity @extra_param = extra_param @additional_properties = additional_properties end |
Instance Attribute Details
#address ⇒ String
TODO: Write general description for this method
50 51 52 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 50 def address @address end |
#brand_id ⇒ String
TODO: Write general description for this method
38 39 40 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 38 def brand_id @brand_id end |
#city ⇒ String
TODO: Write general description for this method
42 43 44 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 42 def city @city end |
#country ⇒ String
TODO: Write general description for this method
54 55 56 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 54 def country @country end |
#created_on ⇒ Integer
TODO: Write general description for this method
70 71 72 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 70 def created_on @created_on end |
#cust_reg_date ⇒ String
TODO: Write general description for this method
62 63 64 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 62 def cust_reg_date @cust_reg_date end |
#customer_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 14 def customer_id @customer_id end |
#date_of_birth ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 30 def date_of_birth @date_of_birth end |
#email_id ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 26 def email_id @email_id end |
#extra_param ⇒ ExtraParam10
TODO: Write general description for this method
82 83 84 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 82 def extra_param @extra_param end |
#full_name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 22 def full_name @full_name end |
#last_activity ⇒ Integer
TODO: Write general description for this method
78 79 80 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 78 def last_activity @last_activity end |
#last_updated ⇒ Integer
TODO: Write general description for this method
74 75 76 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 74 def last_updated @last_updated end |
#merchant_customer_id ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 18 def merchant_customer_id @merchant_customer_id end |
#phone_no ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 34 def phone_no @phone_no end |
#state_code ⇒ String
TODO: Write general description for this method
58 59 60 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 58 def state_code @state_code end |
#success_trans ⇒ Integer
TODO: Write general description for this method
66 67 68 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 66 def success_trans @success_trans end |
#zip_code ⇒ String
TODO: Write general description for this method
46 47 48 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 46 def zip_code @zip_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 148 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. customer_id = hash.key?('customerId') ? hash['customerId'] : nil merchant_customer_id = hash.key?('merchantCustomerId') ? hash['merchantCustomerId'] : nil full_name = hash.key?('fullName') ? hash['fullName'] : nil email_id = hash.key?('emailId') ? hash['emailId'] : nil date_of_birth = hash.key?('dateOfBirth') ? hash['dateOfBirth'] : nil phone_no = hash.key?('phoneNo') ? hash['phoneNo'] : nil brand_id = hash.key?('brandID') ? hash['brandID'] : nil city = hash.key?('city') ? hash['city'] : nil zip_code = hash.key?('zipCode') ? hash['zipCode'] : nil address = hash.key?('address') ? hash['address'] : nil country = hash.key?('country') ? hash['country'] : nil state_code = hash.key?('stateCode') ? hash['stateCode'] : nil cust_reg_date = hash.key?('custRegDate') ? hash['custRegDate'] : nil success_trans = hash.key?('successTrans') ? hash['successTrans'] : nil created_on = hash.key?('createdOn') ? hash['createdOn'] : nil last_updated = hash.key?('lastUpdated') ? hash['lastUpdated'] : nil last_activity = hash.key?('lastActivity') ? hash['lastActivity'] : nil extra_param = ExtraParam10.from_hash(hash['extraParam']) if hash['extraParam'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Success19.new(customer_id: customer_id, merchant_customer_id: merchant_customer_id, full_name: full_name, email_id: email_id, date_of_birth: date_of_birth, phone_no: phone_no, brand_id: brand_id, city: city, zip_code: zip_code, address: address, country: country, state_code: state_code, cust_reg_date: cust_reg_date, success_trans: success_trans, created_on: created_on, last_updated: last_updated, last_activity: last_activity, extra_param: extra_param, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 85 def self.names @_hash = {} if @_hash.nil? @_hash['customer_id'] = 'customerId' @_hash['merchant_customer_id'] = 'merchantCustomerId' @_hash['full_name'] = 'fullName' @_hash['email_id'] = 'emailId' @_hash['date_of_birth'] = 'dateOfBirth' @_hash['phone_no'] = 'phoneNo' @_hash['brand_id'] = 'brandID' @_hash['city'] = 'city' @_hash['zip_code'] = 'zipCode' @_hash['address'] = 'address' @_hash['country'] = 'country' @_hash['state_code'] = 'stateCode' @_hash['cust_reg_date'] = 'custRegDate' @_hash['success_trans'] = 'successTrans' @_hash['created_on'] = 'createdOn' @_hash['last_updated'] = 'lastUpdated' @_hash['last_activity'] = 'lastActivity' @_hash['extra_param'] = 'extraParam' @_hash end |
.nullables ⇒ Object
An array for nullable fields
114 115 116 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 114 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
109 110 111 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 109 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 215 def inspect class_name = self.class.name.split('::').last "<#{class_name} customer_id: #{@customer_id.inspect}, merchant_customer_id:"\ " #{@merchant_customer_id.inspect}, full_name: #{@full_name.inspect}, email_id:"\ " #{@email_id.inspect}, date_of_birth: #{@date_of_birth.inspect}, phone_no:"\ " #{@phone_no.inspect}, brand_id: #{@brand_id.inspect}, city: #{@city.inspect}, zip_code:"\ " #{@zip_code.inspect}, address: #{@address.inspect}, country: #{@country.inspect},"\ " state_code: #{@state_code.inspect}, cust_reg_date: #{@cust_reg_date.inspect},"\ " success_trans: #{@success_trans.inspect}, created_on: #{@created_on.inspect},"\ " last_updated: #{@last_updated.inspect}, last_activity: #{@last_activity.inspect},"\ " extra_param: #{@extra_param.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/paysecure_api_documentation_live/models/success19.rb', line 202 def to_s class_name = self.class.name.split('::').last "<#{class_name} customer_id: #{@customer_id}, merchant_customer_id:"\ " #{@merchant_customer_id}, full_name: #{@full_name}, email_id: #{@email_id}, date_of_birth:"\ " #{@date_of_birth}, phone_no: #{@phone_no}, brand_id: #{@brand_id}, city: #{@city},"\ " zip_code: #{@zip_code}, address: #{@address}, country: #{@country}, state_code:"\ " #{@state_code}, cust_reg_date: #{@cust_reg_date}, success_trans: #{@success_trans},"\ " created_on: #{@created_on}, last_updated: #{@last_updated}, last_activity:"\ " #{@last_activity}, extra_param: #{@extra_param}, additional_properties:"\ " #{@additional_properties}>" end |